SystemOrganization addCategory: #'Metacello-TestsMC'!
SystemOrganization addCategory: #'Metacello-TestsMC-Configurations'!
SystemOrganization addCategory: #'Metacello-TestsMC-Gofer'!
SystemOrganization addCategory: #'Metacello-TestsMC-Resources'!

TestCase subclass: #MetacelloCleanUpChangeSetsTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloCleanUpChangeSetsTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 12/21/2010 10:13'!
testCleanUpChangeSets
	"excess change sets can cause a noticeable slow down in monticello performance, so this test just cleans them up"
	
	| removals set|
	(ChangeSet respondsTo: #allChangeSets) ifFalse: [ ^self ].
	removals := OrderedCollection new.
	(set := ChangeSet perform: #allChangeSets) do: [:cs |
		(cs name beginsWith: 'MC')
			ifTrue: [
				cs name size >= 3
					ifTrue: [ | post |
						post := cs name copyFrom: 3 to: cs name size.
						post asInteger printString = post 
							ifTrue: [ removals add: cs ]]]].
	removals do: [:cs | set remove: cs ].
	removals := OrderedCollection new.
	(set := ChangeSet perform: #allChangeSets) do: [:cs |
		((cs name beginsWith: 'GoferBar') 
			or: [ (cs name beginsWith: 'GoferFoo')
				or: [ (cs name beginsWith: 'GoferFaux')
					or: [ (cs name beginsWith: 'GoferBeau')
						or: [ (cs name beginsWith: 'MetacelloTestConfiguration')]]]])
			ifTrue: [removals add: cs ]].
	removals do: [:cs | set remove: cs ].
! !

TestCase subclass: #MetacelloConfigAbstractAPITestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloConfigAbstractAPITestCase classSide methodsFor: 'testing' stamp: 'DaleHenrichs 12/20/2010 13:57'!
isAbstract
	"Override to true if a TestCase subclass is Abstract and should not have
	TestCase instances built from it"

	^self name = #MetacelloConfigAbstractAPITestCase
			! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'private' stamp: 'dkh 01/07/2010 16:46'!
conditionResult: resultString 
	"GemStone unconditionally prints Symbols with quotes, Squeak and Pharo do not"

	^(((resultString 
		copyReplaceAll: '#preloadForSupplyingAnswers' with: '#''preloadForSupplyingAnswers''')
			copyReplaceAll: '#postloadForSupplyingAnswers' with: '#''postloadForSupplyingAnswers''')
				copyReplaceAll: '#default' with: '#''default''')
! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'utilities' stamp: 'dkh 3/21/2011 15:42'!
hasPackage: aString
	| package |
	package := MCWorkingCopy allManagers
		detect: [ :each | each packageName = aString ]
		ifNone: [ nil ].
	^ package notNil! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'accessing' stamp: 'dkh 1/11/2010 14:43'!
project

	^self projectWith: #()! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'accessing' stamp: 'DaleHenrichs 12/20/2010 13:59'!
projectWith: projectAttributes

	self subclassResponsibility! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'test version' stamp: 'dkh 12/30/2009 12:50'!
testBlessing
	| project version |
	project := self project.

	version := project version: '1.0-baseline'.
	self assert: version blessing = #testBlessing! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'test version' stamp: 'dkh 12/30/2009 12:56'!
testBlessingBlock
	| project version |
	project := self project.

	version := project version: '1.0.1-baseline'.
	self assert: version blessing = #testBlessing! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'test version' stamp: 'DaleHenrichs 11/4/2010 18:39'!
testIssue100
	"Issue 100:	last block wins when there are duplicate attribute blocks"

	| project version repositoryDescriptions |
	project := self project.

	version := project version: '1.2.4-baseline'.
	self assert: version blessing = #baseline.
	repositoryDescriptions := version spec repositorySpecs collect: [:repoSpec | repoSpec description ].
	self assert: repositoryDescriptions size = 2.
	self assert: (repositoryDescriptions includes: 'http://www.example.com/aa').
	self assert: (repositoryDescriptions includes: 'http://www.example.com/ab').

	version := project version: '1.2.4'.
	self assert: version blessing = #baseline.
	repositoryDescriptions := version spec repositorySpecs collect: [:repoSpec | repoSpec description ].
	self assert: repositoryDescriptions size = 3.
	self assert: (repositoryDescriptions includes: 'http://www.example.com/aa').
	self assert: (repositoryDescriptions includes: 'http://www.example.com/ab').
	self assert: (repositoryDescriptions includes: 'http://www.example.com/ac').
! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'test baselines' stamp: 'dkh 1/11/2010 14:51'!
testNestedBaseline

	| project version packageNames |
	project := self projectWith: #().
	version := project version: '1.1.1-baseline'.
	packageNames := version packages collect: [:pkg | pkg name].
	self assert: packageNames size = 1.
	self assert: (packageNames includes: 'Example-Core').

	project := self projectWith: #(#extra).
	version := project version: '1.1.1-baseline'.
	packageNames := version packages collect: [:pkg | pkg name].
	self assert: packageNames size = 2.
	self assert: (packageNames includes: 'Example-Core').
	self assert: (packageNames includes: 'Example-Test').

	project := self projectWith: #(#nested).
	version := project version: '1.1.1-baseline'.
	packageNames := version packages collect: [:pkg | pkg name].
	self assert: packageNames size = 2.
	self assert: (packageNames includes: 'Example-Core').
	self assert: (packageNames includes: 'Example-Base').

	project := self projectWith: #(nested extra).
	version := project version: '1.1.1-baseline'.
	packageNames := version packages collect: [:pkg | pkg name].
	self assert: packageNames size = 3.
	self assert: (packageNames includes: 'Example-Core').
	self assert: (packageNames includes: 'Example-Base').
	self assert: (packageNames includes: 'Example-Test').
! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'test baselines' stamp: 'dkh 1/11/2010 15:15'!
testNestedBaselineOrder

	| project version packageNames |
	project := self projectWith: #().
	version := project version: '1.1.2-baseline'.
	packageNames := version packages collect: [:pkg | pkg name].
	self assert: packageNames size = 1.
	self assert: (packageNames includes: 'Example-Core').

	project := self projectWith: #(#extra).
	version := project version: '1.1.2-baseline'.
	packageNames := version packages collect: [:pkg | pkg name].
	self assert: packageNames size = 2.
	self assert: (packageNames includes: 'Example-Core').
	self assert: (packageNames includes: 'Example-Test').

	project := self projectWith: #(#nested).
	version := project version: '1.1.2-baseline'.
	packageNames := version packages collect: [:pkg | pkg name].
	self assert: packageNames size = 3.
	self assert: (packageNames includes: 'Example-Core').
	self assert: (packageNames includes: 'Example-Base').
	self assert: (packageNames includes: 'Example-Test-Nested').

	project := self projectWith: #(nested extra).
	version := project version: '1.1.2-baseline'.
	packageNames := version packages collect: [:pkg | pkg name].
	self assert: packageNames size = 4.
	self assert: (packageNames includes: 'Example-Core').
	self assert: (packageNames includes: 'Example-Base').
	self assert: (packageNames includes: 'Example-Test').
	self assert: (packageNames includes: 'Example-Test-Nested').

	project := self projectWith: #(extra nested).
	version := project version: '1.1.2-baseline'.
	packageNames := version packages collect: [:pkg | pkg name].
	self assert: packageNames size = 4.
	self assert: (packageNames includes: 'Example-Core').
	self assert: (packageNames includes: 'Example-Base').
	self assert: (packageNames includes: 'Example-Test').
	self assert: (packageNames includes: 'Example-Test-Nested').
! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'test baselines' stamp: 'dkh 1/11/2010 15:32'!
testNestedVersionOrder

	| project version fileNames |
	project := self projectWith: #(outer).
	version := project version: '1.1.3'.
	fileNames := version packages collect: [:pkg | pkg file].
	self assert: fileNames size = 2.
	self assert: (fileNames includes: 'Example-Core-dkh.1').
	self assert: (fileNames includes: 'Example-Test-dkh.1').

	project := self projectWith: #(extra).
	version := project version: '1.1.3'.
	fileNames := version packages collect: [:pkg | pkg file].
	self assert: fileNames size = 1.
	self assert: (fileNames includes: 'Example-Core-dkh.3').

	project := self projectWith: #(extra nested).
	version := project version: '1.1.3'.
	fileNames := version packages collect: [:pkg | pkg file].
	self assert: fileNames size = 1.
	self assert: (fileNames includes: 'Example-Core-dkh.3').

	project := self projectWith: #(outer extra).
	version := project version: '1.1.3'.
	fileNames := version packages collect: [:pkg | pkg file].
	self assert: fileNames size = 2.
	self assert: (fileNames includes: 'Example-Core-dkh.3').
	self assert: (fileNames includes: 'Example-Test-dkh.1').

	project := self projectWith: #(outer #nested).
	version := project version: '1.1.3'.
	fileNames := version packages collect: [:pkg | pkg file].
	self assert: (fileNames includes: 'Example-Core-dkh.2').

	project := self projectWith: #(outer nested extra).
	version := project version: '1.1.3'.
	fileNames := version packages collect: [:pkg | pkg file].
	self assert: (fileNames includes: 'Example-Core-dkh.3').

	project := self projectWith: #(outer extra nested).
	version := project version: '1.1.3'.
	fileNames := version packages collect: [:pkg | pkg file].
	self assert: (fileNames includes: 'Example-Core-dkh.2').

	project := self projectWith: #(extra nested outer ).
	version := project version: '1.1.3'.
	fileNames := version packages collect: [:pkg | pkg file].
	self assert: (fileNames includes: 'Example-Core-dkh.1').
! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'test package' stamp: 'dkh 1/6/2010 18:29'!
testPackageIncludes
	| project versionSpec version pkg string expected |
	project := self project.

	versionSpec := (version := project version: '1.0.9-baseline') spec.
	pkg := version packageNamed: 'Example-Core'.
	string := pkg printString.
	expected := 'spec name: ''Example-Core'''.
	self assert: string = expected.
	pkg := version packageNamed: 'Example-Tests'.
	string := pkg printString.
	expected := 'spec 
	name: ''Example-Tests'';
	includes: #(''Example-Core'' ).'.
	self assert: string = expected
! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'test package' stamp: 'DaleHenrichs 12/20/2010 15:55'!
testPackageIncludesRequiresSupplyingAnswers
	| project versionSpec version pkg string expected |
	project := self project.

	versionSpec := (version := project version: '1.1.0-baseline') spec.
	pkg := version packageNamed: 'Example-Test1'.
	string := pkg printString.
	expected := 'spec 
	name: ''Example-Test1'';
	requires: #(''Example-Base'' );
	includes: #(''Example-Core'' ).'.
	self assert: string = expected.

	pkg := version packageNamed: 'Example-Test2'.
	string := pkg printString.
	expected := 'spec 
	name: ''Example-Test2'';
	includes: #(''Example-Core'' );
	supplyingAnswers: #( #( ''captionMatch'' ''answer'' ) ).'.
	self assert: string = expected.

	pkg := version packageNamed: 'Example-Test3'.
	string := pkg printString.
	expected := 'spec 
	name: ''Example-Test3'';
	requires: #(''Example-Base'' );
	supplyingAnswers: #( #( ''captionMatch'' ''answer'' ) ).'.
	self assert: string = expected.

	pkg := version packageNamed: 'Example-Test4'.
	string := pkg printString.
	expected := 'spec 
	name: ''Example-Test4'';
	requires: #(''Example-Base'' );
	includes: #(''Example-Core'' );
	supplyingAnswers: #( #( ''captionMatch'' ''answer'' ) ).'.
	self assert: string = expected.
! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'test package' stamp: 'dkh 1/2/2010 17:01'!
testPackageRepositories
	| project versionSpec version pkg repositoryDescriptions string expected |
	project := self project.

	versionSpec := (version := project version: '1.0.6-baseline') spec.
	pkg := version packageNamed: 'Example-Core'.
	repositoryDescriptions := pkg repositorySpecs collect: [:repoSpec | repoSpec description ].
	self assert: repositoryDescriptions size = 2.
	self assert: (repositoryDescriptions includes: 'http://www.example.com/ob').
	self assert: (repositoryDescriptions includes: 'http://www.example.com/or').
	string := pkg printString.
	expected := 'spec 
	name: ''Example-Core'';
	repositories: [
		spec
			repository: ''http://www.example.com/ob'';
			repository: ''http://www.example.com/or'' ].'.
	self assert: string = expected
! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'test package' stamp: 'dkh 1/2/2010 14:06'!
testPackageRepository
	| project versionSpec version pkg |
	project := self project.

	versionSpec := (version := project version: '1.0.5-baseline') spec.
	pkg := version packageNamed: 'Example-Core'.
	self assert: pkg repositorySpecs first description = 'http://www.example.com/ob'! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'test package' stamp: 'dkh 1/6/2010 18:21'!
testPackageRequires
	| project versionSpec version pkg string expected |
	project := self project.

	versionSpec := (version := project version: '1.0.8-baseline') spec.
	pkg := version packageNamed: 'Example-Core'.
	string := pkg printString.
	expected := 'spec name: ''Example-Core'''.
	self assert: string = expected.
	pkg := version packageNamed: 'Example-Tests'.
	string := pkg printString.
	expected := 'spec 
	name: ''Example-Tests'';
	requires: #(''Example-Core'' ).'.
	self assert: string = expected
! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'test project' stamp: 'DaleHenrichs 3/12/2010 11:16'!
testProjectPackage
	| project version loader |
	project := self project.

	version := project version: '1.1.4-baseline'.
	loader := version record.
	loader loadDirective versionDirectivesDo: [:directive | | versionSpec |
		(versionSpec := directive spec) ~~ nil
			ifTrue: [ 
				versionSpec versionString = '1.1.4-baseline'
					ifTrue: [ | projectSpec |
						projectSpec := (versionSpec packageNamed: 'Example Project' ifAbsent: [ self assert: false]) projectReference.
						self assert: projectSpec projectPackage file =  projectSpec projectPackage file ]]].! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'test project' stamp: 'DaleHenrichs 12/20/2010 14:07'!
testProjectPackageRepositories
	| project version ref repositoryDescriptions string pkg expected |
	project := self project.

	version := project version: '1.2.3-baseline'.
	ref := version packageNamed: 'Example Project'.
	repositoryDescriptions := ref projectPackage repositorySpecs collect: [:repoSpec | repoSpec description ].
	self assert: repositoryDescriptions size = 2.
	self assert: (repositoryDescriptions includes: 'http://www.example.com/ob').
	self assert: (repositoryDescriptions includes: 'http://www.example.com/or').
	string := ref printString.
	expected := 'spec 
	name: ''Example Project'';
	className: ''MetacelloExampleProjectConfig'';
	repository: ''http://www.example.com/ob'';
	repository: ''http://www.example.com/or''.'.
	self assert: string = expected
! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'test project' stamp: 'DaleHenrichs 12/20/2010 14:08'!
testProjectPackageRepository
	| project version ref string expected |
	project := self project.

	version := project version: '1.2.2-baseline'.
	ref := version packageNamed: 'Example Project'.
	self assert: ref projectPackage repositorySpecs first description = 'http://www.example.com/ob'.
	string := ref printString.
	expected := 'spec 
	name: ''Example Project'';
	className: ''MetacelloExampleProjectConfig'';
	repository: ''http://www.example.com/ob''.'.
	self assert: string = expected
! !

!MetacelloConfigAbstractAPITestCase methodsFor: 'test version' stamp: 'DaleHenrichs 9/24/2010 11:55'!
testVersionErrors
	| project  |
	project := self project.
	
	self should: [project version: 'does not exist' ] raise: MetacelloVersionDoesNotExistError.
	self should: [project version: #'does not exist' ] raise: MetacelloSymbolicVersionDoesNotExistError.

! !

MetacelloConfigAbstractAPITestCase subclass: #MetacelloConfigAPITestCase
	instanceVariableNames: 'alternatePreLoadExecuted preLoadExecuted postLoadExecuted preloadAnswer postloadAnswer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloConfigAPITestCase methodsFor: 'doits' stamp: 'DaleHenrichs 12/20/2010 13:55'!
alternatePreloadForCore

	alternatePreLoadExecuted := true
! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline100: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #testBlessing.
		spec 
			package: 'Example-Core' with: [ 
				spec 
					includes: 'Example-AddOn';
					file: 'Example-Core-anon.1';
					repository: 'http://www.example.com/or';
					preLoadDoIt: #preloadForCore;
					postLoadDoIt: #postloadForCore:package: ];
			package: 'Example-AddOn' with: [ spec requires: #('Example-Core' ) ];
			package: 'Example-Tests' with: [ spec requires: #('Example-AddOn' ) ]].
! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline101: spec 
	<version: '1.0.1-baseline'>
	
	spec for: #common do: [
		spec blessing: [
			spec value: #testBlessing ]].
! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline102: spec 
	<version: '1.0.2-baseline'>
	
	spec for: #common do: [
		spec 
			preLoadDoIt: #preloadForCore;
			postLoadDoIt: #postloadForCore:package:.
		spec 
			package: 'Example-Core' with: [ spec includes: 'Example-AddOn' ];
			package: 'Example-AddOn' with: [ spec requires: #('Example-Core' ) ];
			package: 'Example-Tests' with: [ spec requires: #('Example-AddOn' ) ]]! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline103: spec 
	<version: '1.0.3-baseline' imports: #( '1.0.2-baseline' )>
	
	spec for: #common do: [
		spec 
			preLoadDoIt: #alternatePreloadForCore ]! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline104: spec 
	<version: '1.0.4-baseline' imports: #( '1.0.2-baseline' )>
	
	spec for: #common do: [
		spec 
			preLoadDoIt: nil ]! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline105: spec 
	<version: '1.0.5-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core' with: [ 
				spec repository: 'http://www.example.com/ob' ]].
! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline106: spec 
	<version: '1.0.6-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core' with: [ 
				spec repositories: [
						spec 
							repository: 'http://www.example.com/or';
							repository: 'http://www.example.com/ob' ]]].
! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline107: spec 
	<version: '1.0.7-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core' with: [ 
				spec 
					preLoadDoIt: #preloadForSupplyingAnswers;
					postLoadDoIt: #postloadForSupplyingAnswers;
					supplyingAnswers: #(#('preload' 'preload answer') #('postload' 'postload answer')) ];
			package: 'Example-Tests' with: [
				spec supplyingAnswers: 
					#(
						#('string' 'preload answer') 
						#('symbol' #'default')
						#('integer' 1)
						#('boolean' true)
						#('another boolean' false)
						#('character' $a)
					)]].
! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline108: spec 
	<version: '1.0.8-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core';
			package: 'Example-Tests' with: [ 
				spec requires: 'Example-Core' ]].
! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline109: spec 
	<version: '1.0.9-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core';
			package: 'Example-Tests' with: [ 
				spec includes: 'Example-Core' ]].
! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline110: spec 
	<version: '1.1.0-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core';
			package: 'Example-Base';
			package: 'Example-Test1' with: [ 
				spec 
					includes: 'Example-Core';
					requires: 'Example-Base' ];
			package: 'Example-Test2' with: [ 
				spec 
					includes: 'Example-Core';
					supplyingAnswers: #(#('captionMatch' 'answer')) ];
			package: 'Example-Test3' with: [ 
				spec 
					supplyingAnswers: #(#('captionMatch' 'answer'));
					requires: 'Example-Base' ];
			package: 'Example-Test4' with: [ 
				spec 
					includes: 'Example-Core';
					supplyingAnswers: #(#('captionMatch' 'answer'));
					requires: 'Example-Base' ];
			yourself].
! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline111: spec 
	<version: '1.1.1-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core'.
		spec for: #nested do: [
			spec
				package: 'Example-Base';
				yourself ]].
	spec for: #extra do: [
		spec
			package: 'Example-Test';
			yourself].
! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline112: spec 
	<version: '1.1.2-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core'.
		spec for: #nested do: [
			spec
				package: 'Example-Base';
				package: 'Example-Test-Nested';
				yourself ]].
	spec for: #extra do: [
		spec
			package: 'Example-Test';
			yourself].
! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline113: spec 
	<version: '1.1.3-baseline'>
	
	spec for: #outer do: [
		spec 
			package: 'Example-Core';
			package: 'Example-Test';
			yourself].
! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 15:53'!
baseline114: spec 
	<version: '1.1.4-baseline'>
	
	spec for: #common do: [
		spec 
			project: 'Example Project' with: [
				spec
					className: 'MetacelloExampleProjectConfig';
					versionString: '1.0-baseline';
					preLoadDoIt: #preloadForProject;
					postLoadDoIt: #postloadForProject;
					repository: 'http://www.example.com/ob';
					yourself. ];
			yourself].
! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline115: spec 
	<version: '1.1.5-baseline' imports: #( '1.1.4-baseline' )>
	
	spec for: #common do: [
		spec 
			project: 'Example Project' with: [
				spec preLoadDoIt: #alternatePreloadForCore ]]! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline116: spec 
	<version: '1.1.6-baseline' imports: #( '1.1.4-baseline' )>
	
	spec for: #common do: [
		spec 
			project: 'Example Project' with: [
				spec preLoadDoIt: #alternatePreloadForCore ]]! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline117: spec 
	<version: '1.1.7-baseline' imports: #( '1.0-baseline' ) >
	
	spec for: #common do: [
		spec 
			package: 'Example-Core' overrides: [ 
				spec 
					preLoadDoIt: #alternatePreloadForCore ]].
! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline118: spec 
	<version: '1.1.8-baseline' imports: #( '1.0-baseline' ) >
	
	spec for: #common do: [
		spec 
			package: 'Example-Core' with: [ 
				spec 
					preLoadDoIt: #alternatePreloadForCore ]].
! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline119: spec 
	<version: '1.1.9-baseline' imports: #( '1.1.4-baseline' )>
	
	spec for: #common do: [
		spec 
			project: 'Example Project' overrides: [
				spec
					className: 'MetacelloExampleProjectConfig';
					versionString: '1.0-baseline';
					preLoadDoIt: #alternatePreloadForCore;
					yourself.]]! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline120: spec 
	<version: '1.2.0-baseline' imports: #( '1.1.4-baseline' )>
	
	spec for: #common do: [
		spec 
			project: 'Copied Example' copyFrom: 'Example Project' with: [
				spec preLoadDoIt: #alternatePreloadForCore ]]! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline121: spec 
	<version: '1.2.1-baseline'>
	
	spec for: #common do: [
		spec blessing: #testBlessing.
		spec repository: 'http://www.example.com/vor'.
		spec 
			package: 'Example-Core' with: [ 
				spec 
					includes: 'Example-AddOn';
					file: 'Example-Core-anon.1';
					repository: 'http://www.example.com/or';
					preLoadDoIt: #preloadForCore;
					postLoadDoIt: #postloadForCore:package: ];
			package: 'Example-AddOn' with: [ spec requires: #('Example-Core' ) ];
			package: 'Example-Tests' with: [ spec requires: #('Example-AddOn' ) ]].
! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline122: spec 
	<version: '1.2.2-baseline'>
	
	spec for: #common do: [
		spec 
			project: 'Example Project' with: [
				spec
					className: 'MetacelloExampleProjectConfig';
					repository: 'http://www.example.com/ob';
					yourself. ];
			yourself].
! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline123: spec 
	<version: '1.2.3-baseline'>
	
	spec for: #common do: [
		spec 
			project: 'Example Project' with: [
				spec
					className: 'MetacelloExampleProjectConfig';
					repository: 'http://www.example.com/ob';
					repository: 'http://www.example.com/or';
					yourself. ];
			yourself].
! !

!MetacelloConfigAPITestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 13:58'!
baseline124: spec 
	<version: '1.2.4-baseline'>
	
	spec for: #common do: [
		spec
			blessing: #baseline;
			repository: 'http://www.example.com/aa';
			yourself.].

	spec for: #common do: [
		spec
			repository: 'http://www.example.com/ab';
			yourself.].
! !

!MetacelloConfigAPITestCase methodsFor: 'doits' stamp: 'DaleHenrichs 12/20/2010 13:55'!
postloadForCore: mcLoader package: pkgSpec

	postLoadExecuted := true! !

!MetacelloConfigAPITestCase methodsFor: 'doits' stamp: 'DaleHenrichs 12/20/2010 13:55'!
postloadForProject

	postLoadExecuted := true! !

!MetacelloConfigAPITestCase methodsFor: 'doits' stamp: 'DaleHenrichs 12/20/2010 13:54'!
postloadForSupplyingAnswers

	postloadAnswer := ProvideAnswerNotification signal: 'postload'! !

!MetacelloConfigAPITestCase methodsFor: 'doits' stamp: 'DaleHenrichs 12/20/2010 13:54'!
preloadForCore

	preLoadExecuted := true
! !

!MetacelloConfigAPITestCase methodsFor: 'doits' stamp: 'DaleHenrichs 12/20/2010 13:54'!
preloadForProject

	preLoadExecuted := true
! !

!MetacelloConfigAPITestCase methodsFor: 'doits' stamp: 'DaleHenrichs 12/20/2010 13:55'!
preloadForSupplyingAnswers

	preloadAnswer := ProvideAnswerNotification signal: 'preload'! !

!MetacelloConfigAPITestCase methodsFor: 'accessing' stamp: 'DaleHenrichs 12/20/2010 13:59'!
projectWith: projectAttributes

	| project |
	"Construct Metacello project"
	project := MetacelloMCProject new.
	project projectAttributes: projectAttributes.
	MetacelloVersionConstructor on: self project: project.
	project loader: MetacelloNullRecordingMCSpecLoader new.
	project loader evalDoits: true.
	^project! !

!MetacelloConfigAPITestCase methodsFor: 'running' stamp: 'DaleHenrichs 12/20/2010 13:56'!
setUp

	super setUp.
	alternatePreLoadExecuted := preLoadExecuted := postLoadExecuted := false! !

!MetacelloConfigAPITestCase methodsFor: 'test null loader' stamp: 'DaleHenrichs 12/20/2010 14:08'!
testNullLoaderLoadedRepositories

	| project version loader repositories |
	project := self project.

	version := project version: '1.2.1-baseline'.
	loader := version load.
	repositories := loader loadedRepositories.
	self assert: repositories size = 2.
	repositories do: [:repo |
		self assert: repo class == MCHttpRepository.
		self assert: (#('http://www.example.com/vor' 'http://www.example.com/or') includes: repo description) ].! !

!MetacelloConfigAPITestCase methodsFor: 'test package' stamp: 'DaleHenrichs 12/20/2010 13:53'!
testPackagePreloadOverride
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.1.7-baseline') spec.
	self deny: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test package' stamp: 'DaleHenrichs 12/21/2010 11:45'!
testPackagePreloadPostload
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.0-baseline') spec.
	self assert: (versionSpec packages map at: 'Example-Core') preLoadDoIt value == #preloadForCore.
	self assert: (versionSpec packages map at: 'Example-Core') postLoadDoIt value == #postloadForCore:package:.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test package' stamp: 'DaleHenrichs 12/20/2010 13:53'!
testPackagePreloadWith
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.1.8-baseline') spec.
	self deny: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test package' stamp: 'DaleHenrichs 12/20/2010 15:55'!
testPackageSupplyingAnswers
	| project versionSpec version pkg string expected |
	project := self project.

	versionSpec := (version := project version: '1.0.7-baseline') spec.
	pkg := version packageNamed: 'Example-Core'.
	string := self conditionResult: pkg printString.
	expected := 'spec 
	name: ''Example-Core'';
	supplyingAnswers: #( #( ''preload'' ''preload answer'' ) #( ''postload'' ''postload answer'' ) );
	preLoadDoIt: #''preloadForSupplyingAnswers'';
	postLoadDoIt: #''postloadForSupplyingAnswers''.'.
	self assert: string = expected.
	self assert: pkg answers = #(#('preload' 'preload answer') #('postload' 'postload answer')).

	self deny: preloadAnswer = 'preload answer'.
	self deny: postloadAnswer = 'postload answer'.
	version load.
	self assert: preloadAnswer = 'preload answer'.
	self assert: postloadAnswer = 'postload answer'.

	pkg := version packageNamed: 'Example-Tests'.
	string := self conditionResult: pkg printString.
	expected := 'spec 
	name: ''Example-Tests'';
	supplyingAnswers: #( #( ''string'' ''preload answer'' ) #( ''symbol'' #''default'' ) #( ''integer'' 1 ) #( ''boolean'' true ) #( ''another boolean'' false ) #( ''character'' $a ) ).'.
	self assert: string = expected.
! !

!MetacelloConfigAPITestCase methodsFor: 'test directives' stamp: 'DaleHenrichs 12/21/2010 11:46'!
testPrePostPackageLoadsDo
	| project version loader loadDirective preloaded count pkgloaded postloaded |
	project := self project.

	version := project version: '1.0-baseline'.
	loader := version fetch.
	loadDirective := loader loadDirective.
	pkgloaded := postloaded := preloaded := false.
	loadDirective directivesDo: [:directive |
		directive preLoadDo: [:pre |
			self deny: preloaded.			 
			self deny: pkgloaded.
			self deny: postloaded.
			preloaded := true.
			self assert: (#preloadForCore == pre spec preLoadDoIt value) ].
		directive packageDo: [:pkg | 
			preloaded ifTrue: [ 
				self deny: postloaded.
				pkgloaded := true.
				pkg spec name = 'Example-Core' ]].
		directive postLoadDo: [:post | 
			self assert: preloaded.			 
			self assert: pkgloaded.
			self deny: postloaded.
			preloaded := false.
			postloaded := true.
			self assert: (#postloadForCore:package: == post spec postLoadDoIt value) ]].
	self assert: postloaded! !

!MetacelloConfigAPITestCase methodsFor: 'test directives' stamp: 'DaleHenrichs 12/21/2010 11:46'!
testPrepostProjectLoadsDo
	| project version loader loadDirective x |
	project := self project.

	version := project version: '1.1.6-baseline'.
	loader := version fetch.
	loadDirective := loader loadDirective.
	loadDirective prepostLoadDirectivesDo: [:directive |
		directive preLoadDo: [:pre | self assert: (#alternatePreloadForCore == directive spec preLoadDoIt value) ].
		directive postLoadDo: [:post | self assert: (#postloadForProject == directive spec postLoadDoIt value) ]].
! !

!MetacelloConfigAPITestCase methodsFor: 'test project' stamp: 'DaleHenrichs 12/20/2010 13:53'!
testProjectPreloadCopyFrom
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.2.0-baseline') spec.
	self deny: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load: 'Copied Example'.
	self assert: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test project' stamp: 'DaleHenrichs 12/20/2010 13:52'!
testProjectPreloadCopyFromB
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.2.0-baseline') spec.
	self deny: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load: 'Example Project'.
	self deny: alternatePreLoadExecuted.
	self assert: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test project' stamp: 'DaleHenrichs 12/20/2010 13:52'!
testProjectPreloadOverride
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.1.9-baseline') spec.
	self deny: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test project' stamp: 'DaleHenrichs 12/20/2010 13:53'!
testProjectPreloadPostload
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.1.4-baseline') spec.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test project' stamp: 'DaleHenrichs 12/20/2010 13:52'!
testProjectPreloadWith
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.1.6-baseline') spec.
	self deny: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test version' stamp: 'DaleHenrichs 12/20/2010 13:52'!
testVersionPreloadOverride
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.0.3-baseline') spec.
	self deny: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test version' stamp: 'DaleHenrichs 12/20/2010 13:53'!
testVersionPreloadPostload
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.0.2-baseline') spec.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'test version' stamp: 'DaleHenrichs 12/20/2010 13:52'!
testVersionPreloadRemove
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.0.4-baseline') spec.
	self deny: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self deny: alternatePreLoadExecuted.
	self deny: preLoadExecuted.
	self assert: postLoadExecuted.! !

!MetacelloConfigAPITestCase methodsFor: 'versions' stamp: 'DaleHenrichs 12/20/2010 13:59'!
version113: spec 
	<version: '1.1.3' imports: #( '1.1.3-baseline' )>
	
	spec for: #outer do: [
		spec
			package: 'Example-Core' with: 'Example-Core-dkh.1';
			package: 'Example-Test' with: 'Example-Test-dkh.1'.
		spec for: #nested do: [
			spec
				package: 'Example-Core' with: 'Example-Core-dkh.2';
				yourself ]].
	spec for: #extra do: [
		spec
			package: 'Example-Core' with: 'Example-Core-dkh.3';
			yourself].
! !

!MetacelloConfigAPITestCase methodsFor: 'versions' stamp: 'DaleHenrichs 12/20/2010 13:59'!
version124: spec 
	<version: '1.2.4' imports: #( '1.2.4-baseline' )>
	
	spec for: #common do: [
		spec
			repository: 'http://www.example.com/ac';
			yourself.].
! !

MetacelloConfigAbstractAPITestCase subclass: #MetacelloConfigAPIToolBoxTestCase
	instanceVariableNames: 'gofer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'running' stamp: 'DaleHenrichs 12/20/2010 13:21'!
configurationRepository
	"MetacelloConfigurationResource reset"

	^ MetacelloConfigurationResource current monticelloRepository! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'accessing' stamp: 'DaleHenrichs 12/20/2010 13:22'!
monticelloRepository
	"MetacelloMonticelloResource reset"
	^ MetacelloMonticelloResource current monticelloRepository! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'accessing' stamp: 'DaleHenrichs 12/20/2010 13:30'!
projectWith: projectAttributes

	| project |
	"Construct Metacello project"
	project := MetacelloMCProject new.
	project projectAttributes: projectAttributes.
	MetacelloVersionConstructor on: (Smalltalk at: #MetacelloTestConfigurationOfProjectToolBox) new project: project.
	project loader: MetacelloNullRecordingMCSpecLoader new.
	project loader evalDoits: true.
	^project! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'running' stamp: 'DaleHenrichs 12/20/2010 13:45'!
runCase
	| original |
	original := MetacelloPlatform current bypassGoferLoadUpdateCategories.
	[ 
	MetacelloPlatform current bypassGoferLoadUpdateCategories: true.
	^ SystemChangeNotifier uniqueInstance doSilently: [ super runCase ] ]
		ensure: [ MetacelloPlatform current bypassGoferLoadUpdateCategories: original ]! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'running' stamp: 'DaleHenrichs 1/5/2011 15:10'!
setUp
	| repo |
	super setUp.
	MetacelloConfigurationResource projectAttributes: nil.
	repo := self monticelloRepository.
	gofer := Gofer new.
	gofer disablePackageCache.
	gofer repository: repo.
	Smalltalk at: #'Metacello_Gofer_Test_Repository' put: repo.
	repo := self configurationRepository.
	gofer repository: repo.
	Smalltalk at: #'Metacello_Configuration_Test_Repository' put: repo.
	gofer package: 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer metacelloLoad.
	Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result' put: false.
	Smalltalk at: #'Metacello_Configuration_Test_POST_DoIt_Result' put: false.
! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'running' stamp: 'dkh 3/21/2011 15:39'!
tearDown
	| aGofer |
	super tearDown.
	aGofer := Gofer new.
	(self hasPackage: 'MetacelloTestConfigurationOfProjectToolBox')
		ifTrue: [ aGofer package: 'MetacelloTestConfigurationOfProjectToolBox' ].
	(self hasPackage: 'MetacelloTestConfigurationOfProjectIssue115')
		ifTrue: [ aGofer package: 'MetacelloTestConfigurationOfProjectIssue115' ].
	aGofer references notEmpty ifTrue: [ aGofer metacelloUnload ].
	Smalltalk removeKey: #'Metacello_Gofer_Test_Repository' ifAbsent: [].
	Smalltalk removeKey: #'Metacello_Configuration_Test_Repository' ifAbsent: [].
	Smalltalk removeKey: #'Metacello_Configuration_Test_DoIt_Result' ifAbsent: [].
	Smalltalk removeKey: #'Metacello_Configuration_Test_POST_DoIt_Result' ifAbsent: [].
! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'test nested for:do:' stamp: 'DaleHenrichs 01/16/2011 13:45'!
testNestedForDoOrder1
	"evaluation of nested for:do: blocks is in breadth first order"

	| project version string expected |
	project := self projectWith: #(#'level1_1').
	version := project version: '1.3.1-baseline'.
	string := version spec printString.
	expected := 'spec blessing: #''baseline''.
spec 
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/1''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/2''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/3''. ].'.
	self assert: string = expected.
! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'test nested for:do:' stamp: 'dkh 1/5/2011 16:38'!
testNestedForDoOrder2

	| project version string expected |
	project := self projectWith: #(#'level1_1' #'level2_1').
	version := project version: '1.3.1-baseline'.
	string := version spec printString.
	expected := 'spec blessing: #''baseline''.
spec 
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/1''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/2''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/3''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/4''. ].'.
	self assert: string = expected.
	
! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'test nested for:do:' stamp: 'dkh 1/5/2011 16:38'!
testNestedForDoOrder3

	| project version string expected |
	project := self projectWith: #(#'level1_1' #'level2_1' #'level3_1').
	version := project version: '1.3.1-baseline'.
	string := version spec printString.
	expected := 'spec blessing: #''baseline''.
spec 
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/1''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/2''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/3''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/4''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/5''. ].'.
	self assert: string = expected.
	
! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'test nested for:do:' stamp: 'dkh 1/5/2011 16:38'!
testNestedForDoOrder4

	| project version string expected |
	project := self projectWith: #(#'level1_1' #'level2_1' #'level2_2').
	version := project version: '1.3.1-baseline'.
	string := version spec printString.
	expected := 'spec blessing: #''baseline''.
spec 
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/1''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/2''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/3''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/4''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/6''. ].'.
	self assert: string = expected.
	
! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'test nested for:do:' stamp: 'dkh 1/5/2011 16:39'!
testNestedForDoOrder5

	| project version string expected |
	project := self projectWith: #(#'level1_1' #'level2_2' #'level2_1').
	version := project version: '1.3.1-baseline'.
	string := version spec printString.
	expected := 'spec blessing: #''baseline''.
spec 
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/1''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/2''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/3''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/6''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/4''. ].'.
	self assert: string = expected.
	
! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'test nested for:do:' stamp: 'dkh 1/5/2011 16:39'!
testNestedForDoOrder6

	| project version string expected |
	project := self projectWith: #(#'level1_1' #'level2_1' #'level2_2' #'level3_2').
	version := project version: '1.3.1-baseline'.
	string := version spec printString.
	expected := 'spec blessing: #''baseline''.
spec 
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/1''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/2''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/3''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/4''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/6''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/7''. ].'.
	self assert: string = expected.
	
! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'test nested for:do:' stamp: 'dkh 1/5/2011 16:39'!
testNestedForDoOrder7

	| project version string expected |
	project := self projectWith: #( #'level1_1' #'level2_1' #'level2_2' #'level3_2' #'level3_1').
	version := project version: '1.3.1-baseline'.
	string := version spec printString.
	expected := 'spec blessing: #''baseline''.
spec 
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/1''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/2''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/3''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/4''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/6''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/7''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/5''. ].'.
	self assert: string = expected.
	
! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'test nested for:do:' stamp: 'dkh 1/5/2011 16:40'!
testNestedForDoOrder8

	| project version string expected |
	project := self projectWith: #( #'level1_1' #'level2_2' #'level3_2' #'level2_1').
	version := project version: '1.3.1-baseline'.
	string := version spec printString.
	expected := 'spec blessing: #''baseline''.
spec 
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/1''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/2''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/3''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/6''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/7''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/4''. ].'.
	self assert: string = expected.
	
! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'test package' stamp: 'DaleHenrichs 12/21/2010 12:23'!
testPackagePreloadOverride

	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.2.6-baseline') spec.
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result').
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_POST_DoIt_Result').
	version load.
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result').
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_POST_DoIt_Result').! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'test package' stamp: 'DaleHenrichs 12/21/2010 12:31'!
testPackagePreloadPostload
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.2.5-baseline') spec.
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result').
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_POST_DoIt_Result').
	version load.
	self assert: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result').
	self assert: (Smalltalk at: #'Metacello_Configuration_Test_POST_DoIt_Result').! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'test project' stamp: 'DaleHenrichs 01/16/2011 13:38'!
testProjectCopyPackageRepositories
	| project version ref repositoryDescriptions string pkg expected |
	project := self project.

	version := project version: '1.3.0-baseline'.
	ref := version packageNamed: 'Copy Project'.
	repositoryDescriptions := ref projectPackage repositorySpecs collect: [:repoSpec | repoSpec description ].
	self assert: repositoryDescriptions size = 2.
	self assert: (repositoryDescriptions includes: 'http://www.example.com/ob').
	self assert: (repositoryDescriptions includes: 'http://www.example.com/or').
	string := ref printString.
	expected := 'spec 
	name: ''Copy Project'';
	className: ''MetacelloExampleProjectConfig'';
	versionString: ''1.0-baseline'';
	preLoadDoIt: #''preloadDoIt'';
	postLoadDoIt: #''postloadDoIt'';
	repository: ''http://www.example.com/ob'';
	repository: ''http://www.example.com/or''.'.
	self assert: string = expected! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'test project' stamp: 'DaleHenrichs 12/21/2010 12:32'!
testProjectCopyPreloadOverride

	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.2.9-baseline') spec.
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result').
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_POST_DoIt_Result').
	version load: 'Copy Project'.
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result').
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_POST_DoIt_Result').! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'test project' stamp: 'DaleHenrichs 12/21/2010 12:42'!
testProjectCopyPreloadPostload
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.2.9-baseline') spec.
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result').
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_POST_DoIt_Result').
	version load: 'Example Project'.
	self assert: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result').
	self assert: (Smalltalk at: #'Metacello_Configuration_Test_POST_DoIt_Result').! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'test project' stamp: 'DaleHenrichs 12/21/2010 12:40'!
testProjectPreloadOverride

	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.2.8-baseline') spec.
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result').
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_POST_DoIt_Result').
	version load: 'Example Project'.
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result').
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_POST_DoIt_Result').! !

!MetacelloConfigAPIToolBoxTestCase methodsFor: 'test project' stamp: 'DaleHenrichs 12/21/2010 12:40'!
testProjectPreloadPostload
	| project versionSpec version |
	project := self project.

	versionSpec := (version := project version: '1.2.7-baseline') spec.
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result').
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_POST_DoIt_Result').
	version load: 'Example Project'.
	self assert: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result').
	self assert: (Smalltalk at: #'Metacello_Configuration_Test_POST_DoIt_Result').! !

TestCase subclass: #MetacelloGoferPackageTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloGoferPackageTestCase methodsFor: 'tests' stamp: 'dkh 1/13/2010 16:29'!
testClassMatch

	self assert: 
		(MetacelloGoferPackage 
			packageFileName: 'JQuery-Core.gemstone' 
			matchesPackageName: 'JQuery-Core').
	self assert: 
		(MetacelloGoferPackage 
			packageFileName: 'JQuery-Core.gemstone-dkh.100' 
			matchesPackageName: 'JQuery-Core').
	self assert: 
		(MetacelloGoferPackage 
			packageFileName: 'Sport-2.031' 
			matchesPackageName: 'Sport').
! !

!MetacelloGoferPackageTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 3/15/2010 14:05'!
testInstanceMatch01

	self assert: 
		((MetacelloGoferPackage name: 'Faux-Smalltalk' packageFilename: 'Faux-Smalltalk-')
			matches: (GoferVersionReference name: 'Faux-Smalltalk-tg.34')).
	self deny: 
		((MetacelloGoferPackage name: 'Faux-Smalltalk' packageFilename: 'Faux-Smalltalk-')
			matches: (GoferVersionReference name: 'Faux-SmalltalkTesting-tg.34')).
! !

!MetacelloGoferPackageTestCase methodsFor: 'tests' stamp: 'dkh 2/22/2011 18:09'!
testInstanceMatch02

	self deny: 
		((MetacelloGoferPackage name: 'GoferBar' packageFilename: 'GoferBar.branch-lr.2')
			matches: (GoferVersionReference name: 'GoferBar-jf.1')).
! !

!MetacelloGoferPackageTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 3/15/2010 14:29'!
testInstanceMatch03

	self assert: 
		((MetacelloGoferPackage name: 'Faux-Smalltalk' packageFilename: 'Faux-Smalltalk-')
			matches: (GoferVersionReference name: 'Faux-Smalltalk-Testing-tg.34')).
! !

!MetacelloGoferPackageTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 3/15/2010 14:33'!
testInstanceMatch04

	self deny: 
		((MetacelloGoferPackage name: 'ConfigurationOfMagritte' packageFilename: 'ConfigurationOfMagritte')
			matches: (GoferVersionReference name: 'ConfigurationOfMagritte2-dkh.137')).
! !

!MetacelloGoferPackageTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 3/19/2010 10:05'!
testInstanceMatch05

	self assert: 
		((MetacelloGoferPackage name: 'Seaside2' packageFilename: 'Seaside2.8')
			 matches: (GoferVersionReference name: 'Seaside2.8a1-lr.597')).
! !

TestCase subclass: #MetacelloHTTPRepositoryLoadTestCase
	instanceVariableNames: 'gofer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'assertions' stamp: 'dkh 10/18/2009 10:33'!
assertClass: aClassSymbol
	self assert: (Smalltalk hasClassNamed: aClassSymbol)! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'assertions' stamp: 'dkh 10/18/2009 10:33'!
assertClass: aClassSymbol selector: aMethodSymbol
	self assertClass: aClassSymbol.
	self assert: ((Smalltalk at: aClassSymbol) includesSelector: aMethodSymbol)! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'baselines' stamp: 'dkh 10/18/2009 10:25'!
baseline: spec 
	<version: 'default'>

	spec
		for: #common
		do: [spec
				project: 'Bogus Project'
				with: [
					spec className: 'BogusConfiguration';
						 file: 'BogusConfiguration';
						 version: 'default';
						 repository: 'http://seaside.gemstone.com/ss/bogus']]! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'baselines' stamp: 'TestRunner 10/22/2009 10:21'!
baselineAuthentication: spec 
	<version: 'authentication'>

	spec
		for: #common
		do: [spec
				project: 'Bogus Project'
				with: [
					spec className: 'BogusConfiguration';
						 file: 'BogusConfiguration';
						 version: 'default';
						 repository: 'http://seaside.gemstone.com/ss/authenticationRequired' username: 'foo' password: 'bar']]! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'accessing' stamp: 'TestRunner 10/22/2009 10:20'!
enabled
	"return true to actually run tests ... don't need to test loading all of the time ...
	 before enabling this, see #testAuthentication"
	
	^false! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'utilities' stamp: 'dkh 10/18/2009 10:33'!
hasPackage: aString
	| package |
	package := MCWorkingCopy allManagers
		detect: [ :each | each packageName = aString ]
		ifNone: [ nil ].
	^ package notNil! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'accessing' stamp: 'dkh 10/18/2009 09:27'!
project

	^(MetacelloVersionConstructor on: self) project
! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'running' stamp: 'dkh 12/15/2009 11:03'!
setUp

	super setUp.
	gofer := Gofer new.
	gofer 
		gemsource: 'bogus'; 
		package: 'BogusConfiguration';
		package: 'Bogus';
		package: 'BogusExt'
		! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'running' stamp: 'DaleHenrichs 12/18/2010 14:27'!
tearDown

	super tearDown.
	[ gofer metacelloUnload ]
		on: Error
		do: [ :err | "assume it is not there" ]! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 10:20'!
testAuthentication
	"test _should_ fail because you are not authorized to access the repository...
	 to test with your own private repository copy the package BogusConfiguration from
	 http://seaside.gemstone.com/ss/bogus to your repository and edit the #baselineAuthentication:
	 appropriately. "

	self enabled ifFalse: [ ^self ].
	(self project version: 'authentication') load.
	self assert: (self hasPackage: 'Bogus'); assertClass: #BogusA.
	self assert: (self hasPackage: 'BogusExt'); assertClass: #BogusA selector: #isFake.
! !

!MetacelloHTTPRepositoryLoadTestCase methodsFor: 'tests' stamp: 'dkh 12/30/2009 10:22'!
testLoad

	self enabled ifFalse: [ ^self ].
	(self project version: 'default') load.
	self assert: (self hasPackage: 'Bogus'); assertClass: #BogusA.
	self assert: (self hasPackage: 'BogusExt'); assertClass: #BogusA selector: #isFake.
! !

TestCase subclass: #MetacelloImportsTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloImportsTestCase methodsFor: 'baselines' stamp: 'dkh 10/24/2009 14:46'!
baseline10beta0: spec 
	<version: '1.0-beta.0-baseline'>
	spec
		for: #common
		do: [
			spec
				package: 'Metacello-Core'
				with: [spec includes: #('Metacello-MC' 'Metacello-Platform' )];
				
				package: 'Metacello-MC';
				
				package: 'Metacello-Platform'
				with: [spec requires: #('Metacello-MC' )]].
! !

!MetacelloImportsTestCase methodsFor: 'baselines' stamp: 'dkh 10/24/2009 14:46'!
baseline10beta3: spec 
	<version: '1.0-beta.3-baseline' imports: #('1.0-beta.0-baseline')>
	spec
		for: #common
		do: [
			spec
				package: 'Metacello-TestsCore'
				with: [spec requires: #('Metacello-Core' )];
				
				package: 'Metacello-Tutorial'
				with: [spec requires: #('Metacello-Core' )];
				
				package: 'Metacello-TutorialTests'
				with: [spec requires: #('Metacello-Tutorial' )]]! !

!MetacelloImportsTestCase methodsFor: 'accessing' stamp: 'dkh 10/17/2009 09:41'!
project

	| constructor project |
	"Construct Metacello project"
	constructor := MetacelloVersionConstructor on: self.
	project := constructor project.
	project loader: MetacelloNullRecordingMCSpecLoader new.
	^project! !

!MetacelloImportsTestCase methodsFor: 'tests' stamp: 'dkh 10/17/2009 10:09'!
testBaseline10beta0

	| project loadedPackages version loader |
	project := self project.

	version := project version: '1.0-beta.0-baseline'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 3.
	self assert: (loadedPackages indexOf: 'Metacello-Core') > 0.
	self assert: (loadedPackages indexOf: 'Metacello-MC') >
						(loadedPackages indexOf: 'Metacello-Core').
	self assert: (loadedPackages indexOf: 'Metacello-Platform') >
						(loadedPackages indexOf: 'Metacello-Core').
! !

!MetacelloImportsTestCase methodsFor: 'tests' stamp: 'dkh 10/17/2009 10:08'!
testBaseline10beta3

	| project loadedPackages version loader |
	project := self project.

	version := project version: '1.0-beta.3-baseline'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 6.
	self assert: (loadedPackages indexOf: 'Metacello-Core') > 0.
	self assert: (loadedPackages indexOf: 'Metacello-MC') >
						(loadedPackages indexOf: 'Metacello-Core').
	self assert: (loadedPackages indexOf: 'Metacello-Platform') >
						(loadedPackages indexOf: 'Metacello-Core').
	self assert: (loadedPackages indexOf: 'Metacello-TestsCore') >
						(loadedPackages indexOf: 'Metacello-Core').
	self assert: (loadedPackages indexOf: 'Metacello-Tutorial') >
						(loadedPackages indexOf: 'Metacello-Core').
	self assert: (loadedPackages indexOf: 'Metacello-TutorialTests') >
						(loadedPackages indexOf: 'Metacello-Tutorial').
! !

!MetacelloImportsTestCase methodsFor: 'tests' stamp: 'dkh 1/7/2010 19:06'!
testVersion10beta3

	| project loadedPackages version loader |
	project := self project.

	version := project version: '1.0-beta.3'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 6.
	self assert: (loadedPackages indexOf: 'Metacello-Core') > 0.
	self assert: (loadedPackages indexOf: 'Metacello-MC') >
						(loadedPackages indexOf: 'Metacello-Core').
	self assert: (loadedPackages indexOf: 'Metacello-Platform') >
						(loadedPackages indexOf: 'Metacello-Core').
	self assert: (loadedPackages indexOf: 'Metacello-TestsCore') >
						(loadedPackages indexOf: 'Metacello-Core').
	self assert: (loadedPackages indexOf: 'Metacello-Tutorial') >
						(loadedPackages indexOf: 'Metacello-Core').
	self assert: (loadedPackages indexOf: 'Metacello-TutorialTests') >
						(loadedPackages indexOf: 'Metacello-Tutorial').
! !

!MetacelloImportsTestCase methodsFor: 'tests' stamp: 'dkh 1/7/2010 19:18'!
testVersion10beta3Extra

	| project loadedPackages version loader |
	project := self project.

	version := project version: '1.0-beta.3-extra'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 6.
	self assert: (loadedPackages indexOf: 'Metacello-Core-dkh.1') > 0.
	self assert: (loadedPackages indexOf: 'Metacello-MC-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Core-dkh.1').
	self assert: (loadedPackages indexOf: 'Metacello-Platform-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Core-dkh.1').
	self assert: (loadedPackages indexOf: 'Metacello-TestsCore-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Core-dkh.1').
	self assert: (loadedPackages indexOf: 'Metacello-Tutorial-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Core-dkh.1').
	self assert: (loadedPackages indexOf: 'Metacello-TutorialTests-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Tutorial-dkh.1').
! !

!MetacelloImportsTestCase methodsFor: 'tests' stamp: 'dkh 1/7/2010 19:09'!
testVersion10beta3ImportedVersions
	| project version |
	project := self project.

	version := project version: '1.0-beta.3-baseline'.
	self assert: version importedVersions size = 1.
	self assert: (version importedVersions includes: '1.0-beta.0-baseline').

	version := project version: '1.0-beta.3'.
	self assert: version importedVersions size = 1.
	self assert: (version importedVersions includes: '1.0-beta.3-baseline').
! !

!MetacelloImportsTestCase methodsFor: 'tests' stamp: 'dkh 1/7/2010 19:19'!
testVersion10beta4

	| project loadedPackages version loader |
	project := self project.

	version := project version: '1.0-beta.4'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 6.
	self assert: (loadedPackages indexOf: 'Metacello-Core-dkh.1') > 0.
	self assert: (loadedPackages indexOf: 'Metacello-MC-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Core-dkh.1').
	self assert: (loadedPackages indexOf: 'Metacello-Platform-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Core-dkh.1').
	self assert: (loadedPackages indexOf: 'Metacello-TestsCore-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Core-dkh.1').
	self assert: (loadedPackages indexOf: 'Metacello-Tutorial-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Core-dkh.1').
	self assert: (loadedPackages indexOf: 'Metacello-TutorialTests-dkh.1') >
						(loadedPackages indexOf: 'Metacello-Tutorial-dkh.1').
! !

!MetacelloImportsTestCase methodsFor: 'tests' stamp: 'dkh 1/7/2010 19:22'!
testVersion10beta4ImportedVersions

	| project loadedPackages version loader |
	project := self project.

	version := project version: '1.0-beta.4'.
	self assert: version importedVersions size = 2.
	self assert: (version importedVersions includes: '1.0-beta.3').
	self assert: (version importedVersions includes: '1.0-beta.3-extra').
! !

!MetacelloImportsTestCase methodsFor: 'versions' stamp: 'dkh 10/14/2009 09:12'!
version10beta3: spec 
	<version: '1.0-beta.3' imports: #('1.0-beta.3-baseline')>
	spec
		for: #common
		do: [ spec blessing: #development].
! !

!MetacelloImportsTestCase methodsFor: 'versions' stamp: 'dkh 1/7/2010 19:16'!
version10beta3Extra: spec 
	<version: '1.0-beta.3-extra' imports: #('1.0-beta.3-baseline')>
	spec
		for: #common
		do: [
			spec
				package: 'Metacello-Core' with: 'Metacello-Core-dkh.1';
				package: 'Metacello-MC' with: 'Metacello-MC-dkh.1';
				package: 'Metacello-Platform' with: 'Metacello-Platform-dkh.1';
				package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
				package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.1';
				package: 'Metacello-TutorialTests' with: 'Metacello-TutorialTests-dkh.1' ].
! !

!MetacelloImportsTestCase methodsFor: 'versions' stamp: 'dkh 1/7/2010 19:19'!
version10beta4: spec 
	<version: '1.0-beta.4' imports: #('1.0-beta.3' '1.0-beta.3-extra' )>
	spec
		for: #common
		do: [ spec blessing: #release].
! !

TestCase subclass: #MetacelloIssue108TestCase
	instanceVariableNames: 'tempRepositories'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloIssue108TestCase methodsFor: 'baselines' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Repository'.
		spec 
			package: 'GoferBar';
			yourself ].
! !

!MetacelloIssue108TestCase methodsFor: 'baselines' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline20: spec 
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Repository'.
		spec 
			package: 'GoferBar' with: [
				spec file: 'GoferBar.gemstone' ];
			yourself ].
! !

!MetacelloIssue108TestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
expectedFailures

	true ifTrue: [ ^#() ].
	^#(
		testMore "place holder to complete test coverage"
	)! !

!MetacelloIssue108TestCase methodsFor: 'utilities' stamp: 'dkh 7/23/2012 19:15'!
hasPackage: aString
	| package |
	package := MCWorkingCopy allManagers
		detect: [ :each | each packageName = aString ]
		ifNone: [ nil ].
	^ package notNil! !

!MetacelloIssue108TestCase methodsFor: 'accessing' stamp: 'dkh 6/12/2012 15:41:23.319'!
project

	| constructor project |
	"Construct Metacello project"
	constructor := MetacelloVersionConstructor on: self.
	project := constructor project.
	project loader: 
		((project loaderClass new)
			shouldDisablePackageCache: true;
			yourself).
	project loadType: #linear.
	^project! !

!MetacelloIssue108TestCase methodsFor: 'private' stamp: 'dkh 6/12/2012 15:41:23.319'!
repositoryName

	^#'Metacello_Repository'! !

!MetacelloIssue108TestCase methodsFor: 'running' stamp: 'dkh 6/12/2012 15:41:23.319'!
runCase
	| original |
	original := MetacelloPlatform current bypassGoferLoadUpdateCategories.
	[ 
	MetacelloPlatform current bypassGoferLoadUpdateCategories: true.
	^ SystemChangeNotifier uniqueInstance doSilently: [ super runCase ] ]
		ensure: [ MetacelloPlatform current bypassGoferLoadUpdateCategories: original ]! !

!MetacelloIssue108TestCase methodsFor: 'running' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUp
	| repo  |
	super setUp.
	repo := MetacelloIssue108Resource current monticelloRepository.
	self tempRepositories add: repo.
	Smalltalk at: self repositoryName put: repo.
! !

!MetacelloIssue108TestCase methodsFor: 'running' stamp: 'dkh 7/23/2012 19:21'!
tearDown
    | aGofer |
    super tearDown.
    Smalltalk removeKey: self repositoryName ifAbsent: [  ].
    self tempRepositories do: [ :repo | MCRepositoryGroup default removeRepository: repo ].
    aGofer := Gofer new.
    self tearDownPackageNames
        do: [ :pName | 
            (self hasPackage: pName)
                ifTrue: [ aGofer package: pName ] ].
    aGofer references notEmpty
        ifTrue: [ aGofer metacelloUnload ]! !

!MetacelloIssue108TestCase methodsFor: 'running' stamp: 'dkh 7/23/2012 19:16'!
tearDownPackageNames
    ^ #('GoferBar')! !

!MetacelloIssue108TestCase methodsFor: 'accessing' stamp: 'dkh 6/12/2012 15:41:23.319'!
tempRepositories

	tempRepositories ifNil: [ tempRepositories := OrderedCollection new ].
	^tempRepositories! !

!MetacelloIssue108TestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testBaseline10
	| wc project loader |
	project := self class new project.
	loader := project load: '1.0-baseline'.
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-dkh.70').
! !

!MetacelloIssue108TestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testBaseline20
	| wc project loader |
	project := self class new project.
	loader := project load: '2.0-baseline'.
	wc := (GoferVersionReference name: 'GoferBar.gemstone') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar.gemstone-dkh.70').
! !

!MetacelloIssue108TestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testLatestPackage
	"illustrate different behavior for GoferPackageReference, GoferVersionReference and MetacelloGoferPackage"
	
	| gofer repositorySpecs aString |
	gofer := Gofer new.
	gofer disablePackageCache.
	gofer repository: (Smalltalk at: self repositoryName).

	"GoferPackageReference"
	self assert: 'GoferBar-dkh.70' = ((GoferPackageReference name: 'GoferBar') resolveWith: gofer) name.
	self should: [ (GoferPackageReference name: 'GoferBar.gemstone') resolveWith: gofer ] raise: Error.

	"GoferVersionReference"
	self should: [ (GoferVersionReference name: 'GoferBar') resolveWith: gofer ] raise: Error.
	self should: [ (GoferVersionReference name: 'GoferBar.gemstone') resolveWith: gofer ] raise: Error.

	"MetacelloGoferPackage"
	self assert: 'GoferBar-dkh.70' = ((MetacelloGoferPackage name: 'GoferBar' packageFilename: 'GoferBar') resolveWith: gofer) name.
	self assert: 'GoferBar.gemstone-dkh.70' = ((MetacelloGoferPackage name: 'GoferBar' packageFilename: 'GoferBar.gemstone') resolveWith: gofer) name! !

TestCase subclass: #MetacelloIssue115TestCase
	instanceVariableNames: 'gofer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloIssue115TestCase methodsFor: 'running' stamp: 'dkh 3/21/2011 15:41'!
configurationRepository
	"MetacelloConfigurationResource reset"

	^ MetacelloConfigurationResource current monticelloRepository! !

!MetacelloIssue115TestCase methodsFor: 'utilities' stamp: 'dkh 3/22/2011 14:58'!
hasPackage: aString
	| package |
	package := MCWorkingCopy allManagers
		detect: [ :each | each packageName = aString ]
		ifNone: [ nil ].
	^ package notNil! !

!MetacelloIssue115TestCase methodsFor: 'accessing' stamp: 'dkh 3/21/2011 15:41'!
monticelloRepository
	"MetacelloMonticelloResource reset"
	^ MetacelloMonticelloResource current monticelloRepository! !

!MetacelloIssue115TestCase methodsFor: 'accessing' stamp: 'dkh 3/22/2011 14:57'!
project

	^self projectWith: #()! !

!MetacelloIssue115TestCase methodsFor: 'accessing' stamp: 'dkh 3/21/2011 15:50'!
projectClass

	^(Smalltalk at: #MetacelloTestConfigurationOfProjectIssue115)! !

!MetacelloIssue115TestCase methodsFor: 'accessing' stamp: 'dkh 3/21/2011 15:51'!
projectWith: projectAttributes

	| project |
	"Construct Metacello project"
	project := MetacelloMCProject new.
	project projectAttributes: projectAttributes.
	MetacelloVersionConstructor on: self  projectClass new project: project.
	project loader: MetacelloNullRecordingMCSpecLoader new.
	project loader evalDoits: true.
	^project! !

!MetacelloIssue115TestCase methodsFor: 'running' stamp: 'dkh 3/21/2011 15:41'!
runCase
	| original |
	original := MetacelloPlatform current bypassGoferLoadUpdateCategories.
	[ 
	MetacelloPlatform current bypassGoferLoadUpdateCategories: true.
	^ SystemChangeNotifier uniqueInstance doSilently: [ super runCase ] ]
		ensure: [ MetacelloPlatform current bypassGoferLoadUpdateCategories: original ]! !

!MetacelloIssue115TestCase methodsFor: 'running' stamp: 'dkh 3/22/2011 14:49'!
setUp
	| repo |
	super setUp.
	repo := self monticelloRepository.
	gofer := Gofer new.
	gofer disablePackageCache.
	gofer repository: repo.
	Smalltalk at: #'Metacello_Gofer_Test_Repository' put: repo.
	repo := self configurationRepository.
	gofer repository: repo.
	Smalltalk at: #'Metacello_Configuration_Test_Repository' put: repo.
! !

!MetacelloIssue115TestCase methodsFor: 'running' stamp: 'dkh 3/21/2011 15:44'!
tearDown
	| aGofer |
	super tearDown.
	aGofer := Gofer new.
	(self hasPackage: 'MetacelloTestConfigurationOfProjectIssue115')
		ifTrue: [ aGofer package: 'MetacelloTestConfigurationOfProjectIssue115' ].
	aGofer references notEmpty ifTrue: [ aGofer metacelloUnload ].
	Smalltalk removeKey: #'Metacello_Gofer_Test_Repository' ifAbsent: [].
	Smalltalk removeKey: #'Metacello_Configuration_Test_Repository' ifAbsent: [].
! !

!MetacelloIssue115TestCase methodsFor: 'tests' stamp: 'dkh 3/22/2011 14:54'!
testIssue115a
	| project versionSpec version validations |
	gofer version: 'MetacelloTestConfigurationOfProjectIssue115-dkh.1'.
	gofer metacelloLoad.
	project := self project.
	self shouldnt: [versionSpec := (version := project version: '1.0') spec] raise: Error.
	validations := MetacelloToolBox validateConfiguration: self projectClass.
	self assert: validations size = 1.
	validations detect: [ :validation | validation reasonCode == #cannotResolveVersion ] ifNone: [ self assert: false ]! !

!MetacelloIssue115TestCase methodsFor: 'tests' stamp: 'dkh 3/22/2011 14:55'!
testIssue115b
	| project versionSpec version validations |
	gofer version: 'MetacelloTestConfigurationOfProjectIssue115-dkh.2'.
	gofer metacelloLoad.
	project := self project.
	self shouldnt: [versionSpec := (version := project version: '1.1') spec] raise: Error.
	validations := MetacelloToolBox validateConfiguration: self projectClass.
	self assert: validations size = 2.
	validations do: [ :validation | self assert: validation reasonCode == #cannotResolveVersion ]! !

TestCase subclass: #MetacelloIssue136TestCase
	instanceVariableNames: 'gofer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloIssue136TestCase methodsFor: 'running' stamp: 'dkh 9/7/2011 14:51'!
configurationRepository
	"MetacelloConfigurationResource reset"

	^ MetacelloConfigurationResource current monticelloRepository! !

!MetacelloIssue136TestCase methodsFor: 'utilities' stamp: 'dkh 9/7/2011 14:51'!
hasPackage: aString
	| package |
	package := MCWorkingCopy allManagers
		detect: [ :each | each packageName = aString ]
		ifNone: [ nil ].
	^ package notNil! !

!MetacelloIssue136TestCase methodsFor: 'accessing' stamp: 'dkh 9/7/2011 14:51'!
monticelloRepository
	"MetacelloMonticelloResource reset"
	^ MetacelloMonticelloResource current monticelloRepository! !

!MetacelloIssue136TestCase methodsFor: 'accessing' stamp: 'dkh 9/7/2011 14:51'!
project

	^self projectWith: #()! !

!MetacelloIssue136TestCase methodsFor: 'accessing' stamp: 'dkh 9/7/2011 14:52'!
projectClass

	^(Smalltalk at: #MetacelloTestConfigurationOfProjectIssue136)! !

!MetacelloIssue136TestCase methodsFor: 'accessing' stamp: 'dkh 9/7/2011 14:51'!
projectWith: projectAttributes

	| project |
	"Construct Metacello project"
	project := MetacelloMCProject new.
	project projectAttributes: projectAttributes.
	MetacelloVersionConstructor on: self  projectClass new project: project.
	project loader: MetacelloNullRecordingMCSpecLoader new.
	project loader evalDoits: true.
	^project! !

!MetacelloIssue136TestCase methodsFor: 'running' stamp: 'dkh 9/7/2011 14:51'!
runCase
	| original |
	original := MetacelloPlatform current bypassGoferLoadUpdateCategories.
	[ 
	MetacelloPlatform current bypassGoferLoadUpdateCategories: true.
	^ SystemChangeNotifier uniqueInstance doSilently: [ super runCase ] ]
		ensure: [ MetacelloPlatform current bypassGoferLoadUpdateCategories: original ]! !

!MetacelloIssue136TestCase methodsFor: 'running' stamp: 'dkh 9/7/2011 14:51'!
setUp
	| repo |
	super setUp.
	repo := self monticelloRepository.
	gofer := Gofer new.
	gofer disablePackageCache.
	gofer repository: repo.
	Smalltalk at: #'Metacello_Gofer_Test_Repository' put: repo.
	repo := self configurationRepository.
	gofer repository: repo.
	Smalltalk at: #'Metacello_Configuration_Test_Repository' put: repo.
! !

!MetacelloIssue136TestCase methodsFor: 'running' stamp: 'dkh 9/7/2011 14:52'!
tearDown
	| aGofer |
	super tearDown.
	aGofer := Gofer new.
	(self hasPackage: 'MetacelloTestConfigurationOfProjectIssue136')
		ifTrue: [ aGofer package: 'MetacelloTestConfigurationOfProjectIssue136' ].
	aGofer references notEmpty ifTrue: [ aGofer metacelloUnload ].
	Smalltalk removeKey: #'Metacello_Gofer_Test_Repository' ifAbsent: [].
	Smalltalk removeKey: #'Metacello_Configuration_Test_Repository' ifAbsent: [].
! !

!MetacelloIssue136TestCase methodsFor: 'tests' stamp: 'dkh 9/7/2011 15:37'!
testCachedIssue136

	self 
		shouldnt: [
			MetacelloPlatform current
				stackCacheFor: #issue136
				at: #testing
				doing: [:cache | self testIssue136 ]] 
		raise: MetacelloProjectSpecLoadError! !

!MetacelloIssue136TestCase methodsFor: 'tests' stamp: 'dkh 9/7/2011 15:29'!
testIssue136

	| project projectReferenceProject configurationName projectBaseName projectSpec projectPackage |
	gofer version: 'MetacelloTestConfigurationOfProjectIssue136-dkh.1'.
	gofer metacelloLoad.
	project := self project.
	configurationName := 'MetacelloTestConfigurationOfProjectIssue136'.
	projectBaseName := 'Issue136'.
	projectReferenceProject := (MetacelloPlatform current globalNamed: configurationName asSymbol ifAbsent: [ self assert: false ]) project.
	projectPackage := projectReferenceProject projectPackage.
	projectPackage repository: 'dictionary://Metacello_Configuration_Test_Repository'.
	projectSpec := (project projectSpec)
						name: projectBaseName;
						className: configurationName;
						versionString: '1.0';
						projectPackage: projectPackage;
						repository: 'dictionary://Metacello_Configuration_Test_Repository';
		yourself.
	projectSpec load.
	projectReferenceProject := (MetacelloPlatform current globalNamed: configurationName asSymbol ifAbsent: [ self assert: false ]) project.
	projectPackage := projectReferenceProject projectPackage.
	projectPackage repository: 'dictionary://Metacello_Configuration_Test_Repository'.
	projectPackage file: 'MetacelloTestConfigurationOfProjectIssue136-dkh.2'.
	projectSpec := (project projectSpec)
						name: projectBaseName;
						className: configurationName;
						versionString: '1.1';
						projectPackage: projectPackage;
						repository: 'dictionary://Metacello_Configuration_Test_Repository';
		yourself.
	projectSpec load! !

TestCase subclass: #MetacelloLoadOrderTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloLoadOrderTestCase methodsFor: 'baselines' stamp: 'dkh 10/24/2009 14:46'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core';
			package: 'Example-AddOn' with: [ spec requires: #('Example-Core' ) ];
			package: 'Example-Tests' with: [ spec requires: #('Example-AddOn' ) ];
			package: 'Example-TestsUI' with: [ spec requires: #('Example-UI' 'Example-Tests' ) ];
			package: 'Example-UI' with: [ spec requires: #('Example-AddOn' ) ]].
! !

!MetacelloLoadOrderTestCase methodsFor: 'baselines' stamp: 'dkh 10/24/2009 14:47'!
baseline11: spec 
	<version: '1.1-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core' with: [ spec includes: #('Example-AddOn' ) ];
			package: 'Example-Tests' with: [ spec requires: #('Example-Core' ) ];
			package: 'Example-AddOn' with: [ spec requires: #('Example-Core' ) ];
			package: 'Example-TestsUI' with: [ spec requires: #('Example-UI' 'Example-Tests' ) ];
			package: 'Example-UI' with: [ spec requires: #('Example-AddOn' ) ]].
! !

!MetacelloLoadOrderTestCase methodsFor: 'baselines' stamp: 'dkh 10/24/2009 14:47'!
baseline12: spec 
	<version: '1.2-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core';
			package: 'Example-AddOn' with: [ spec requires: #('Example-Core' ) ];
			package: 'Example-Tests' with: [ spec requires: #('Example-AddOn' ) ];
			package: 'Example-TestsUI' with: [ spec requires: #('Example-UI' 'Example-Tests' ) ];
			package: 'Example-UI' with: [ spec requires: #('Example-AddOn' ) ].
		spec
			group: 'Core' with: #('Example-Core' 'Example-AddOn' );
			group: 'Tests' with: #('Example-Tests' 'Example-TestsUI' );
			group: 'No UI' with: #('Core' 'Example-Tests' ).].
! !

!MetacelloLoadOrderTestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 5/24/2010 12:10'!
baseline13: spec 
	<version: '1.3-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core';
			package: 'Example-AddOn' with: [ spec requires: #('Example-Core' ) ];
			package: 'Example-Tests' with: [ spec requires: #('Example-AddOn' ) ];
			package: 'Example-TestsUI' with: [ spec requires: #('Example-UI' 'Example-Tests' ) ];
			package: 'Example-UI' with: [ spec requires: #('Example-AddOn' ) ].
		spec
			group: 'Core' with: #('Example-Core' 'Example-AddOn' );
			group: 'Tests' with: #('Example-Tests' 'Example-TestsUI' );
			group: 'No UI' with: #('Core' 'Example-Tests' ).
		spec package: 'Example-Group-Test' with: [ spec requires: #('Tests') ]].
! !

!MetacelloLoadOrderTestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 7/23/2010 13:51'!
baseline14: spec 
	<version: '1.4-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core' with: [
				spec includes: #('Example-GemStone-Core') ];

			package: 'Example-2' with: [
				spec requires: #('Example-Core') ];
			package: 'Example-3' with: [
				spec requires: #('Example-Core') ];
			package: 'Example-Core';
			package: 'Example-1' with: [
				spec requires: #('Example-Core') ];

			package: 'Example-GemStone300-Core' with: [
				spec 
					requires: #('Example-Core');
					includes: #('Example-GemStone-Core') ];

			package: 'Example-GemStone-Core' with: [
				spec requires: #('Example-Core') ];
			package: 'Example-Core' with: [
				spec includes: #('Example-GemStone300-Core') ];
		yourself.]! !

!MetacelloLoadOrderTestCase methodsFor: 'baselines' stamp: 'TestRunner 10/24/2009 15:01'!
baseline300alpha5: spec 
	<version: '3.0.0-alpha5-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: '3.0.0 baseline based on 3.0.0-alpha5'.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec
			package: 'Grease-Core';
			package: 'Seaside-Core' with: [ spec requires: #('Grease-Core' ). ];
			package: 'Seaside-Canvas' with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Session' with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' with: [ spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Tools-Core' with: [ 
				spec requires: #('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Session' ). ];
			package: 'Seaside-Widgets' with: [ spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			package: 'Seaside-Environment' with: [ 
				spec requires: 
					#('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component' 'Seaside-RenderLoop'
					  'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Flow' with: [ 
				spec requires: #('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Development' with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' ). ];
			package: 'Seaside-Examples' with: [ 
				spec requires: #('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' with: [ 
				spec requires: #('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [ spec requires: #('Seaside-Tools-Core' ). ];
			package: 'RSS-Core' with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' with: [ spec requires: #('RSS-Core' ). ];
			package: 'Javascript-Core' with: [ spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' with: [ spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' with: [ spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' with: [ spec requires: #('Javascript-Core' ). ];
			package: 'Scriptaculous-Core' with: [ spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' with: [ 
				spec requires: #('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' ). ];
			package: 'Seaside-HTML5' with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Email' with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-FileSystem' with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Slime' with: [ spec requires: #('Grease-Core' ). ];
			
			package: 'Grease-Tests-Core' with: [ spec requires: #('Grease-Core' ). ];
			package: 'Seaside-Tests-Core' with: [ spec requires: #('Seaside-Core' 'Grease-Tests-Core' ). ];
			package: 'Seaside-Tests-UTF8' with: [ spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Session' with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Component' with: [ spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' with: [ 
				spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Environment' with: [ 
				spec requires: 
					#('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop' 
					  'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Functional' with: [ 
				spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Flow' with: [ spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Tools-Web' with: [ 
				spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Development' with: [ 
				spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' ). ];
			package: 'Seaside-Tests-Examples' with: [ 
				spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'RSS-Tests-Core' with: [ spec requires: #('RSS-Core' ). ];
			package: 'Javascript-Tests-Core' with: [ spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' with: [ 
				spec requires: 
					#('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development' 'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' with: [ spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' with: [ 
				spec requires: #('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'Scriptaculous-Tests-Core' with: [ 
				spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' with: [ 
				spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-HTML5' with: [ spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' with: [ 
				spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Email' with: [ spec requires: #('Seaside-Email' 'Seaside-Tools-Core' ) ];
			package: 'Seaside-Tests-FileSystem' with: [ spec requires: #('Seaside-FileSystem' ). ];
			package: 'Seaside-Tests-Slime' with: [ spec requires: #('Seaside-Slime' ). ]].

	spec for: #squeakCommon do: [
		spec
			package: 'Grease-Core' with: [ spec includes: #('Grease-Pharo-Core' ) ];
			package: 'Seaside-Core' with: [ spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Environment' with: [ spec includes: #('Seaside-Pharo-Environment' ) ];
			package: 'Seaside-Flow' with: [ spec includes: #('Seaside-Pharo-Flow' ) ];
			package: 'Seaside-Tools-Web' with: [ spec includes: #('Seaside-Pharo-Tools-Web' ) ];
			package: 'Seaside-Development' with: [ spec includes: #('Seaside-Pharo-Development' ) ];
			package: 'Seaside-Tools-OmniBrowser' with: [ spec includes: #('Seaside-Pharo-Tools-OmniBrowser' ) ];
			package: 'Seaside-Email' with: [ spec includes: #('Seaside-Pharo-Email' ) ];
			package: 'Javascript-Core' with: [ spec includes: #('Javascript-Pharo-Core' ) ];

			package: 'Grease-Tests-Core' with: [ spec includes: #('Grease-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' with: [ spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Functional' with: [ spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			package: 'Seaside-Tests-Flow' with: [ spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Development' with: [ spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			
			package: 'Grease-Pharo-Core' with: [ spec requires: #('Grease-Core' ) ];
			package: 'Seaside-Pharo-Core' with: [ spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-Pharo-Environment' with: [ spec requires: #('Seaside-Environment' ) ];
			package: 'Seaside-Pharo-Continuation' with: [ spec requires: #('Grease-Core' ) ];
			package: 'Seaside-Pharo-Flow' with: [ spec requires: #('Seaside-Flow' 'Grease-Core' 'Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Pharo-Tools-Web' with: [ spec requires: #('Seaside-Tools-Web' ) ];
			package: 'Seaside-Pharo-Development' with: [ spec requires: #('Seaside-Development' ) ];
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-Pharo-Email' with: [ spec requires: #('Seaside-Email' ) ];
			package: 'Comet-Pharo-Core' with: [ spec requires: #('Comet-Core' ) ];

			package: 'Javascript-Pharo-Core' with: [ spec requires: #('Javascript-Core' ) ];
			package: 'DynamicBindings' with: [ spec repository: 'http://www.squeaksource.com/KomHttpServer' ];
			package: 'KomServices' with: [ spec repository: 'http://www.squeaksource.com/KomHttpServer' ];
			package: 'KomHttpServer' with: [ spec repository: 'http://www.squeaksource.com/KomHttpServer' ];
			package: 'Seaside-Adaptors-Comanche' with: [ 
				spec requires: #('Seaside-Core' 'DynamicBindings' 'KomServices' 'KomHttpServer' ) ];
			package: 'Seaside-Adaptors-Swazoo' with: [ spec requires: #('Seaside-Core' 'Seaside-Swazoo' ) ];
			package: 'Comet-Core' with: [ 
				spec includes: #('Comet-Pharo-Core' ).
				spec requires: #('Seaside-Canvas' 'Javascript-Core' ) ];
			package: 'Comet-Examples' with: [ spec requires: #('JQuery-UI' 'Comet-Core' ) ];
			package: 'Seaside-Swazoo' with: [ spec requires: #('Grease-Core' ). ];

			package: 'Grease-Tests-Pharo-Core' with: [ spec requires: #('Grease-Tests-Core' ) ];
			package: 'Seaside-Tests-Pharo-Core' with: [ spec requires: #('Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-Pharo-Functional' with: [ spec requires: #('Seaside-Tests-Functional' ) ];
			package: 'Seaside-Tests-Pharo-Continuation' with: [ 
				spec requires: #('Seaside-Pharo-Continuation' 'Grease-Tests-Core' ) ];
			package: 'Seaside-Tests-Pharo-Development' with: [ spec requires: #('Seaside-Tests-Development' ) ];
			package: 'Seaside-Tests-Adaptors-Comanche' with: [ 
				spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Core' )];
			package: 'Comet-Tests-Core' with: [ spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ]].
! !

!MetacelloLoadOrderTestCase methodsFor: 'accessing' stamp: 'dkh 10/17/2009 09:41'!
project

	| constructor project |
	"Construct Metacello project"
	constructor := MetacelloVersionConstructor on: self.
	project := constructor project.
	project loader: MetacelloNullRecordingMCSpecLoader new.
	^project! !

!MetacelloLoadOrderTestCase methodsFor: 'testing' stamp: 'dkh 10/17/2009 10:10'!
testBaseline10
	| loadedPackages project loader |
	project := self class new project.
	loader := project load: '1.0-baseline'.
	loadedPackages := loader loadedPackages asArray.
	self assert: (loadedPackages indexOf: 'Example-Core')
			> 0.
	self assert: (loadedPackages indexOf: 'Example-AddOn')
			> (loadedPackages indexOf: 'Example-Core').
	self assert: (loadedPackages indexOf: 'Example-Tests')
			> (loadedPackages indexOf: 'Example-AddOn').
	self assert: (loadedPackages indexOf: 'Example-UI')
			> (loadedPackages indexOf: 'Example-AddOn').
	self assert: (loadedPackages indexOf: 'Example-TestsUI')
			> (loadedPackages indexOf: 'Example-UI').
	self assert: (loadedPackages indexOf: 'Example-TestsUI')
			> (loadedPackages indexOf: 'Example-Tests').
! !

!MetacelloLoadOrderTestCase methodsFor: 'testing' stamp: 'dkh 10/17/2009 10:11'!
testBaseline11
	| loadedPackages project loader |
	project := self class new project.
	loader := project load: '1.1-baseline'.
	loadedPackages := loader loadedPackages asArray.
	self assert: (loadedPackages indexOf: 'Example-Core')
			> 0.
	self assert: (loadedPackages indexOf: 'Example-AddOn')
			> (loadedPackages indexOf: 'Example-Core').
	self assert: (loadedPackages indexOf: 'Example-Tests')
			> (loadedPackages indexOf: 'Example-AddOn').
	self assert: (loadedPackages indexOf: 'Example-UI')
			> (loadedPackages indexOf: 'Example-AddOn').
	self assert: (loadedPackages indexOf: 'Example-TestsUI')
			> (loadedPackages indexOf: 'Example-UI').
	self assert: (loadedPackages indexOf: 'Example-TestsUI')
			> (loadedPackages indexOf: 'Example-Tests').
! !

!MetacelloLoadOrderTestCase methodsFor: 'testing' stamp: 'dkh 10/21/2009 11:16'!
testBaseline12
	| loadedPackages project loader |
	project := self class new project.
	loader := (project version: '1.2-baseline') load: 'No UI'.
	loadedPackages := loader loadedPackages asArray.
	self assert: (loadedPackages indexOf: 'Example-Core')
			> 0.
	self assert: (loadedPackages indexOf: 'Example-AddOn')
			> (loadedPackages indexOf: 'Example-Core').
	self assert: (loadedPackages indexOf: 'Example-Tests')
			> (loadedPackages indexOf: 'Example-AddOn').
	self assert: (loadedPackages indexOf: 'Example-UI') = 0.
	self assert: (loadedPackages indexOf: 'Example-TestsUI') = 0.
! !

!MetacelloLoadOrderTestCase methodsFor: 'testing' stamp: 'DaleHenrichs 5/24/2010 12:14'!
testBaseline13
	| loadedPackages project loader |
	project := self class new project.
	loader := (project version: '1.3-baseline') load: 'Example-Group-Test'.
	loadedPackages := loader loadedPackages asArray.
	self assert: (loadedPackages indexOf: 'Example-Core') > 0.
	self assert: (loadedPackages indexOf: 'Example-AddOn')
			> (loadedPackages indexOf: 'Example-Core').
	self assert: (loadedPackages indexOf: 'Example-Tests')
			> (loadedPackages indexOf: 'Example-AddOn').

	self assert: (loadedPackages indexOf: 'Example-UI')
			> (loadedPackages indexOf: 'Example-AddOn').
	self assert: (loadedPackages indexOf: 'Example-TestsUI')
			> (loadedPackages indexOf: 'Example-UI').
	self assert: (loadedPackages indexOf: 'Example-TestsUI')
			> (loadedPackages indexOf: 'Example-Tests').

	self assert: (loadedPackages indexOf: 'Example-Group-Test')
			> (loadedPackages indexOf: 'Example-Tests').
	self assert: (loadedPackages indexOf: 'Example-Group-Test')
			> (loadedPackages indexOf: 'Example-TestsUI').
! !

!MetacelloLoadOrderTestCase methodsFor: 'testing' stamp: 'DaleHenrichs 7/23/2010 12:57'!
testBaseline13a
	| loadedPackages project loader |
	project := self class new project.
	loader := (project version: '1.3-baseline') load: 'Example-Group-Test'.
	loadedPackages := loader loadedPackages asArray.
	self assert: (loadedPackages indexOf: 'Example-Core') > 0.
	self assert: (loadedPackages indexOf: 'Example-AddOn')
			> (loadedPackages indexOf: 'Example-Core').
	self assert: (loadedPackages indexOf: 'Example-Tests')
			> (loadedPackages indexOf: 'Example-AddOn').

	self assert: (loadedPackages indexOf: 'Example-UI')
			> (loadedPackages indexOf: 'Example-AddOn').
	self assert: (loadedPackages indexOf: 'Example-TestsUI')
			> (loadedPackages indexOf: 'Example-UI').
	self assert: (loadedPackages indexOf: 'Example-TestsUI')
			> (loadedPackages indexOf: 'Example-Tests').

	self assert: (loadedPackages indexOf: 'Example-Group-Test')
			> (loadedPackages indexOf: 'Example-Tests').
	self assert: (loadedPackages indexOf: 'Example-Group-Test')
			> (loadedPackages indexOf: 'Example-TestsUI').
! !

!MetacelloLoadOrderTestCase methodsFor: 'testing' stamp: 'DaleHenrichs 7/23/2010 13:55'!
testBaseline14
	"test for http://code.google.com/p/metacello/issues/detail?id=90"
	| loadedPackages project loader |
	project := self class new project.
	loader := (project version: '1.4-baseline') load: #('Example-3' 'Example-2' 'Example-1').
	loadedPackages := loader loadedPackages asArray.

	self assert: (loadedPackages indexOf: 'Example-Core') > 0.

	self assert: (loadedPackages indexOf: 'Example-GemStone300-Core')
			> (loadedPackages indexOf: 'Example-Core').
	self assert: (loadedPackages indexOf: 'Example-GemStone-Core')
			> (loadedPackages indexOf: 'Example-GemStone300-Core').
	self assert: (loadedPackages indexOf: 'Example-3')
			> (loadedPackages indexOf: 'Example-GemStone-Core').
! !

!MetacelloLoadOrderTestCase methodsFor: 'testing' stamp: 'dkh 10/17/2009 10:12'!
testBaseline300alpha5IncludesX
	"make sure that includes: constraints are met"
	"the includes: directive should slave the included package such that included packages are 
	 loaded before any of the packages that require the base package."
	
	| project loadedPackageNames loadedPackageSpecs baseSpecName loader |
	project := self class new project.
	loader := project load: '3.0.0-alpha5-baseline'.
	loadedPackageNames := loader loadedPackages asArray.
	loadedPackageSpecs := loader packages.
	loadedPackageSpecs do: [:baseSpec |
		baseSpecName := baseSpec name.
		"this only applies to packageSpecs, groups are not treated this way"
		baseSpec includes do: [:includedSpecName |
			loadedPackageSpecs do: [:spec |
				(spec requires includes: baseSpecName)
					ifTrue: [
						self assert: 
							((loadedPackageNames indexOf: spec name) >=
								(loadedPackageNames indexOf: includedSpecName)).
						self assert: 
							((loadedPackageNames indexOf: spec name) >
								(loadedPackageNames indexOf: baseSpecName)) ].
				(spec requires includes: includedSpecName)
					ifTrue: [
						self assert: 
							((loadedPackageNames indexOf: spec name) >
								(loadedPackageNames indexOf: includedSpecName)) ]]]].! !

TestCase subclass: #MetacelloMCIssue125TestCase
	instanceVariableNames: 'gofer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloMCIssue125TestCase methodsFor: 'running' stamp: 'dkh 9/11/2012 15:16'!
configurationRepository
	"MetacelloConfigurationResource reset"

	^ MetacelloConfigurationResource current monticelloRepository! !

!MetacelloMCIssue125TestCase methodsFor: 'utilities' stamp: 'dkh 9/11/2012 15:16'!
hasPackage: aString
	| package |
	package := MCWorkingCopy allManagers
		detect: [ :each | each packageName = aString ]
		ifNone: [ nil ].
	^ package notNil! !

!MetacelloMCIssue125TestCase methodsFor: 'accessing' stamp: 'dkh 9/11/2012 15:16'!
monticelloRepository
	"MetacelloMonticelloResource reset"
	^ MetacelloMonticelloResource current monticelloRepository! !

!MetacelloMCIssue125TestCase methodsFor: 'accessing' stamp: 'dkh 9/11/2012 15:16'!
project

	^self projectWith: #()! !

!MetacelloMCIssue125TestCase methodsFor: 'accessing' stamp: 'dkh 9/11/2012 15:16'!
projectClass
    ^ Smalltalk at: self projectName asSymbol! !

!MetacelloMCIssue125TestCase methodsFor: 'accessing' stamp: 'dkh 9/11/2012 15:17'!
projectName
    ^ 'MetacelloTestConfigurationOfProjectIssue125'! !

!MetacelloMCIssue125TestCase methodsFor: 'accessing' stamp: 'dkh 9/11/2012 15:43'!
projectWith: projectAttributes
    | project |
    "Construct Metacello project"
    project := MetacelloMCProject new.
    project projectAttributes: projectAttributes.
    MetacelloVersionConstructor on: self projectClass new project: project.
    ^ project! !

!MetacelloMCIssue125TestCase methodsFor: 'running' stamp: 'dkh 9/11/2012 15:16'!
runCase
	| original |
	original := MetacelloPlatform current bypassGoferLoadUpdateCategories.
	[ 
	MetacelloPlatform current bypassGoferLoadUpdateCategories: true.
	^ SystemChangeNotifier uniqueInstance doSilently: [ super runCase ] ]
		ensure: [ MetacelloPlatform current bypassGoferLoadUpdateCategories: original ]! !

!MetacelloMCIssue125TestCase methodsFor: 'running' stamp: 'dkh 9/11/2012 15:32'!
setUp
    | repo |
    super setUp.
    repo := self monticelloRepository.
    gofer := Gofer new.
    gofer disablePackageCache.
    gofer repository: repo.
    Smalltalk at: #'Metacello_Gofer_Test_Repository' put: repo.
    repo := self configurationRepository.
    gofer repository: repo.
    Smalltalk at: #'Metacello_Configuration_Test_Repository' put: repo.
    gofer version: 'MetacelloTestConfigurationOfProjectIssue125-dkh.1'.
    gofer metacelloLoad! !

!MetacelloMCIssue125TestCase methodsFor: 'running' stamp: 'dkh 9/11/2012 15:16'!
tearDown
    | aGofer |
    super tearDown.
    aGofer := Gofer new.
    self tearDownPackageNames
        do: [ :pName | 
            (self hasPackage: pName)
                ifTrue: [ aGofer package: pName ] ].
    aGofer references notEmpty
        ifTrue: [ aGofer metacelloUnload ].
    Smalltalk removeKey: #'Metacello_Gofer_Test_Repository' ifAbsent: [  ].
    Smalltalk removeKey: #'Metacello_Configuration_Test_Repository' ifAbsent: [  ]! !

!MetacelloMCIssue125TestCase methodsFor: 'running' stamp: 'dkh 9/11/2012 15:18'!
tearDownPackageNames
    ^ {(self projectName).
    'GoferFoo'.
    'GoferBar'.
    'GoferFaux'.
    'GoferBeau'}! !

!MetacelloMCIssue125TestCase methodsFor: 'tests' stamp: 'dkh 9/11/2012 15:44'!
testForDoListAtrribute1Active
    | project version wc |
    project := self projectWith: #(#'attribute1').
    version := project version: '3.0'.
    version load.
    {('GoferFoo' -> 'GoferFoo-lr.4').
    ('GoferBar' -> 'GoferBar-jf.1').
    ('GoferFaux' -> 'GoferFaux-tg.32').
    ('GoferBeau' -> 'GoferBeau-dkh.55')}
        do: [ :assoc | 
            wc := (GoferPackageReference name: assoc key) workingCopy.
            self assert: wc ancestry ancestors first name = assoc value ]! !

!MetacelloMCIssue125TestCase methodsFor: 'tests' stamp: 'dkh 9/11/2012 15:44'!
testForDoListAtrribute2Active
    | project version wc |
    project := self projectWith: #(#'attribute2').
    version := project version: '3.0'.
    version load.
    {('GoferFoo' -> 'GoferFoo-lr.4').
    ('GoferBar' -> 'GoferBar-jf.1').
    ('GoferFaux' -> 'GoferFaux-tg.33').
    ('GoferBeau' -> 'GoferBeau-dkh.56')}
        do: [ :assoc | 
            wc := (GoferPackageReference name: assoc key) workingCopy.
            self assert: wc ancestry ancestors first name = assoc value ]! !

!MetacelloMCIssue125TestCase methodsFor: 'tests' stamp: 'dkh 9/11/2012 15:44'!
testForDoListAttribute1Atrribute2Active
    | project version wc |
    project := self projectWith: #(#'attribute1' #'attribute2').
    version := project version: '3.0'.
    version load.
    {('GoferFoo' -> 'GoferFoo-lr.4').
    ('GoferBar' -> 'GoferBar-jf.1').
    ('GoferFaux' -> 'GoferFaux-tg.33').
    ('GoferBeau' -> 'GoferBeau-dkh.56')}
        do: [ :assoc | 
            wc := (GoferPackageReference name: assoc key) workingCopy.
            self assert: wc ancestry ancestors first name = assoc value ]! !

!MetacelloMCIssue125TestCase methodsFor: 'tests' stamp: 'dkh 9/11/2012 15:44'!
testForDoListAttribute2Atrribute1Active
    | project version wc |
    project := self projectWith: #(#'attribute2' #'attribute1').
    version := project version: '3.0'.
    version load.
    {('GoferFoo' -> 'GoferFoo-lr.4').
    ('GoferBar' -> 'GoferBar-jf.1').
    ('GoferFaux' -> 'GoferFaux-tg.32').
    ('GoferBeau' -> 'GoferBeau-dkh.55')}
        do: [ :assoc | 
            wc := (GoferPackageReference name: assoc key) workingCopy.
            self assert: wc ancestry ancestors first name = assoc value ]! !

!MetacelloMCIssue125TestCase methodsFor: 'tests' stamp: 'dkh 9/11/2012 15:44'!
testForDoListNotActive
    | project version wc |
    project := self projectWith: #().
    version := project version: '3.0'.
    version load.
    {('GoferFoo' -> 'GoferFoo-lr.4').
    ('GoferBar' -> 'GoferBar-jf.1')}
        do: [ :assoc | 
            wc := (GoferPackageReference name: assoc key) workingCopy.
            self assert: wc ancestry ancestors first name = assoc value ]! !

TestCase subclass: #MetacelloPlatformAttributesTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloPlatformAttributesTestCase methodsFor: 'baselines' stamp: 'dkh 10/24/2009 14:48'!
baseline011: spec 
	<version: '0.11-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'FFI project '.
		spec repository: 'source.squeakfoundation.org/FFI'.

		spec 
			package: 'FFI-Kernel';
			package: 'FFI-Examples' with: [
				spec requires: #('FFI-Kernel' ) ];
			package: 'FFI-Tests' with: [
				spec requires: #('FFI-Examples' ) ]].
! !

!MetacelloPlatformAttributesTestCase methodsFor: 'baselines' stamp: 'dkh 10/24/2009 14:49'!
baseline10beta0: spec 
	<version: '1.0-beta.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'GemTools client for Pharo/Squeak'.
		spec repository: 'http://seaside.gemstone.com/ss/GLASSClient'.
		spec 
			package: 'OB-SUnitGUI' with: [
				spec repository: 'http://seaside.gemstone.com/ss/obsunit' ];
			package: 'GemTools-Client' with: [
				spec requires: #('OB-SUnitGUI' ) ];
			package: 'GemTools-Platform' with: [
				spec requires: #('GemTools-Client' ) ]].
! !

!MetacelloPlatformAttributesTestCase methodsFor: 'accessing' stamp: 'dkh 10/14/2009 16:40'!
project

	^self projectWith: #()! !

!MetacelloPlatformAttributesTestCase methodsFor: 'accessing' stamp: 'dkh 10/17/2009 09:41'!
projectWith: projectAttributes

	| project |
	"Construct Metacello project"
	project := MetacelloMCProject new.
	project projectAttributes: projectAttributes.
	MetacelloVersionConstructor on: self project: project.
	project loader: MetacelloNullRecordingMCSpecLoader new.
	^project! !

!MetacelloPlatformAttributesTestCase methodsFor: 'tests' stamp: 'dkh 10/17/2009 10:13'!
testBaseline011
	| project loadedPackages version loader |
	project := self project.

	version := project version: '0.11-baseline'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 3.
	self assert: (loadedPackages indexOf: 'FFI-Kernel') > 0.
	self assert: (loadedPackages indexOf: 'FFI-Examples') >
						(loadedPackages indexOf: 'FFI-Kernel').
	self assert: (loadedPackages indexOf: 'FFI-Tests') >
						(loadedPackages indexOf: 'FFI-Examples').
! !

!MetacelloPlatformAttributesTestCase methodsFor: 'tests' stamp: 'dkh 10/17/2009 10:14'!
testBaseline011Pharo10Beta
	| project loadedPackages version loader |
	project := self projectWith: #(#'pharo1.0Beta').

	version := project version: '0.11-baseline'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 3.
	self assert: (loadedPackages indexOf: 'FFI-Kernel') > 0.
	self assert: (loadedPackages indexOf: 'FFI-Examples') >
						(loadedPackages indexOf: 'FFI-Kernel').
	self assert: (loadedPackages indexOf: 'FFI-Tests') >
						(loadedPackages indexOf: 'FFI-Examples').
! !

!MetacelloPlatformAttributesTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 1/21/2011 09:56'!
testLastVersion
	| project version |
	project := self project.

	version := project lastVersion.
	self assert: version versionString = '1.0-beta.0'! !

!MetacelloPlatformAttributesTestCase methodsFor: 'tests' stamp: 'dkh 10/17/2009 10:14'!
testVersion011
	| project loadedPackages version loader |
	project := self project.

	version := project version: '0.11'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 3.
	self assert: (loadedPackages indexOf: 'FFI-Kernel-ar.8') > 0.
	self assert: (loadedPackages indexOf: 'FFI-Examples-ar.1') >
						(loadedPackages indexOf: 'FFI-Kernel-ar.8').
	self assert: (loadedPackages indexOf: 'FFI-Tests-ar.2') >
						(loadedPackages indexOf: 'FFI-Examples-ar.1').
! !

!MetacelloPlatformAttributesTestCase methodsFor: 'tests' stamp: 'dkh 10/17/2009 10:14'!
testVersion011Pharo10Beta
	| project loadedPackages version loader |
	project := self projectWith: #(#'pharo1.0Beta').

	version := project version: '0.11'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 3.
	self assert: (loadedPackages indexOf: 'FFI-Kernel-ar.11') > 0.
	self assert: (loadedPackages indexOf: 'FFI-Examples-ar.1') >
						(loadedPackages indexOf: 'FFI-Kernel-ar.11').
	self assert: (loadedPackages indexOf: 'FFI-Tests-ar.3') >
						(loadedPackages indexOf: 'FFI-Examples-ar.1').
! !

!MetacelloPlatformAttributesTestCase methodsFor: 'tests' stamp: 'dkh 10/17/2009 10:14'!
testVersion10beta0
	| project loadedPackages version loader |
	project := self project.

	version := project version: '1.0-beta.0'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 3.
	self assert: (loadedPackages indexOf: 'OB-SUnitGUI-dkh.52') >
						(loadedPackages indexOf: 'FFI-Tests-ar.3').
	self assert: (loadedPackages indexOf: 'GemTools-Client.experimental-dkh.493') >
						(loadedPackages indexOf: 'OB-SUnitGUI-dkh.52').
	self assert: (loadedPackages indexOf: 'GemTools-Platform.squeakCommon-dkh.2') >
						(loadedPackages indexOf: 'GemTools-Client.experimental-dkh.493').
! !

!MetacelloPlatformAttributesTestCase methodsFor: 'tests' stamp: 'dkh 10/17/2009 10:15'!
testVersion10beta0Pharo10Beta
	| project loadedPackages version loader |
	project := self projectWith: #(#'pharo1.0Beta').

	version := project version: '1.0-beta.0'.

	loader := version load.
	loadedPackages := loader loadedPackages asArray. 
	self assert: loadedPackages size = 3.
	self assert: (loadedPackages indexOf: 'OB-SUnitGUI-dkh.52') >
						(loadedPackages indexOf: 'FFI-Tests-ar.3').
	self assert: (loadedPackages indexOf: 'GemTools-Client.experimental-dkh.493') >
						(loadedPackages indexOf: 'OB-SUnitGUI-dkh.52').
	self assert: (loadedPackages indexOf: 'GemTools-Platform.pharo10beta-dkh.2') >
						(loadedPackages indexOf: 'GemTools-Client.experimental-dkh.493').
! !

!MetacelloPlatformAttributesTestCase methodsFor: 'versions' stamp: 'dkh 10/16/2009 13:39'!
version011: spec 
	<version: '0.11' imports: #('0.11-baseline' )>
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'FFI project ... used by GemTools for Pharo 1.0beta #10440'.
		spec 
			package: 'FFI-Kernel' with: 'FFI-Kernel-ar.8';
			package: 'FFI-Examples' with: 'FFI-Examples-ar.1';
			package: 'FFI-Tests' with: 'FFI-Tests-ar.2' ].
	spec for: #'pharo1.0Beta' do: [
		spec 
			package: 'FFI-Kernel' with: 'FFI-Kernel-ar.11';
			package: 'FFI-Tests' with: 'FFI-Tests-ar.3' ].
! !

!MetacelloPlatformAttributesTestCase methodsFor: 'versions' stamp: 'dkh 10/16/2009 13:39'!
version10beta0: spec 
	<version: '1.0-beta.0' imports: #('1.0-beta.0-baseline' )>
	
	spec for: #common do: [
		spec blessing: #beta.
		spec description: 'GemTools client for Pharo/Squeak'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Client' with: 'GemTools-Client.experimental-dkh.493';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.2' ].
	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-dkh.2' ].
! !

TestCase subclass: #MetacelloToolBoxAPITestCase
	instanceVariableNames: 'tempRepositories'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 6/12/2012 15:41:23.319'!
alternatRepositoryName

	^#'Metacello_Dev_Cycle_Alternate_Repository'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 9/12/2012 09:51'!
baseline10Issue125AddSourceString
    ^ 'baseline100: spec
	<version: ''1.0-baseline''>

	spec for: #''common'' do: [
		spec blessing: #''baseline''.
		spec repository: ''dictionary://Metacello_Dev_Cycle_Repository''.
		spec project: ''MetacelloTestConfigurationOfFoo'' with: [
				spec
					className: ''MetacelloTestConfigurationOfFoo'';
					versionString: #''bleedingEdge'';
					repository: ''cache'' ].
		spec 
			package: ''GeauxFaux'' with: [
				spec requires: #(''MetacelloTestConfigurationOfFoo'' ). ];
			package: ''GeauxBeau'' with: [
				spec requires: #(''GeauxFaux'' ). ].
		spec 
			group: ''default'' with: #(''Core'' );
			group: ''Core'' with: #(''GeauxFaux'' );
			group: ''Tests'' with: #(''GeauxBeau'' );
			group: ''Core Tests'' with: #(''Core'' ''Tests'' ). ].

	spec for: #(#''pharo1.0.x'' #''pharo1.3.x'' ) do: [
		spec blessing: #''baseline''.
		spec 
			package: ''GeauxFaux'' with: [
				spec includes: #(''GoferFaux'' ). ];
			package: ''GeauxBeau'' with: [
				spec requires: #(''GeauxFaux'' ). ];
			package: ''GoferBar'' with: [
				spec 
					repositories: [
						spec
							repository: ''http://example.com/repo1'';
							repository: ''http://example.com/repo2'' ];
					preLoadDoIt: #''preloadGoferBar''. ];
			package: ''GoferBeau'' with: [
				spec 
					supplyingAnswers: #( #( ''list of packages'' ''Kernel* Collection*'' ) );
					file: ''GoferBeau.pharo'';
					postLoadDoIt: #''postloadGoferBar''. ];
			package: ''GoferFaux'' with: [
				spec repository: ''http://example.com/repo2''. ].
		spec 
			group: ''default'' with: #(''Core'' );
			group: ''Core'' with: #(''GeauxFaux'' );
			group: ''Tests'' with: #(''GeauxBeau'' );
			group: ''Core Tests'' with: #(''Core'' ''Tests'' ). ].
'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 9/12/2012 09:56'!
baseline10Issue125ModifySourceString
    ^ 'baseline100: spec
	<version: ''1.0-baseline''>

	spec for: #''common'' do: [
		spec blessing: #''baseline''.
		spec repository: ''dictionary://Metacello_Dev_Cycle_Repository''.
		spec project: ''MetacelloTestConfigurationOfFoo'' with: [
				spec
					className: ''MetacelloTestConfigurationOfFoo'';
					versionString: #''bleedingEdge'';
					repository: ''cache'' ].
		spec 
			package: ''GeauxFaux'' with: [
				spec requires: #(''MetacelloTestConfigurationOfFoo'' ). ];
			package: ''GeauxBeau'' with: [
				spec requires: #(''GeauxFaux'' ). ].
		spec 
			group: ''default'' with: #(''Core'' );
			group: ''Core'' with: #(''GeauxFaux'' );
			group: ''Tests'' with: #(''GeauxBeau'' );
			group: ''Core Tests'' with: #(''Core'' ''Tests'' ). ].

	spec for: #(#''pharo1.0.x'' #''pharo1.3.x'' ) do: [
		spec blessing: #''baseline''.
		spec 
			package: ''GeauxFaux'' with: [
				spec 
					requires: #(''GoferFoo'' );
					includes: #(''GoferFaux'' );
					repository: ''http://www.squeaksource.com/CommandShell''. ];
			package: ''GeauxBeau'' with: [
				spec requires: #(''GeauxFaux'' ). ];
			package: ''GoferBar'' with: [
				spec 
					repositories: [
						spec
							repository: ''http://example.com/repo1'';
							repository: ''http://example.com/repo2'' ];
					preLoadDoIt: #''preloadGoferBar''. ];
			package: ''GoferBeau'' with: [
				spec 
					supplyingAnswers: #( #( ''list of packages'' ''Kernel* Collection*'' ) );
					file: ''GoferBeau.pharo'';
					postLoadDoIt: #''postloadGoferBar''. ];
			package: ''GoferFaux'' with: [
				spec repository: ''http://example.com/repo2''. ];
			package: ''GoferFoo''.
		spec 
			group: ''default'' with: #(''Core'' );
			group: ''Core'' with: #(''GeauxFaux'' );
			group: ''Tests'' with: #(''GeauxBeau'' );
			group: ''Core Tests'' with: #(''Core'' ''Tests'' ). ].
'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline11SourceString

	^'baseline11: spec
	<version: ''1.1-baseline''>

	spec for: #''common'' do: [
		spec blessing: #''baseline''.
		spec repository: ''dictionary://Metacello_Dev_Cycle_Repository''.
		spec project: ''MetacelloTestConfigurationOfFoo'' with: [
				spec
					className: ''MetacelloTestConfigurationOfFoo'';
					versionString: #''bleedingEdge'';
					repository: ''cache'' ].
		spec 
			package: ''GeauxFaux'' with: [
				spec requires: #(''MetacelloTestConfigurationOfFoo'' ). ];
			package: ''GeauxBeau'' with: [
				spec requires: #(''GeauxFaux'' ). ].
		spec 
			group: ''default'' with: #(''Core'' );
			group: ''Core'' with: #(''GeauxFaux'' );
			group: ''Tests'' with: #(''GeauxBeau'' );
			group: ''Core Tests'' with: #(''Core'' ''Tests'' ). ].

	spec for: #''pharo'' do: [
		spec 
			package: ''GoferFoo'';
			package: ''GoferBar'' with: [
				spec requires: #(''GoferFoo'' ). ].
		spec group: ''UI'' with: #(''GoferBar'' ). ].
'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 9/12/2012 16:26'!
baseline12SourceString

	^'baseline12: spec
	<version: ''1.2-baseline''>

	spec for: #''common'' do: [
		spec blessing: #''baseline''.
		spec repository: ''dictionary://Metacello_Dev_Cycle_Repository''.
		spec project: ''MetacelloTestConfigurationOfFoo'' with: [
				spec
					className: ''MetacelloTestConfigurationOfFoo'';
					versionString: #''bleedingEdge'';
					repository: ''cache'' ].
		spec 
			package: ''GeauxFaux'' with: [
				spec requires: #(''MetacelloTestConfigurationOfFoo'' ). ];
			package: ''GeauxBeau'' with: [
				spec requires: #(''GeauxFaux'' ). ].
		spec 
			group: ''default'' with: #(''Core'' );
			group: ''Core'' with: #(''GeauxFaux'' );
			group: ''Tests'' with: #(''GeauxBeau'' );
			group: ''Core Tests'' with: #(''Core'' ''Tests'' ).

		spec for: #''nested'' do: [
			spec package: ''GoferFoo''.
			spec group: ''UI'' with: #(''GoferFoo'' ). ]. ].

	spec for: #''outer'' do: [
		spec package: ''GoferFaux'' with: [
				spec requires: #(''GoferFoo'' ). ].

		spec for: #''nested'' do: [
			spec package: ''GoferBeau''. ]. ].

	spec for: #''other'' do: [
		spec 
			package: ''GoferBeau'' with: [
				spec requires: #(''MetacelloTestConfigurationOfFoo'' ). ];
			package: ''GoferBar'' with: [
				spec requires: #(''GeauxFaux'' ). ]. ].
'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 9/14/2012 10:19'!
baseline14SourceString
    ^ 'baseline14: spec
	<version: ''1.4-baseline''>

	spec for: #''common'' do: [
		spec blessing: #''baseline''.
		spec repository: ''dictionary://Metacello_Dev_Cycle_Repository''.
		spec 
			package: ''GeauxFaux'';
			package: ''GeauxBeau'' with: [
				spec requires: #(''GeauxFaux'' ). ].
		spec 
			group: ''default'' with: #(''Core'' );
			group: ''Core'' with: #(''GeauxFaux'' ). ].

	spec for: #''platform'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: [
				spec
					className: ''MetacelloTestConfigurationOfFoo'';
					versionString: #''bleedingEdge'';
					repository: ''cache'';
					repository: ''dictionary://Metacello_Configuration_Test_Repository'' ].
		spec package: ''GoferBar''. ].

	spec for: #''platform1.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: [
				spec
					className: ''MetacelloTestConfigurationOfFoo'';
					versionString: #''bleedingEdge'';
					repository: ''cache'';
					repository: ''dictionary://Metacello_Configuration_Test_Repository'' ].
		spec package: ''GeauxBeau''. ].

	spec for: #''platform2.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: [
				spec
					className: ''MetacelloTestConfigurationOfFoo'';
					versionString: #''bleedingEdge'';
					repository: ''cache'';
					repository: ''dictionary://Metacello_Configuration_Test_Repository'' ].
		spec package: ''GoferFaux''. ].

	spec for: #''platform2.1.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: [
				spec
					className: ''MetacelloTestConfigurationOfFoo'';
					versionString: #''bleedingEdge'';
					repository: ''cache'';
					repository: ''dictionary://Metacello_Configuration_Test_Repository'' ].
		spec 
			package: ''GoferFoo'';
			package: ''GoferFaux'' with: [
				spec requires: #(''GoferFoo'' ). ]. ].

	spec for: #''platform3.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: [
				spec
					className: ''MetacelloTestConfigurationOfFoo'';
					versionString: #''bleedingEdge'';
					repository: ''cache'';
					repository: ''dictionary://Metacello_Configuration_Test_Repository'' ].
		spec package: ''GoferFoo''. ].

	spec for: #''platform3.1.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: [
				spec
					className: ''MetacelloTestConfigurationOfFoo'';
					versionString: #''bleedingEdge'';
					repository: ''cache'';
					repository: ''dictionary://Metacello_Configuration_Test_Repository'' ].
		spec 
			package: ''GoferFoo'' with: [
				spec requires: #(''GoferFaux'' ). ];
			package: ''GoferFaux''. ].

	spec for: #''platform4.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: [
				spec
					className: ''MetacelloTestConfigurationOfFoo'';
					versionString: #''bleedingEdge'';
					repository: ''cache'';
					repository: ''dictionary://Metacello_Configuration_Test_Repository'' ].
		spec package: ''GoferFoo''. ].

	spec for: #''platform4.1.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: [
				spec
					className: ''MetacelloTestConfigurationOfFoo'';
					versionString: #''bleedingEdge'';
					repository: ''cache'';
					repository: ''dictionary://Metacello_Configuration_Test_Repository'' ].
		spec 
			package: ''GoferFoo'' with: [
				spec requires: #(''GoferFaux'' ). ];
			package: ''GoferFaux''. ].
'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 6/12/2012 15:41:23.319'!
complexBaseline11SourceString

	^ 'baseline11: spec
	<version: ''1.1-baseline''>

	spec for: #''common'' do: [
		spec blessing: #''baseline''.
		spec repository: ''dictionary://Metacello_Dev_Cycle_Repository''.
		spec project: ''MetacelloTestConfigurationOfFoo'' with: [
				spec
					className: ''MetacelloTestConfigurationOfFoo'';
					versionString: #''bleedingEdge'';
					repository: ''cache'' ].
		spec 
			package: ''GeauxFaux'' with: [
				spec 
					requires: #(''MetacelloTestConfigurationOfFoo'' );
					includes: #(''GoferFaux'' ). ];
			package: ''GeauxBeau'' with: [
				spec requires: #(''GeauxFaux'' ). ];
			package: ''GoferBar'' with: [
				spec 
					repositories: [
						spec
							repository: ''http://example.com/repo1'';
							repository: ''http://example.com/repo2'' ];
					preLoadDoIt: #''preloadGoferBar''. ];
			package: ''GoferBeau'' with: [
				spec 
					supplyingAnswers: #( #( ''list of packages'' ''Kernel* Collection*'' ) );
					file: ''GoferBeau.pharo'';
					postLoadDoIt: #''postloadGoferBar''. ];
			package: ''GoferFaux'' with: [
				spec repository: ''http://example.com/repo2''. ].
		spec 
			group: ''default'' with: #(''Core'' );
			group: ''Core'' with: #(''GeauxFaux'' );
			group: ''Tests'' with: #(''GeauxBeau'' );
			group: ''Core Tests'' with: #(''Core'' ''Tests'' ). ].
'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 6/12/2012 15:41:23.319'!
complexBaseline11SourceString2

	^ 'baseline11: spec
	<version: ''1.1-baseline''>

	spec for: #''common'' do: [
		spec blessing: #''baseline''.
		spec repository: ''dictionary://Metacello_Dev_Cycle_Repository''.
		spec project: ''MetacelloTestConfigurationOfFoo'' with: [
				spec
					className: ''MetacelloTestConfigurationOfFoo'';
					versionString: #''bleedingEdge'';
					repository: ''cache'' ].
		spec 
			package: ''GeauxFaux'' with: [
				spec 
					requires: #(''MetacelloTestConfigurationOfFoo'' ''GoferFoo'' );
					includes: #(''GoferFaux'' ). ];
			package: ''GeauxBeau'' with: [
				spec requires: #(''GeauxFaux'' ). ];
			package: ''GoferBar'' with: [
				spec 
					repositories: [
						spec
							repository: ''http://example.com/repo1'';
							repository: ''http://example.com/repo2'' ];
					preLoadDoIt: #''preloadGoferBar''. ];
			package: ''GoferBeau'' with: [
				spec 
					supplyingAnswers: #( #( ''list of packages'' ''Kernel* Collection*'' ) );
					file: ''GoferBeau.pharo'';
					postLoadDoIt: #''postloadGoferBar''. ];
			package: ''GoferFaux'' with: [
				spec repository: ''http://example.com/repo2''. ];
			package: ''GoferFoo''.
		spec 
			group: ''default'' with: #(''Core'' );
			group: ''Core'' with: #(''GeauxFaux'' );
			group: ''Tests'' with: #(''GeauxBeau'' );
			group: ''Core Tests'' with: #(''Core'' ''Tests'' ). ].
'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 6/12/2012 15:41:23.319'!
configurationName

	^#'ConfigurationOfMetacello_Dev_Cycle'! !

!MetacelloToolBoxAPITestCase methodsFor: 'utility' stamp: 'dkh 6/12/2012 15:41:23.319'!
create10Baseline

	MetacelloToolBox
		createBaseline: '1.0-baseline'
		for: self configurationName asString
		repository: 'dictionary://', self repositoryName asString
		requiredProjects: #('MetacelloTestConfigurationOfFoo')
		packages: #('GeauxFaux' 'GeauxBeau')
		dependencies:
			{('GeauxFaux' -> #('MetacelloTestConfigurationOfFoo')).
			('GeauxBeau' -> #('GeauxFaux'))}
		groups:
			{('default' -> #('Core')).
			('Core' -> #('GeauxFaux')).
			('Tests' -> #('GeauxBeau')).
			('Core Tests' -> #('Core' 'Tests'))}.
! !

!MetacelloToolBoxAPITestCase methodsFor: 'utility' stamp: 'dkh 9/12/2012 10:59'!
create10BaselineIssue115
    (MetacelloToolBox configurationNamed: self configurationName asString)
        createVersionMethod: 'baseline100:' inCategory: 'baselines' forVersion: '1.0-baseline';
        addSection: #'common'
            repository: nil
            requiredProjects: #()
            packages: #('GoferFoo' 'GoferBar')
            dependencies: {('GoferBar' -> #('GoferFoo'))}
            groups: #()
            versionSpecsDo: [ :versionSpec |  ];
        addSection: #'nested'
            repository: nil
            requiredProjects: #('MetacelloTestConfigurationOfFoo')
            packages: #('GoferFoo')
            dependencies: {('GoferFoo' -> #('MetacelloTestConfigurationOfFoo'))}
            includes: #()
            files: #()
            repositories: {('MetacelloTestConfigurationOfFoo' -> {('dictionary://' , self repositoryName asString)})}
            preLoadDoIts: #()
            postLoadDoIts: #()
            supplyingAnswers: #()
            groups: #()
            versionSpecsDo: [ :versionSpec |  ];
        commitMethod! !

!MetacelloToolBoxAPITestCase methodsFor: 'utility' stamp: 'dkh 9/12/2012 09:44'!
create10BaselineIssue125
    (MetacelloToolBox configurationNamed: self configurationName asString)
        createVersionMethod: 'baseline100:' inCategory: 'baselines' forVersion: '1.0-baseline';
        addSection: #'common'
            repository: 'dictionary://' , self repositoryName asString
            requiredProjects: #('MetacelloTestConfigurationOfFoo')
            packages: #('GeauxFaux' 'GeauxBeau')
            dependencies:
                {('GeauxFaux' -> #('MetacelloTestConfigurationOfFoo')).
                ('GeauxBeau' -> #('GeauxFaux'))}
            groups:
                {('default' -> #('Core')).
                ('Core' -> #('GeauxFaux')).
                ('Tests' -> #('GeauxBeau')).
                ('Core Tests' -> #('Core' 'Tests'))}
            versionSpecsDo: [ :versionSpec | versionSpec blessing: #'baseline' ];
        commitMethod;
        modifyVersionMethodForVersion: '1.0-baseline' versionSpecsDo: [ :attribute :versionSpec | true ];
        addSection: (MetacelloMethodSectionPath with: #(#'pharo1.0.x' #'pharo1.3.x'))
            repository: nil
            requiredProjects: #()
            packages: #('GeauxFaux' 'GeauxBeau' 'GoferBar' 'GoferBeau' 'GoferFaux')
            dependencies: {('GeauxBeau' -> #('GeauxFaux'))}
            includes: {('GeauxFaux' -> #('GoferFaux'))}
            files: {('GoferBeau' -> 'GoferBeau.pharo')}
            repositories:
                {('GoferBar' -> #('http://example.com/repo1' 'http://example.com/repo2')).
                ('GoferFaux' -> #('http://example.com/repo2'))}
            preLoadDoIts: {('GoferBar' -> #'preloadGoferBar')}
            postLoadDoIts: {('GoferBeau' -> #'postloadGoferBar')}
            supplyingAnswers:
                {('GoferBeau'
                    ->
                        {{'list of packages'.
                        'Kernel* Collection*'}})}
            groups:
                {('default' -> #('Core')).
                ('Core' -> #('GeauxFaux')).
                ('Tests' -> #('GeauxBeau')).
                ('Core Tests' -> #('Core' 'Tests'))}
            versionSpecsDo: [ :versionSpec | versionSpec blessing: #'baseline' ];
        commitMethod! !

!MetacelloToolBoxAPITestCase methodsFor: 'utility' stamp: 'dkh 9/12/2012 11:17'!
create10VersionIssue115
    MetacelloConfigurationResource projectAttributes: #(#'nested').
    self create10BaselineIssue115.
    (Smalltalk at: self configurationName) compile: self projectSourceString classified: 'cat'.
    (MetacelloToolBox configurationNamed: self configurationName asString)
        createVersionMethod: 'version10:' inCategory: 'versions' forVersion: '1.0';
        importFrom: '1.0-baseline'
            updateProjects: true
            updatePackages: true
            versionSpecsDo: [ :attributeOrPath :versionSpec | 
                attributeOrPath == #'common'
                    ifTrue: [ versionSpec blessing: #'development' ].
                true ];
        commitMethod! !

!MetacelloToolBoxAPITestCase methodsFor: 'utility' stamp: 'dkh 9/12/2012 16:43'!
create11Baseline
    MetacelloToolBox
        createBaseline: '1.0-baseline'
        for: self configurationName asString
        repository: 'dictionary://' , self repositoryName asString
        requiredProjects: #('MetacelloTestConfigurationOfFoo')
        packages: #('GeauxFaux')
        dependencies: {('GeauxFaux' -> #('MetacelloTestConfigurationOfFoo'))}
        groups:
            {('default' -> #('Core')).
            ('Core' -> #('GeauxFaux'))}! !

!MetacelloToolBoxAPITestCase methodsFor: 'utility' stamp: 'dkh 9/13/2012 12:15'!
create12Baseline
    MetacelloToolBox
        createBaseline: '1.2-baseline'
        for: self configurationName asString
        repository: 'dictionary://' , self repositoryName asString
        requiredProjects: #()
        packages: #('GeauxFaux' 'GeauxBeau')
        dependencies: {('GeauxBeau' -> #('GeauxFaux'))}
        groups:
            {('default' -> #('Core')).
            ('Core' -> #('GeauxFaux'))}! !

!MetacelloToolBoxAPITestCase methodsFor: 'utility' stamp: 'dkh 9/14/2012 14:27'!
create12Version
    self createNested12Baseline.
    (MetacelloToolBox configurationNamed: self configurationName asString)
        createVersionMethod: 'version12:' inCategory: 'versions' forVersion: '1.2';
        importFrom: '1.2-baseline'
            updateProjects: true
            updatePackages: true
            versionSpecsDo: [ :attributeOrPath :versionSpec | 
                attributeOrPath == #'common'
                    ifTrue: [ versionSpec blessing: #'development' ].
                attributeOrPath = #(#(#'common') #(#'nested')) asMetacelloAttributePath
                    ifTrue: [ versionSpec description: 'nested for:do: section' ].
                true ];
        commitMethod! !

!MetacelloToolBoxAPITestCase methodsFor: 'utility' stamp: 'dkh 9/14/2012 09:53'!
create14Baseline
    MetacelloConfigurationResource projectAttributes: #(#'platform' #'platform1.x' #'platform2.x').
    self create12Baseline.
    (Smalltalk at: self configurationName) compile: self projectSourceString classified: 'cat'.
    (MetacelloToolBox configurationNamed: self configurationName asString)
        createVersionMethod: 'baseline14:' inCategory: 'baselines' forVersion: '1.4-baseline';
        addSectionsFrom: '1.2-baseline'
            forBaseline: true
            updateProjects: false
            updatePackages: false
            versionSpecsDo: [ :attribute :versionSpec | true ];
        commitMethod;
        modifyVersionMethodForVersion: '1.4-baseline';
        addSection: #'platform'
            repository: nil
            requiredProjects: #('MetacelloTestConfigurationOfFoo')
            packages: #('GoferBar')
            dependencies: {}
            includes: #()
            files: #()
            repositories:
                {('MetacelloTestConfigurationOfFoo' -> {'dictionary://Metacello_Configuration_Test_Repository'})}
            preLoadDoIts: #()
            postLoadDoIts: #()
            supplyingAnswers: #()
            groups: #()
            versionSpecsDo: [ :versionSpec |  ];
        addSection: #'platform1.x'
            repository: nil
            requiredProjects: #('MetacelloTestConfigurationOfFoo')
            packages: #('GeauxBeau')
            dependencies: #()
            includes: #()
            files: #()
            repositories:
                {('MetacelloTestConfigurationOfFoo' -> {'dictionary://Metacello_Configuration_Test_Repository'})}
            preLoadDoIts: #()
            postLoadDoIts: #()
            supplyingAnswers: #()
            groups: #()
            versionSpecsDo: [ :versionSpec |  ];
        addSection: #'platform2.x'
            repository: nil
            requiredProjects: #('MetacelloTestConfigurationOfFoo')
            packages: #('GoferFaux')
            dependencies: #()
            includes: #()
            files: #()
            repositories:
                {('MetacelloTestConfigurationOfFoo' -> {'dictionary://Metacello_Configuration_Test_Repository'})}
            preLoadDoIts: #()
            postLoadDoIts: #()
            supplyingAnswers: #()
            groups: #()
            versionSpecsDo: [ :versionSpec |  ];
        addSection: #'platform2.1.x'
            repository: nil
            requiredProjects: #('MetacelloTestConfigurationOfFoo')
            packages: #('GoferFoo' 'GoferFaux')
            dependencies: {('GoferFaux' -> #('GoferFoo'))}
            includes: #()
            files: #()
            repositories:
                {('MetacelloTestConfigurationOfFoo' -> {'dictionary://Metacello_Configuration_Test_Repository'})}
            preLoadDoIts: #()
            postLoadDoIts: #()
            supplyingAnswers: #()
            groups: #()
            versionSpecsDo: [ :versionSpec |  ];
        addSection: #'platform3.x'
            repository: nil
            requiredProjects: #('MetacelloTestConfigurationOfFoo')
            packages: #('GoferFoo')
            dependencies: #()
            includes: #()
            files: #()
            repositories:
                {('MetacelloTestConfigurationOfFoo' -> {'dictionary://Metacello_Configuration_Test_Repository'})}
            preLoadDoIts: #()
            postLoadDoIts: #()
            supplyingAnswers: #()
            groups: #()
            versionSpecsDo: [ :versionSpec |  ];
        addSection: #'platform3.1.x'
            repository: nil
            requiredProjects: #('MetacelloTestConfigurationOfFoo')
            packages: #('GoferFoo' 'GoferFaux')
            dependencies: {('GoferFoo' -> #('GoferFaux'))}
            includes: #()
            files: #()
            repositories:
                {('MetacelloTestConfigurationOfFoo' -> {'dictionary://Metacello_Configuration_Test_Repository'})}
            preLoadDoIts: #()
            postLoadDoIts: #()
            supplyingAnswers: #()
            groups: #()
            versionSpecsDo: [ :versionSpec |  ];
        addSection: #'platform4.x'
            repository: nil
            requiredProjects: #('MetacelloTestConfigurationOfFoo')
            packages: #('GoferFoo')
            dependencies: #()
            includes: #()
            files: #()
            repositories:
                {('MetacelloTestConfigurationOfFoo' -> {'dictionary://Metacello_Configuration_Test_Repository'})}
            preLoadDoIts: #()
            postLoadDoIts: #()
            supplyingAnswers: #()
            groups: #()
            versionSpecsDo: [ :versionSpec |  ];
        addSection: #'platform4.1.x'
            repository: nil
            requiredProjects: #('MetacelloTestConfigurationOfFoo')
            packages: #('GoferFoo' 'GoferFaux')
            dependencies: {('GoferFoo' -> #('GoferFaux'))}
            includes: #()
            files: #()
            repositories:
                {('MetacelloTestConfigurationOfFoo' -> {'dictionary://Metacello_Configuration_Test_Repository'})}
            preLoadDoIts: #()
            postLoadDoIts: #()
            supplyingAnswers: #()
            groups: #()
            versionSpecsDo: [ :versionSpec |  ];
        commitMethod! !

!MetacelloToolBoxAPITestCase methodsFor: 'utility' stamp: 'dkh 9/14/2012 09:51'!
create14Version
    self create14Baseline.
    (MetacelloToolBox configurationNamed: self configurationName asString)
        createVersionMethod: 'version14:' inCategory: 'versions' forVersion: '1.4';
        importFrom: '1.4-baseline'
            projectAttributes: #(#'common' #'platform' #'platform1.x')
            inactiveAttributes: #(#(#'platform2.x' #'platform2.1.x') #(#'platform3.x' #'platform3.1.x'))
            updateProjects: true
            updatePackages: true
            versionSpecsDo: [ :attributeOrPath :versionSpec | 
                attributeOrPath == #'common'
                    ifTrue: [ versionSpec blessing: #'development' ].
                true ];
        commitMethod! !

!MetacelloToolBoxAPITestCase methodsFor: 'utility' stamp: 'dkh 9/13/2012 15:13'!
create15Baseline
    MetacelloConfigurationResource projectAttributes: #(#'nested' #'outer' #'other').
    self create10Baseline.
    (Smalltalk at: self configurationName) compile: self projectSourceString classified: 'cat'.
    (MetacelloToolBox configurationNamed: self configurationName asString)
        createVersionMethod: 'baseline15:' inCategory: 'baselines' forVersion: '1.5-baseline';
        addSectionsFrom: '1.0-baseline'
            forBaseline: true
            updateProjects: false
            updatePackages: false
            versionSpecsDo: [ :attribute :versionSpec | true ];
        commitMethod;
        modifyVersionMethodForVersion: '1.5-baseline';
        addSection: #(#(#'outer' #'nested'))
            repository: nil
            requiredProjects: #()
            packages: #('GoferFaux')
            dependencies: #()
            groups: #()
            versionSpecsDo: [ :versionSpec |  ];
        commitMethod! !

!MetacelloToolBoxAPITestCase methodsFor: 'utility' stamp: 'dkh 6/12/2012 15:41:23.319'!
createComplex11Baseline

	MetacelloToolBox
		createBaseline: '1.1-baseline'
		for: self configurationName asString
		repository: 'dictionary://' , self repositoryName asString
		requiredProjects: #('MetacelloTestConfigurationOfFoo')
		packages: #('GeauxFaux' 'GeauxBeau' 'GoferBar' 'GoferBeau' 'GoferFaux' )
		dependencies:
			{('GeauxFaux' -> #('MetacelloTestConfigurationOfFoo')).
			('GeauxBeau' -> #('GeauxFaux'))}
		includes: {('GeauxFaux' -> #('GoferFaux'))}
		files: {('GoferBeau' -> 'GoferBeau.pharo')}
		repositories: {('GoferBar' -> #('http://example.com/repo1' 'http://example.com/repo2')). ('GoferFaux' -> #('http://example.com/repo2'))}
		preLoadDoIts: {('GoferBar' -> #preloadGoferBar)}
		postLoadDoIts: {('GoferBeau' -> #postloadGoferBar)}
		supplyingAnswers: {'GoferBeau' -> {{ 'list of packages'. 'Kernel* Collection*' }}.}
		groups:
			{('default' -> #('Core')).
			('Core' -> #('GeauxFaux')).
			('Tests' -> #('GeauxBeau')).
			('Core Tests' -> #('Core' 'Tests'))}.
! !

!MetacelloToolBoxAPITestCase methodsFor: 'utility' stamp: 'dkh 9/12/2012 16:19'!
createNested12Baseline
    MetacelloConfigurationResource projectAttributes: #(#'nested' #'outer' #'other').
    self create10Baseline.
    (Smalltalk at: self configurationName) compile: self projectSourceString classified: 'cat'.
    (MetacelloToolBox configurationNamed: self configurationName asString)
        createVersionMethod: 'baseline12:' inCategory: 'baselines' forVersion: '1.2-baseline';
        addSectionsFrom: '1.0-baseline'
            forBaseline: true
            updateProjects: false
            updatePackages: false
            versionSpecsDo: [ :attribute :versionSpec | true ];
        commitMethod;
        modifyVersionMethodForVersion: '1.2-baseline';
        addSection: #(#(#'common') #(#'nested')) asMetacelloAttributePath
            repository: nil
            requiredProjects: #()
            packages: #('GoferFoo')
            dependencies: {}
            groups: {('UI' -> #('GoferFoo'))}
            versionSpecsDo: [ :versionSpec |  ];
        addSection: #'outer'
            repository: nil
            requiredProjects: #()
            packages: #('GoferFaux')
            dependencies: {('GoferFaux' -> #('GoferFoo'))}
            groups: #()
            versionSpecsDo: [ :versionSpec |  ];
        addSection: #(#(#'outer') #(#'nested'))
            repository: nil
            requiredProjects: #()
            packages: #('GoferBeau')
            dependencies: #()
            groups: #()
            versionSpecsDo: [ :versionSpec |  ];
        addSection: #'other'
            repository: nil
            requiredProjects: #()
            packages: #('GoferBeau' 'GoferBar')
            dependencies:
                {('GoferBeau' -> #('MetacelloTestConfigurationOfFoo')).
                ('GoferBar' -> #('GeauxFaux'))}
            groups: #()
            versionSpecsDo: [ :versionSpec |  ];
        commitMethod! !

!MetacelloToolBoxAPITestCase methodsFor: 'utility' stamp: 'dkh 9/12/2012 16:54'!
createNested13Baseline
    MetacelloConfigurationResource projectAttributes: #(#'nested' #'outer' #'other').
    self create11Baseline.
    (Smalltalk at: self configurationName) compile: self projectSourceString classified: 'cat'.
    (MetacelloToolBox configurationNamed: self configurationName asString)
        createVersionMethod: 'baseline13:' inCategory: 'baselines' forVersion: '1.3-baseline';
        addSectionsFrom: '1.0-baseline'
            forBaseline: true
            updateProjects: false
            updatePackages: false
            versionSpecsDo: [ :attribute :versionSpec | true ];
        commitMethod;
        modifyVersionMethodForVersion: '1.3-baseline';
        addSection: #(#(#'common') #(#'nested')) asMetacelloAttributePath
            repository: nil
            requiredProjects: #()
            packages: #('GoferFoo')
            dependencies: {}
            groups: {('UI' -> #('GoferFoo'))}
            versionSpecsDo: [ :versionSpec |  ];
        addSection: #'outer'
            repository: nil
            requiredProjects: #()
            packages: #('GoferFaux' 'GeauxBeau')
            dependencies: {('GoferFaux' -> #('GoferFoo'))}
            groups: #()
            versionSpecsDo: [ :versionSpec |  ];
        addSection: #(#(#'outer') #(#'nested'))
            repository: nil
            requiredProjects: #()
            packages: #('GoferBeau')
            dependencies: #()
            groups: #()
            versionSpecsDo: [ :versionSpec |  ];
        addSection: #'other'
            repository: nil
            requiredProjects: #()
            packages: #('GoferBeau' 'GoferBar' 'GeauxBeau')
            dependencies:
                {('GoferBeau' -> #('MetacelloTestConfigurationOfFoo')).
                ('GoferBar' -> #('GeauxFaux'))}
            groups: #()
            versionSpecsDo: [ :versionSpec |  ];
        commitMethod! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 6/12/2012 15:41:23.319'!
hasPackage: aString
	| package |
	package := MCWorkingCopy allManagers
		detect: [ :each | each packageName = aString ]
		ifNone: [ nil ].
	^ package notNil! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 6/12/2012 15:41:23.319'!
projectSourceString

	^'project
	| constructor |
	project := MetacelloMCProject new.
	project projectAttributes: MetacelloConfigurationResource projectAttributes.
	MetacelloVersionConstructor on: self project: project.
	project loadType: #linear.
	^project
'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 6/12/2012 15:41:23.319'!
repositoryName

	^#'Metacello_Dev_Cycle_Repository'! !

!MetacelloToolBoxAPITestCase methodsFor: 'running' stamp: 'dkh 6/12/2012 15:41:23.319'!
runCase
	| original |
	original := MetacelloPlatform current bypassGoferLoadUpdateCategories.
	[ 
	MetacelloPlatform current bypassGoferLoadUpdateCategories: true.
	^ SystemChangeNotifier uniqueInstance doSilently: [ super runCase ] ]
		ensure: [ MetacelloPlatform current bypassGoferLoadUpdateCategories: original ]! !

!MetacelloToolBoxAPITestCase methodsFor: 'running' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUp
	| repo gofer |
	super setUp.
	repo := MCDictionaryRepository new.
	repo description: 'dictionary://', self repositoryName asString.
	self tempRepositories add: repo.
	Smalltalk at: self repositoryName put: repo.
	repo := MCDictionaryRepository new.
	repo description: 'dictionary://', self alternatRepositoryName asString.
	self tempRepositories add: repo.
	Smalltalk at: self alternatRepositoryName put: repo.
	Smalltalk at: self configurationName ifPresent: [:cl | cl removeFromSystem ].

	repo := MetacelloConfigurationResource current monticelloRepository.
	self tempRepositories add: repo.
	Smalltalk at: #'Metacello_Configuration_Test_Repository' put: repo.
	gofer := Gofer new
		repository: repo;
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		metacelloLoad.
	repo := MetacelloMonticelloResource current monticelloRepository.
	repo description: 'dictionary://Metacello_Gofer_Test_Repository'.
	self tempRepositories add: repo.
	Smalltalk at: #'Metacello_Gofer_Test_Repository' put: repo.

	(Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project load: '4.0'.
! !

!MetacelloToolBoxAPITestCase methodsFor: 'running' stamp: 'dkh 6/12/2012 15:41:23.319'!
tearDown
	| aGofer |
	super tearDown.
	aGofer := Gofer new.
	self tearDownPackages: aGofer.
	aGofer references notEmpty ifTrue: [ aGofer metacelloUnload ].
	Smalltalk removeKey: self repositoryName ifAbsent: [  ].
	Smalltalk removeKey: self alternatRepositoryName  ifAbsent: [  ].
	Smalltalk removeKey: #'Metacello_Gofer_Test_Repository' ifAbsent: [].
	Smalltalk removeKey: #'Metacello_Configuration_Test_Repository' ifAbsent: [].
	Smalltalk at: self configurationName ifPresent: [ :cl | cl removeFromSystem ].
	self tempRepositories do: [:repo | MCRepositoryGroup default removeRepository: repo ].
	(self hasPackage: self configurationName asString)
		ifTrue: [ 
			(Gofer new)
				package: self configurationName asString;
				metacelloUnload ].
	MetacelloConfigurationResource projectAttributes: nil.
! !

!MetacelloToolBoxAPITestCase methodsFor: 'running' stamp: 'dkh 6/12/2012 15:41:23.319'!
tearDownPackages: aGoferInstance

	(self hasPackage: 'GoferFoo')
		ifTrue: [ aGoferInstance package: 'GoferFoo' ].
	(self hasPackage: 'GoferBar')
		ifTrue: [ aGoferInstance package: 'GoferBar' ].
	(self hasPackage: 'GoferFaux')
		ifTrue: [ aGoferInstance package: 'GoferFaux' ].
	(self hasPackage: 'GoferBeau')
		ifTrue: [ aGoferInstance package: 'GoferBeau' ].
	(self hasPackage: 'GeauxFaux')
		ifTrue: [ aGoferInstance package: 'GeauxFaux' ].
	(self hasPackage: 'GeauxBeau')
		ifTrue: [ aGoferInstance package: 'GeauxBeau' ].
	(self hasPackage: 'MetacelloTestConfigurationOfFoo')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfFoo' ].
	(self hasPackage: 'MetacelloTestConfigurationOfProjectFee')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfProjectFee' ].
! !

!MetacelloToolBoxAPITestCase methodsFor: 'accessing' stamp: 'dkh 6/12/2012 15:41:23.319'!
tempRepositories

	tempRepositories ifNil: [ tempRepositories := OrderedCollection new ].
	^tempRepositories! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testAddNestedSection2
	"Add nested section as addition to existing version"

	| source |
	self createNested12Baseline.
	self assert: (source := ((Smalltalk at: self configurationName) sourceCodeAt: #baseline12:) asString) = self baseline12SourceString! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testAddSection1
	"Add section as part of creating a new version"

	| toolbox |
	self create10Baseline.
	(toolbox := MetacelloToolBox configurationNamed: self configurationName asString)
		createVersionMethod: 'baseline11:' inCategory: 'baselines' forVersion: '1.1-baseline';
		addSectionsFrom: '1.0-baseline'
			forBaseline: true
			updateProjects: false
			updatePackages: false
			versionSpecsDo: [ :attribute :versionSpec | true ];
		addSection: #pharo
			repository: nil
			requiredProjects: #()
			packages: #('GoferFoo' 'GoferBar')
			dependencies: {('GoferBar' -> #('GoferFoo'))}
			groups: {('UI' -> #('GoferBar'))}
			versionSpecsDo: [ :versionSpec |  ];
		commitMethod.
	self assert: ((Smalltalk at: self configurationName) sourceCodeAt: #'baseline11:') = self baseline11SourceString! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testAddSection2
	"Add section as addition to existing version"

	| toolbox |
	self create10Baseline.
	(toolbox := MetacelloToolBox configurationNamed: self configurationName asString)
		createVersionMethod: 'baseline11:' inCategory: 'baselines' forVersion: '1.1-baseline';
		addSectionsFrom: '1.0-baseline'
			forBaseline: true
			updateProjects: false
			updatePackages: false
			versionSpecsDo: [ :attribute :versionSpec | true ];
		commitMethod.
	toolbox
		modifyVersionMethodForVersion: '1.1-baseline';
		addSection: #pharo
			repository: nil
			requiredProjects: #()
			packages: #('GoferFoo' 'GoferBar')
			dependencies: {('GoferBar' -> #('GoferFoo'))}
			groups: {('UI' -> #('GoferBar'))}
			versionSpecsDo: [ :versionSpec |  ];
		commitMethod.
	self assert: ((Smalltalk at: self configurationName) sourceCodeAt: #'baseline11:') = self baseline11SourceString! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testComplexCreateBaseline

	self createComplex11Baseline.
	self assert: ((Smalltalk at: self configurationName) sourceCodeAt: #baseline11:) = self complexBaseline11SourceString! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testComplexModifyBaseline
	self createComplex11Baseline.
	MetacelloToolBox
		modifyVersion: '1.1-baseline'
		section: #common
		for: self configurationName asString
		repository: nil
		requiredProjects: #()
		packages: #('GoferFoo')
		dependencies: {'GeauxFaux' -> #('GoferFoo').}
		includes: #()
		files: #()
		repositories: #()
		preLoadDoIts: #()
		postLoadDoIts: #()
		supplyingAnswers: #()
		groups: #().
	self assert: ((Smalltalk at: self configurationName) sourceCodeAt: #baseline11:) = self complexBaseline11SourceString2! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testComplexNullModifyBaseline
	self createComplex11Baseline.
	MetacelloToolBox
		modifyVersion: '1.1-baseline'
		section: #common
		for: self configurationName asString
		repository: nil
		requiredProjects: #()
		packages: #()
		dependencies: #()
		includes: #()
		files: #()
		repositories: #()
		preLoadDoIts: #()
		postLoadDoIts: #()
		supplyingAnswers: #()
		groups: #().
	self assert: ((Smalltalk at: self configurationName) sourceCodeAt: #baseline11:) = self complexBaseline11SourceString! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 9/7/2012 14:00'!
testImportFrom1
    | toolbox |
    self create10Baseline.
    (toolbox := MetacelloToolBox configurationNamed: self configurationName asString)
        createVersionMethod: 'version10:' inCategory: 'versions' forVersion: '1.0';
        importFrom: '1.0-baseline'
            updateProjects: true
            updatePackages: true
            versionSpecsDo: [ :attributeOrPath :versionSpec | 
                attributeOrPath == #'common'
                    ifTrue: [ versionSpec blessing: #'development' ].
                true ];
        commitMethod.
    self assert: ((Smalltalk at: self configurationName) sourceCodeAt: #'version10:') = self version10SourceString! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 9/14/2012 14:27'!
testImportFrom2
    self create12Version.
    self
        assert:
            ((Smalltalk at: self configurationName) sourceCodeAt: #'version12:') asString = self version12SourceString! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 9/13/2012 16:06'!
testImportFrom3
    "change order of project attributes...i.e., not reversed which is default"

    | toolbox source |
    self createNested13Baseline.
    (toolbox := MetacelloToolBox configurationNamed: self configurationName asString)
        createVersionMethod: 'version13:' inCategory: 'versions' forVersion: '1.3';
        importFrom: '1.3-baseline'
            projectAttributes: #(#'common' #'nested' #'outer' #'other')
            inactiveAttributes: #()
            updateProjects: true
            updatePackages: true
            versionSpecsDo: [ :attributeOrPath :versionSpec | 
                attributeOrPath == #'common'
                    ifTrue: [ versionSpec blessing: #'development' ].
                attributeOrPath = #(#(#'common') #(#'nested')) asMetacelloAttributePath
                    ifTrue: [ versionSpec description: 'nested for:do: section' ].
                true ];
        commitMethod.
    self
        assert:
            (source := ((Smalltalk at: self configurationName) sourceCodeAt: #'version13:') asString) = self version13SourceString3! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 9/13/2012 16:06'!
testImportFrom4
    "change order of project attributes relative to import3...i.e., not reversed which is default"

    | toolbox source |
    self createNested13Baseline.
    (toolbox := MetacelloToolBox configurationNamed: self configurationName asString)
        createVersionMethod: 'version13:' inCategory: 'versions' forVersion: '1.3';
        importFrom: '1.3-baseline'
            projectAttributes: #(#'common' #'other' #'nested' #'outer')
            inactiveAttributes: #()
            updateProjects: true
            updatePackages: true
            versionSpecsDo: [ :attributeOrPath :versionSpec | 
                attributeOrPath == #'common'
                    ifTrue: [ versionSpec blessing: #'development' ].
                attributeOrPath = #(#(#'common') #(#'nested')) asMetacelloAttributePath
                    ifTrue: [ versionSpec description: 'nested for:do: section' ].
                true ];
        commitMethod.
    self
        assert:
            (source := ((Smalltalk at: self configurationName) sourceCodeAt: #'version13:') asString) = self version13SourceString4! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 9/14/2012 09:58'!
testImportFrom5
    "#platform4 is left untouched ..."

    self create14Version.
    self
        assert:
            ((Smalltalk at: self configurationName) sourceCodeAt: #'baseline14:') asString = self baseline14SourceString.
    self
        assert:
            ((Smalltalk at: self configurationName) sourceCodeAt: #'version14:') asString = self version14SourceString! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 9/13/2012 15:15'!
testImportFrom6A
    | toolbox source |
    self create15Baseline.
    (toolbox := MetacelloToolBox configurationNamed: self configurationName asString)
        createVersionMethod: 'version15:' inCategory: 'versions' forVersion: '1.5';
        importFrom: '1.5-baseline'
            updateProjects: true
            updatePackages: true
            versionSpecsDo: [ :attributeOrPath :versionSpec | 
                attributeOrPath == #'common'
                    ifTrue: [ versionSpec blessing: #'development' ].
                true ];
        commitMethod.
    self
        assert:
            (source := ((Smalltalk at: self configurationName) sourceCodeAt: #'version15:') asString) = self version15SourceStringA! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 9/13/2012 19:07'!
testImportFrom6B
    | toolbox source |
    self create15Baseline.
    (toolbox := MetacelloToolBox configurationNamed: self configurationName asString)
        createVersionMethod: 'version15:' inCategory: 'versions' forVersion: '1.5';
        importFrom: '1.5-baseline'
            projectAttributes: #(#'common')
            inactiveAttributes: #()
            updateProjects: true
            updatePackages: true
            versionSpecsDo: [ :attributeOrPath :versionSpec | 
                attributeOrPath == #'common'
                    ifTrue: [ versionSpec blessing: #'development' ].
                true ];
        commitMethod.
    self
        assert:
            (source := ((Smalltalk at: self configurationName) sourceCodeAt: #'version15:') asString) = self version15SourceStringB! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 9/13/2012 16:06'!
testImportFrom6C
    | toolbox source |
    self create15Baseline.
    (toolbox := MetacelloToolBox configurationNamed: self configurationName asString)
        createVersionMethod: 'version15:' inCategory: 'versions' forVersion: '1.5';
        importFrom: '1.5-baseline'
            projectAttributes: #(#'common' #'nested')
            inactiveAttributes: #()
            updateProjects: true
            updatePackages: true
            versionSpecsDo: [ :attributeOrPath :versionSpec | 
                attributeOrPath == #'common'
                    ifTrue: [ versionSpec blessing: #'development' ].
                true ];
        commitMethod.
    self
        assert:
            (source := ((Smalltalk at: self configurationName) sourceCodeAt: #'version15:') asString) = self version15SourceStringA! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 9/13/2012 16:06'!
testImportFrom6D
    | toolbox source |
    self create15Baseline.
    (toolbox := MetacelloToolBox configurationNamed: self configurationName asString)
        createVersionMethod: 'version15:' inCategory: 'versions' forVersion: '1.5';
        importFrom: '1.5-baseline'
            projectAttributes: #(#'common' #'outer')
            inactiveAttributes: #()
            updateProjects: true
            updatePackages: true
            versionSpecsDo: [ :attributeOrPath :versionSpec | 
                attributeOrPath == #'common'
                    ifTrue: [ versionSpec blessing: #'development' ].
                true ];
        commitMethod.
    self
        assert:
            (source := ((Smalltalk at: self configurationName) sourceCodeAt: #'version15:') asString) = self version15SourceStringA! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 9/12/2012 14:18'!
testIssue115CreateVersion
    self create10VersionIssue115.
    self
        assert:
            ((Smalltalk at: self configurationName) sourceCodeAt: #'version10:') = self version10Issue115CreateVersionSourceString! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 9/12/2012 14:22'!
testIssue115UpdateVersion
    self create10VersionIssue115.
    ((Smalltalk at: #'MetacelloTestConfigurationOfFoo') project version: '5.0') load.
    (MetacelloToolBox configurationNamed: self configurationName asString)
        updateVersionMethodForVersion: '1.0'
            updateProjects: true
            updatePackages: true
            versionSpecsDo: [ :attribute :versionSpec | true ];
        commitMethod.
    self
        assert:
            ((Smalltalk at: self configurationName) sourceCodeAt: #'version10:') = self version10Issue115UpdatedVersionSourceString! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 9/12/2012 09:51'!
testIssue125AddSection
    "https://github.com/dalehenrich/metacello-work/issues/125"

    self create10BaselineIssue125.
    self
        assert:
            ((Smalltalk at: self configurationName) sourceCodeAt: #'baseline100:') = self baseline10Issue125AddSourceString! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 9/12/2012 09:56'!
testIssue125ModifySection
    "https://github.com/dalehenrich/metacello-work/issues/125"

    self create10BaselineIssue125.
    MetacelloToolBox
        modifyVersion: '1.0-baseline'
        section: (MetacelloMethodSectionPath with: #(#'pharo1.0.x' #'pharo1.3.x'))
        for: self configurationName asString
        repository: nil
        requiredProjects: #()
        packages: #('GoferFoo')
        dependencies: {('GeauxFaux' -> #('GoferFoo'))}
        includes: #()
        files: #()
        repositories: {('GeauxFaux' -> #('http://www.squeaksource.com/CommandShell'))}
        preLoadDoIts: #()
        postLoadDoIts: #()
        supplyingAnswers: #()
        groups: #().
    self
        assert:
            ((Smalltalk at: self configurationName) sourceCodeAt: #'baseline100:') = self baseline10Issue125ModifySourceString! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 9/14/2012 14:33'!
testMethodSectionsFromDo
    | fileNames expected |
    self create12Version.
    fileNames := Set new.
    [ 
    (MetacelloToolBox configurationNamed: self configurationName)
        methodSectionsFrom: '1.2'
        do: [ :methodSection | 
            methodSection versionSpec
                specListProjectDo: [ :spec |  ]
                packageDo: [ :spec | fileNames add: spec file ]
                groupDo: [ :spec |  ].
            false ] ]
        on: MetacelloCannotUpdateReleasedVersionError
        do: [ :ex | ex resume ].
    expected := #('GeauxFaux-tg.32' 'GeauxBeau-dkh.55' 'GoferFoo-lr.1' 'GoferFaux-tg.32' 'GoferBeau-dkh.55' 'GoferBar-lr.0').
    self assert: fileNames size = expected size.
    self assert: (fileNames difference: expected asSet) isEmpty! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testReasonCodes

	self assert: (MetacelloToolBox descriptionForValidationReasonCode: #noVersionSpecified) = 'no version defined for the project reference or package. The version specified in the baseline or the latest version of the project or package in the repository will be used.'.
	self assert: (MetacelloToolBox descriptionForValidationReasonCode: #duplicateNames) = 'multiple independent definitions for an entity with same name (project, package, or group).'.
! !

!MetacelloToolBoxAPITestCase methodsFor: 'tests' stamp: 'dkh 9/13/2012 16:59'!
testUpdateVersionMethod
    "see testImportFrom5"

    self create14Version.
    (MetacelloToolBox configurationNamed: self configurationName asString)
        updateVersionMethodForVersion: '1.4'
            projectAttributes: #(#'common' #'platform' #'platform2.x' #'platform2.1.x')
            updateProjects: true
            updatePackages: true
            versionSpecsDo: [ :attribute :versionSpec | true ];
        commitMethod.
    self
        assert:
            ((Smalltalk at: self configurationName) sourceCodeAt: #'version14:') asString = self version14SourceStringUpdated.
    ((Smalltalk at: #'MetacelloTestConfigurationOfFoo') project version: '5.0') load.
    (MetacelloToolBox configurationNamed: self configurationName asString)
        updateVersionMethodForVersion: '1.4'
            projectAttributes: #(#'common' #'platform' #'platform2.x' #'platform2.1.x')
            updateProjects: true
            updatePackages: true
            versionSpecsDo: [ :attribute :versionSpec | true ];
        commitMethod.
    self
        assert:
            ((Smalltalk at: self configurationName) sourceCodeAt: #'version14:') asString = self version14SourceStringUpdated50! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 9/12/2012 14:18'!
version10Issue115CreateVersionSourceString
    ^ 'version10: spec
	<version: ''1.0'' imports: #(''1.0-baseline'' )>

	spec for: #''common'' do: [
		spec blessing: #''development''.
		spec 
			package: ''GoferFoo'' with: ''GoferFoo-lr.1'';
			package: ''GoferBar'' with: ''GoferBar-lr.0''. ].

	spec for: #''nested'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: ''4.0''. ].
'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 9/12/2012 14:24'!
version10Issue115UpdatedVersionSourceString
    ^ 'version10: spec
	<version: ''1.0'' imports: #(''1.0-baseline'' )>

	spec for: #''common'' do: [
		spec blessing: #''development''.
		spec 
			package: ''GoferFoo'' with: ''GoferFoo-lr.2'';
			package: ''GoferBar'' with: ''GoferBar-lr.1''. ].

	spec for: #''nested'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: ''5.0''. ].
'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 6/12/2012 15:41:23.319'!
version10SourceString

	^'version10: spec
	<version: ''1.0'' imports: #(''1.0-baseline'' )>

	spec for: #''common'' do: [
		spec blessing: #''development''.
		spec project: ''MetacelloTestConfigurationOfFoo'' with: ''4.0''.
		spec 
			package: ''GeauxFaux'' with: ''GeauxFaux-tg.32'';
			package: ''GeauxBeau'' with: ''GeauxBeau-dkh.55''. ].
'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 9/12/2012 16:21'!
version12SourceString
    ^ 'version12: spec
	<version: ''1.2'' imports: #(''1.2-baseline'' )>

	spec for: #''common'' do: [
		spec blessing: #''development''.
		spec project: ''MetacelloTestConfigurationOfFoo'' with: ''4.0''.
		spec 
			package: ''GeauxFaux'' with: ''GeauxFaux-tg.32'';
			package: ''GeauxBeau'' with: ''GeauxBeau-dkh.55''.

		spec for: #''nested'' do: [
			spec description: ''nested for:do: section''.
			spec package: ''GoferFoo'' with: ''GoferFoo-lr.1''. ]. ].

	spec for: #''outer'' do: [
		spec package: ''GoferFaux'' with: ''GoferFaux-tg.32''.

		spec for: #''nested'' do: [
			spec package: ''GoferBeau'' with: ''GoferBeau-dkh.55''. ]. ].

	spec for: #''other'' do: [
		spec package: ''GoferBar'' with: ''GoferBar-lr.0''. ].
'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 9/12/2012 17:02'!
version13SourceString3
    ^ 'version13: spec
	<version: ''1.3'' imports: #(''1.3-baseline'' )>

	spec for: #''common'' do: [
		spec blessing: #''development''.
		spec project: ''MetacelloTestConfigurationOfFoo'' with: ''4.0''.
		spec package: ''GeauxFaux'' with: ''GeauxFaux-tg.32''.

		spec for: #''nested'' do: [
			spec description: ''nested for:do: section''.
			spec package: ''GoferFoo'' with: ''GoferFoo-lr.1''. ]. ].

	spec for: #''outer'' do: [
		spec 
			package: ''GoferFaux'' with: ''GoferFaux-tg.32'';
			package: ''GeauxBeau'' with: ''GeauxBeau-dkh.55''.

		spec for: #''nested'' do: [
			spec package: ''GoferBeau'' with: ''GoferBeau-dkh.55''. ]. ].

	spec for: #''other'' do: [
		spec package: ''GoferBar'' with: ''GoferBar-lr.0''. ].
'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 9/12/2012 17:07'!
version13SourceString4
    ^ 'version13: spec
	<version: ''1.3'' imports: #(''1.3-baseline'' )>

	spec for: #''common'' do: [
		spec blessing: #''development''.
		spec project: ''MetacelloTestConfigurationOfFoo'' with: ''4.0''.
		spec package: ''GeauxFaux'' with: ''GeauxFaux-tg.32''.

		spec for: #''nested'' do: [
			spec description: ''nested for:do: section''.
			spec package: ''GoferFoo'' with: ''GoferFoo-lr.1''. ]. ].

	spec for: #''outer'' do: [
		spec package: ''GoferFaux'' with: ''GoferFaux-tg.32''.

		spec for: #''nested'' do: [
			spec package: ''GoferBeau'' with: ''GoferBeau-dkh.55''. ]. ].

	spec for: #''other'' do: [
		spec 
			package: ''GoferBar'' with: ''GoferBar-lr.0'';
			package: ''GeauxBeau'' with: ''GeauxBeau-dkh.55''. ].
'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 9/14/2012 09:57'!
version14SourceString
    ^ 'version14: spec
	<version: ''1.4'' imports: #(''1.4-baseline'' )>

	spec for: #''common'' do: [
		spec blessing: #''development''.
		spec package: ''GeauxFaux'' with: ''GeauxFaux-tg.32''. ].

	spec for: #''platform'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: ''4.0''.
		spec package: ''GoferBar'' with: ''GoferBar-lr.0''. ].

	spec for: #''platform1.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: ''4.0''.
		spec package: ''GeauxBeau'' with: ''GeauxBeau-dkh.55''. ].

	spec for: #''platform2.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: #''bleedingEdge''.
		spec package: ''GoferFaux'' with: ''''. ].

	spec for: #''platform2.1.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: #''bleedingEdge''.
		spec package: ''GoferFoo'' with: ''''. ].

	spec for: #''platform3.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: #''bleedingEdge''.
		spec package: ''GoferFoo'' with: ''''. ].

	spec for: #''platform3.1.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: #''bleedingEdge''.
		spec package: ''GoferFaux'' with: ''''. ].

	spec for: #''platform4.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: #''bleedingEdge''.
		spec package: ''GoferFoo'' with: ''''. ].

	spec for: #''platform4.1.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: #''bleedingEdge''.
		spec 
			package: ''GoferFoo'';
			package: ''GoferFaux'' with: ''''. ].
'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 9/14/2012 10:03'!
version14SourceStringUpdated
    ^ 'version14: spec
	<version: ''1.4'' imports: #(''1.4-baseline'' )>

	spec for: #''common'' do: [
		spec blessing: #''development''.
		spec package: ''GeauxFaux'' with: ''GeauxFaux-tg.32''. ].

	spec for: #''platform'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: ''4.0''.
		spec package: ''GoferBar'' with: ''GoferBar-lr.0''. ].

	spec for: #''platform1.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: ''4.0''.
		spec package: ''GeauxBeau'' with: ''GeauxBeau-dkh.55''. ].

	spec for: #''platform2.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: ''4.0''.
		spec package: ''GoferFaux'' with: ''GoferFaux-tg.32''. ].

	spec for: #''platform2.1.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: ''4.0''.
		spec package: ''GoferFoo'' with: ''GoferFoo-lr.1''. ].

	spec for: #''platform3.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: #''bleedingEdge''.
		spec package: ''GoferFoo'' with: ''''. ].

	spec for: #''platform3.1.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: #''bleedingEdge''.
		spec package: ''GoferFaux'' with: ''''. ].

	spec for: #''platform4.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: #''bleedingEdge''.
		spec package: ''GoferFoo'' with: ''''. ].

	spec for: #''platform4.1.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: #''bleedingEdge''.
		spec 
			package: ''GoferFoo'';
			package: ''GoferFaux'' with: ''''. ].
'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 9/14/2012 10:04'!
version14SourceStringUpdated50
    ^ 'version14: spec
	<version: ''1.4'' imports: #(''1.4-baseline'' )>

	spec for: #''common'' do: [
		spec blessing: #''development''.
		spec package: ''GeauxFaux'' with: ''GeauxFaux-tg.32''. ].

	spec for: #''platform'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: ''5.0''.
		spec package: ''GoferBar'' with: ''GoferBar-lr.1''. ].

	spec for: #''platform1.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: ''4.0''.
		spec package: ''GeauxBeau'' with: ''GeauxBeau-dkh.55''. ].

	spec for: #''platform2.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: ''5.0''.
		spec package: ''GoferFaux'' with: ''GoferFaux-tg.34''. ].

	spec for: #''platform2.1.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: ''5.0''.
		spec package: ''GoferFoo'' with: ''GoferFoo-lr.2''. ].

	spec for: #''platform3.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: #''bleedingEdge''.
		spec package: ''GoferFoo'' with: ''''. ].

	spec for: #''platform3.1.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: #''bleedingEdge''.
		spec package: ''GoferFaux'' with: ''''. ].

	spec for: #''platform4.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: #''bleedingEdge''.
		spec package: ''GoferFoo'' with: ''''. ].

	spec for: #''platform4.1.x'' do: [
		spec project: ''MetacelloTestConfigurationOfFoo'' with: #''bleedingEdge''.
		spec 
			package: ''GoferFoo'';
			package: ''GoferFaux'' with: ''''. ].
'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 9/13/2012 15:15'!
version15SourceStringA
    ^ 'version15: spec
	<version: ''1.5'' imports: #(''1.5-baseline'' )>

	spec for: #''common'' do: [
		spec blessing: #''development''.
		spec project: ''MetacelloTestConfigurationOfFoo'' with: ''4.0''.
		spec 
			package: ''GeauxFaux'' with: ''GeauxFaux-tg.32'';
			package: ''GeauxBeau'' with: ''GeauxBeau-dkh.55''. ].

	spec for: #(#''outer'' #''nested'' ) do: [
		spec package: ''GoferFaux'' with: ''GoferFaux-tg.32''. ].
'! !

!MetacelloToolBoxAPITestCase methodsFor: 'private' stamp: 'dkh 9/13/2012 19:23'!
version15SourceStringB
    ^ 'version15: spec
	<version: ''1.5'' imports: #(''1.5-baseline'' )>

	spec for: #''common'' do: [
		spec blessing: #''development''.
		spec project: ''MetacelloTestConfigurationOfFoo'' with: ''4.0''.
		spec 
			package: ''GeauxFaux'' with: ''GeauxFaux-tg.32'';
			package: ''GeauxBeau'' with: ''GeauxBeau-dkh.55''. ].

	spec for: #(#''outer'' #''nested'' ) do: [
		spec package: ''GoferFaux'' with: ''''. ].
'! !

TestCase subclass: #MetacelloVersionQueryTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloVersionQueryTestCase methodsFor: 'accessing' stamp: 'dkh 10/21/2009 13:40'!
exampleProject

	^MetacelloVersionQueryExampleConfig new project! !

!MetacelloVersionQueryTestCase methodsFor: 'accessing' stamp: 'dkh 10/21/2009 13:40'!
masterProject

	^MetacelloVersionQueryMasterConfig new project! !

!MetacelloVersionQueryTestCase methodsFor: 'accessing' stamp: 'dkh 10/21/2009 13:40'!
projectProject

	^MetacelloVersionQueryProjectConfig new project! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:04'!
testBaseline10Groups
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('Core' 'Tests' 'No UI' 'UI').
	list := version groups.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 13:42'!
testBaseline10Load
	| loadedPackages project loader |
	project := self exampleProject.
	loader := (project version: '1.0-baseline') load: 'UI'.
	loadedPackages := loader loadedPackages asArray.
	self assert: (loadedPackages indexOf: 'Example-Core')
			> 0.
	self assert: (loadedPackages indexOf: 'Example-AddOn')
			> (loadedPackages indexOf: 'Example-Core').
	self assert: (loadedPackages indexOf: 'Example-Tests')
			> (loadedPackages indexOf: 'Example-AddOn').
	self assert: (loadedPackages indexOf: 'Example-UI')
			> (loadedPackages indexOf: 'Example-AddOn').
	self assert: (loadedPackages indexOf: 'Example-TestsUI')
			> (loadedPackages indexOf: 'Example-UI').
	self assert: (loadedPackages indexOf: 'Example-TestsUI')
			> (loadedPackages indexOf: 'Example-Tests').
! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:05'!
testBaseline10Packages
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('Example-Core' 'Example-AddOn' 'Example-Tests' 'Example-UI' 'Example-TestsUI').
	list := version packages.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:05'!
testBaseline10PackagesForSpecNamed01
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('Example-Core').
	list := version packagesForSpecNamed: 'Example-Core'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:05'!
testBaseline10PackagesForSpecNamed02
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #().
	list := version packagesForSpecNamed: 'None existent'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/21/2009 14:16'!
testBaseline10PackagesForSpecNamed03
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('Example-Core' 'Example-AddOn' 'Example-Tests' 'Example-UI' 'Example-TestsUI').
	list := version packagesForSpecNamed: 'ALL'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:05'!
testBaseline10PackagesForSpecNamed04
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('Example-Core' 'Example-AddOn' ).
	list := version packagesForSpecNamed: 'Core'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:05'!
testBaseline10PackagesForSpecNamed05
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('Example-Core' 'Example-AddOn' 'Example-Tests' ).
	list := version packagesForSpecNamed: 'No UI'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/21/2009 14:35'!
testBaseline10PackagesForSpecNamed06
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('Example-Core' 'Example-AddOn' 'Example-Tests' 'Example-TestsUI').
	list := version packagesForSpecNamed: 'UI'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:05'!
testBaseline10PackagesForSpecNamed07
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('Example-Core' 'Example-AddOn' 'Example-Tests' 'Example-UI' 'Example-TestsUI').
	list := version packagesForSpecNamed: 'default'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:21'!
testBaseline10PackagesForSpecNamed08
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('Example-Core' 'Example-AddOn' 'Example-Tests' 'Example-TestsUI' 'Example-UI' 'Misc-UTF8' ).
	list := version allPackagesForSpecNamed: { 'No UI'. 'UI'. 'Tests'. }.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:22'!
testBaseline10Projects
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.
	expected := #('UTF8').
	list := version projects.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'test resolveToLoadableSpecs' stamp: 'DaleHenrichs 1/19/2010 12:12'!
testBaseline10ResolveToLoadableSpecs01
	| project version expected list |
	project := self exampleProject.
	version := project version: '1.0-baseline'.

	expected := #('Example-Core' 'UTF8').
	list := version resolveToLoadableSpecs: #('Example-Core').
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].

	expected := #('Example-AddOn' 'Example-Core' 'UTF8').
	list := version resolveToLoadableSpecs: #('Example-AddOn').
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].

	expected := #('Example-Core' 'Example-AddOn' 'Example-Tests' 'UTF8').
	list := version resolveToLoadableSpecs: #('No UI').
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].
! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:06'!
testBaseline20Groups
	| project version expected list |
	project := self projectProject.
	version := project version: '2.0-baseline'.
	expected := #('Core' 'Tests').
	list := version groups.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 2/8/2010 17:11'!
testBaseline20Load
	| project version |
	project := self exampleProject.
	version := project currentVersionAgainst: #('Core') "in 2.1 'Core' is a package and in 2.0 'Core' is a group ... no errors"! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:06'!
testBaseline20Packages
	| project version expected list |
	project := self projectProject.
	version := project version: '2.0-baseline'.
	expected := #('Project-Core' 'Project-Tests').
	list := version packages.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:06'!
testBaseline20PackagesForSpecNamed01
	| project version expected list |
	project := self projectProject.
	version := project version: '2.0-baseline'.
	expected := #('Project-Core').
	list := version packagesForSpecNamed: 'Core'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:23'!
testBaseline20PackagesForSpecNamed02
	| project version expected list |
	project := self projectProject.
	version := project version: '2.0-baseline'.
	expected := #('Project-Core' 'Example-Core' 'Example-AddOn' 'Example-Tests' 'Example-UI' 'Example-TestsUI' 'Misc-UTF8').
	list := version allPackagesForSpecNamed: 'Core'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:06'!
testBaseline20PackagesForSpecNamed03
	| project version expected list |
	project := self projectProject.
	version := project version: '2.0-baseline'.
	expected := #('Project-Core' 'Project-Tests').
	list := version packagesForSpecNamed: 'ALL'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:23'!
testBaseline20PackagesForSpecNamed04
	| project version expected list |
	project := self projectProject.
	version := project version: '2.0-baseline'.
	expected := #('Project-Core' 'Project-Tests' 'Example-Core' 'Example-AddOn' 'Example-Tests' 'Example-UI' 'Example-TestsUI' 'Misc-UTF8').
	list := version allPackagesForSpecNamed: 'ALL'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:06'!
testBaseline20Projects
	| project version expected list |
	project := self projectProject.
	version := project version: '2.0-baseline'.
	expected := #('Example ALL').
	list := version projects.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:24'!
testBaseline21PackagesForSpecNamed01
	| project version expected list |
	project := self projectProject.
	version := project version: '2.1-baseline'.
	expected := #('Project-Core' 'Example-Core' 'Example-AddOn' 'Misc-UTF8' 'Misc-MD5').
	list := version allPackagesForSpecNamed: 'Core'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:25'!
testBaseline21PackagesForSpecNamed02
	| project version expected list |
	project := self projectProject.
	version := project version: '2.1-baseline'.
	expected := #('Project-Core' 'Example-Core' 'Example-AddOn' 'Project-Tests' 'Example-Tests' 'Misc-UTF8' 'Misc-MD5').
	list := version allPackagesForSpecNamed: 'Tests'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'dkh 10/21/2009 14:06'!
testBaseline30Groups
	| project version expected list |
	project := self masterProject.
	version := project version: '3.0-baseline'.
	expected := #('Core' 'Tests').
	list := version groups.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/21/2009 16:23'!
testBaseline30Packages
	| project version expected list |
	project := self masterProject.
	version := project version: '3.0-baseline'.
	expected := #('Master-Core' 'Master-Tests' 'Master-Platform' ).
	list := version packages.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:26'!
testBaseline30PackagesForSpecNamed01
	| project version expected list |
	project := self masterProject.
	version := project version: '3.0-baseline'.
	expected := #('Master-Core' 'Master-Platform' 'Project-Core' 'Example-Core' 'Example-AddOn' 'Misc-UTF8' 'Misc-MD5' 'Misc-XML').
	list := version allPackagesForSpecNamed: 'Core'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:26'!
testBaseline30PackagesForSpecNamed02
	| project version expected list |
	project := self masterProject.
	version := project version: '3.0-baseline'.
	expected := #('Master-Core' 'Master-Platform' 'Project-Core' 'Example-Core' 'Example-AddOn' 'Project-Tests' 'Example-Tests' 'Master-Tests' 'Misc-UTF8' 'Misc-MD5' 'Misc-XML').
	list := version allPackagesForSpecNamed: 'Tests'.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:27'!
testBaseline30PackagesForSpecNamed03
	| project version expected list |
	project := self masterProject.
	version := project version: '3.0-baseline'.
	expected := #('Master-Core' 'Master-Platform' 'Project-Core' 'Example-Core' 'Example-AddOn' 'Project-Tests' 'Example-Tests' 'Master-Tests' 'Misc-UTF8' 'Misc-MD5' 'Misc-XML').
	list := version allPackagesForSpecNamed: { 'Tests'. }.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'TestRunner 10/22/2009 08:27'!
testBaseline30Projects
	| project version expected list |
	project := self masterProject.
	version := project version: '3.0-baseline'.
	expected := #('Project Core' 'Project Tests' 'XML').
	list := version projects.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'test resolveToLoadableSpecs' stamp: 'DaleHenrichs 1/19/2010 15:18'!
testBaseline30ResolveToLoadableSpecs01
	| project version expected list |
	project := self masterProject.
	version := project version: '3.0-baseline'.

	expected := #('Master-Core' 'Master-Platform' 'Project Core' 'XML').
	list := version resolveToLoadableSpecs: #('Core').
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].


! !

!MetacelloVersionQueryTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 1/22/2010 11:41'!
testBaseline31PackagesForSpecNamed03
	| project version expected list |
	project := self masterProject.
	version := project version: '3.1-baseline'.
	expected := #('Master-Core' 'Master-Platform' 'Project-Core' 'Example-Core' 'Example-AddOn' 'Project-Tests' 'Example-Tests' 'Master-Tests' 'Misc-UTF8' 'Misc-MD5' 'Misc-XML').
	list := version allPackagesForSpecNamed: { 'Tests'. }.
	self assert: (list size = expected size).
	list do: [:pkg |
		self assert: (expected includes: pkg name) ].! !

!MetacelloVersionQueryTestCase methodsFor: 'test latest filter' stamp: 'dkh 12/21/2009 14:59'!
testLatestFilter
	| project |
	project := MetacelloVersionQueryLatestVersionConfig new project.

	self assert: (project latestVersionMatching: '*.*') versionString = '1.2'.
	self assert: (project latestVersionMatching: '*.*.*') versionString = '1.1.2'.
	self assert: (project 
		latestVersionMatching: '*.*'
		includedBlessings: #(#development)) versionString = '1.3'.
	self assert: (project 
		latestVersionMatching: '*.*.*'
		includedBlessings: #(#development)) versionString = '1.3.2'.
	self assert: (project 
		latestVersionMatching: '*.*'
		excludedBlessings: #()) versionString = '1.3'.
	self assert: (project 
		latestVersionMatching: '*.?'
		includedBlessings: #(#development)) versionString = '1.3.2'.
	self assert: (project 
		latestVersionMatching: '*.?'
		excludedBlessings: #()) versionString = '1.3.2'.
	self assert: (project latestVersionMatching: '*') = nil
! !

GoferCleanup subclass: #MetacelloTestsGoferCleanup
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Gofer'!

!MetacelloTestsGoferCleanup methodsFor: 'cleaning' stamp: 'DaleHenrichs 12/18/2010 20:10'!
cleanupProtocols: aWorkingCopy
	"Not needed - for faster test running"! !

TestResource subclass: #MetacelloAlternateResource
	instanceVariableNames: 'versionReferences monticelloRepository'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Resources'!

!MetacelloAlternateResource methodsFor: 'accessing' stamp: 'dkh 1/12/2010 12:39'!
monticelloRepository
	^ monticelloRepository! !

!MetacelloAlternateResource methodsFor: 'running' stamp: 'dkh 1/12/2010 12:39'!
setUp
	super setUp.
	self
		setUpVersionReferences;
		setUpMonticelloRepository! !

!MetacelloAlternateResource methodsFor: 'running' stamp: 'dkh 9/4/2012 23:23'!
setUpMonticelloRepository
    "This method builds a fake repository with the version references from #buildReferences."

    monticelloRepository := MCDictionaryRepository new.
    versionReferences
        do: [ :reference | 
            monticelloRepository
                basicStoreVersion:
                    (MCVersion new
                        setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                        info:
                            (MCVersionInfo
                                name: reference name
                                id: UUID new
                                message: 'This is a mock version'
                                date: Date today
                                time: Time now
                                author: reference author
                                ancestors: #())
                        snapshot:
                            (MCSnapshot
                                fromDefinitions:
                                    (Array
                                        with:
                                            (MCOrganizationDefinition categories: (Array with: reference packageName asSymbol))
                                        with:
                                            (MCClassDefinition
                                                name: reference packageName asSymbol
                                                superclassName: #'Object'
                                                category: reference packageName asSymbol
                                                instVarNames: #()
                                                comment: '')))
                        dependencies: #()) ]! !

!MetacelloAlternateResource methodsFor: 'running' stamp: 'DaleHenrichs 01/20/2010 17:05'!
setUpVersionReferences
	"self reset"

	versionReferences := OrderedCollection new.
	versionReferences
		add: (GoferVersionReference name: 'GoferBar-dkh.24');
		add: (GoferVersionReference name: 'GoferBar-dkh.25');
		add: (GoferVersionReference name: 'GoferFoo-dkh.75');
		add: (GoferVersionReference name: 'GoferFoo-dkh.104')! !

!MetacelloAlternateResource methodsFor: 'accessing' stamp: 'dkh 1/12/2010 12:39'!
versionReferences
	^ versionReferences! !

TestResource subclass: #MetacelloAtomicConfigurationResource
	instanceVariableNames: 'monticelloRepository'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Resources'!

!MetacelloAtomicConfigurationResource classSide methodsFor: 'accessing' stamp: 'DaleHenrichs 12/20/2010 12:21'!
project

	^self new project! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFan' stamp: 'DaleHenrichs 3/18/2010 12:08'!
baseline20Fan: spec 
	"self reset"
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #baseline.
		spec 
			package: 'GoferFan';
			yourself ].
! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/18/2010 09:31'!
baseline20Foo: spec 
	"self reset"
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #baseline.
		spec 
			package: 'GoferBar';
			package: 'GoferFoo';
			package: 'GoferBeau';
			package: 'GoferFaux';
			yourself ].
! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFan' stamp: 'DaleHenrichs 3/18/2010 12:08'!
baseline20MethodSourceFan

	^(self class sourceCodeAt: #baseline20Fan:) asString

! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/16/2010 10:12'!
baseline20MethodSourceFoo

	^(self class sourceCodeAt: #baseline20Foo:) asString

! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/18/2010 12:16'!
baseline25Foo: spec 
	"self reset"
	<version: '2.5-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #baseline.
		spec 
			package: 'GoferFoo' with: [spec requires: 'GoferFan' ];
			yourself.
		spec 
			project: 'GoferFan' with: [ "requires GoferBeau"
				spec
					className: 'MetacelloTestConfigurationOfAtomicFan';
					versionString: '2.0-baseline';
					loads: 'GoferFan';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/18/2010 12:05'!
baseline25MethodSourceFoo

	^(self class sourceCodeAt: #baseline25Foo:) asString

! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFan' stamp: 'DaleHenrichs 4/14/2010 10:55'!
baseline31Fan: spec 
	"self reset"
	<version: '3.1-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec postLoadDoIt: #postLoad31baseline.
		spec 
			package: 'GoferBar';
			package: 'GoferBeau' with: [ 
				spec 
					requires: 'GoferBar';
					includes: #('GoferFoo' ) ]; 
			package: 'GoferFar' with: [ spec requires: #('GoferFoo' ) ]; 
			yourself.
		spec 
			project: 'GoferFoo' with: [ "requires GoferBeau"
				spec
					className: 'MetacelloTestConfigurationOfLinearFoo';
					versionString: '2.0';
					loads: 'GoferFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFan' stamp: 'DaleHenrichs 4/14/2010 10:48'!
baseline31MethodSourceFan

	^(self class sourceCodeAt: #baseline31Fan:) asString

! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 6/24/2010 16:53'!
baseline60Foo: spec 
	"self reset"
	<version: '6.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with:'GoferFoo-lr.4';
			package: 'GoferBar' with: 'GoferBar-lr.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.34';
			package: 'GoferBeau' with: 'GoferBeau-dkh.55';
			yourself.
		spec
			group: '1' with: #('GoferFoo' 'GoferBar');
			group: '2' with: #('1' 'GoferFaux');
			yourself ].
! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 6/24/2010 16:02'!
baseline60MethodSourceFoo

	^(self class sourceCodeAt: #baseline60Foo:) asString

! !

!MetacelloAtomicConfigurationResource methodsFor: 'Issue 86' stamp: 'DaleHenrichs 6/24/2010 15:45'!
baseline60MethodSourceProjectIssue86

	^(self class sourceCodeAt: #baseline60ProjectIssue86:) asString

! !

!MetacelloAtomicConfigurationResource methodsFor: 'Issue 86' stamp: 'DaleHenrichs 6/24/2010 16:54'!
baseline60ProjectIssue86: spec 
	"projects and packages"
	"self reset"
	<version: '6.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'A' with: [
				spec
					className: 'MetacelloTestConfigurationOfLinearFoo';
					versionString: '6.0';
					loads: #('1');
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'B' with: [
				spec
					className: 'MetacelloTestConfigurationOfLinearFoo';
					versionString: '6.0';
					loads: #('2');
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 6/24/2010 16:54'!
baseline61Foo: spec 
	"self reset"
	<version: '6.1'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with:'GoferFoo-lr.4';
			package: 'GoferBar' with: 'GoferBar-lr.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.34';
			package: 'GoferBeau' with: 'GoferBeau-dkh.55';
			yourself.
		spec
			group: '1' with: #('GoferFoo' 'GoferBar');
			group: '2' with: #('GoferFoo' 'GoferBeau');
			yourself ].
! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 6/24/2010 16:52'!
baseline61MethodSourceFoo

	^(self class sourceCodeAt: #baseline61Foo:) asString

! !

!MetacelloAtomicConfigurationResource methodsFor: 'Issue 86' stamp: 'DaleHenrichs 6/24/2010 16:54'!
baseline61MethodSourceProjectIssue86

	^(self class sourceCodeAt: #baseline61ProjectIssue86:) asString

! !

!MetacelloAtomicConfigurationResource methodsFor: 'Issue 86' stamp: 'DaleHenrichs 6/24/2010 17:03'!
baseline61ProjectIssue86: spec 
	"projects and packages"
	"self reset"
	<version: '6.1'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'A' with: [
				spec
					className: 'MetacelloTestConfigurationOfLinearFoo';
					versionString: '6.1';
					loads: #('1');
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'B' with: [
				spec
					className: 'MetacelloTestConfigurationOfLinearFoo';
					versionString: '6.1';
					loads: #('2');
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 6/24/2010 17:19'!
baseline62Foo: spec 
	"self reset"
	<version: '6.2'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with:'GoferFoo-lr.4';
			package: 'GoferBar' with: 'GoferBar-lr.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.34';
			package: 'GoferBeau' with: 'GoferBeau-dkh.55';
			yourself.
		spec
			group: '1' with: #('GoferFoo' 'GoferBar');
			group: '2' with: #('GoferFoo' );
			yourself ].
! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 6/24/2010 17:19'!
baseline62MethodSourceFoo

	^(self class sourceCodeAt: #baseline62Foo:) asString

! !

!MetacelloAtomicConfigurationResource methodsFor: 'Issue 86' stamp: 'DaleHenrichs 6/24/2010 17:20'!
baseline62MethodSourceProjectIssue86

	^(self class sourceCodeAt: #baseline62ProjectIssue86:) asString

! !

!MetacelloAtomicConfigurationResource methodsFor: 'Issue 86' stamp: 'DaleHenrichs 6/24/2010 17:20'!
baseline62ProjectIssue86: spec 
	"projects and packages"
	"self reset"
	<version: '6.2'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'A' with: [
				spec
					className: 'MetacelloTestConfigurationOfLinearFoo';
					versionString: '6.2';
					loads: #('1');
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'B' with: [
				spec
					className: 'MetacelloTestConfigurationOfLinearFoo';
					versionString: '6.2';
					loads: #('2');
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/16/2010 11:43'!
linearProjectMethodSource

	^(self class sourceCodeAt: #project) asString copyReplaceAll: 'atomic' with: 'linear'

! !

!MetacelloAtomicConfigurationResource methodsFor: 'accessing' stamp: 'DaleHenrichs 3/16/2010 10:12'!
monticelloRepository
	^ monticelloRepository! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFan' stamp: 'DaleHenrichs 4/14/2010 10:56'!
postLoad31baseline
	"Throw an error if GoferFar isn't loaded"

	Smalltalk at: #GoferFar ifAbsent: [ self error: 'GoferFar should be loaded' ]! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFan' stamp: 'DaleHenrichs 4/14/2010 10:50'!
postLoad31baselineMethodSource

	^(self class sourceCodeAt: #postLoad31baseline) asString

! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/16/2010 10:13'!
project
	"self reset"

	| constructor project |
	"Construct Metacello project"
	constructor := MetacelloVersionConstructor on: self.
	project := constructor project.
	project loader: 
		((project loaderClass new)
			shouldDisablePackageCache: true;
			yourself).
	project loadType: #atomic.
	^project
! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'DaleHenrichs 12/20/2010 12:22'!
projectClassMethodSource

	^(self class class sourceCodeAt: #project) asString

! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/16/2010 10:12'!
projectMethodSource

	^(self class sourceCodeAt: #project) asString

! !

!MetacelloAtomicConfigurationResource methodsFor: 'running' stamp: 'DaleHenrichs 6/24/2010 15:45'!
setUp
	super setUp.
	self
		setUpMonticelloRepository;
		setUpConfigurationOfAtomicFoo;
		setUpConfigurationOfLinearFoo;
		setUpConfigurationOfAtomicFan;
		setUpConfigurationOfUmbrellaA;
		setUpConfigurationOfUmbrellaB;
		setUpConfigurationOfProjectIssue86;
		yourself! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFan' stamp: 'dkh 9/4/2012 23:23'!
setUpConfigurationOfAtomicFan
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfAtomicFan-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline20Fan:'
        category: 'cat'
        timeStamp: ''
        source: self baseline20MethodSourceFan).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline31Fan:'
        category: 'cat'
        timeStamp: ''
        source: self baseline31MethodSourceFan).
    (MCMethodDefinition
        className: className asString
        selector: 'postLoad31baseline'
        category: 'cat'
        timeStamp: ''
        source: self postLoad31baselineMethodSource)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'dkh 9/4/2012 23:23'!
setUpConfigurationOfAtomicFoo
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfAtomicFoo-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline20Foo:'
        category: 'cat'
        timeStamp: ''
        source: self baseline20MethodSourceFoo).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline25Foo:'
        category: 'cat'
        timeStamp: ''
        source: self baseline25MethodSourceFoo).
    (MCMethodDefinition
        className: className asString
        selector: 'version20Foo:'
        category: 'cat'
        timeStamp: ''
        source: self version20MethodSourceFoo)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'dkh 9/4/2012 23:23'!
setUpConfigurationOfLinearFoo
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfLinearFoo-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self linearProjectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline20Foo:'
        category: 'cat'
        timeStamp: ''
        source: self baseline20MethodSourceFoo).
    (MCMethodDefinition
        className: className asString
        selector: 'version20Foo:'
        category: 'cat'
        timeStamp: ''
        source: self version20MethodSourceFoo).
    (MCMethodDefinition
        className: className asString
        selector: 'version50Foo:'
        category: 'cat'
        timeStamp: ''
        source: self version50MethodSourceFoo).
    (MCMethodDefinition
        className: className asString
        selector: 'version51Foo:'
        category: 'cat'
        timeStamp: ''
        source: self version51MethodSourceFoo).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline60Foo:'
        category: 'cat'
        timeStamp: ''
        source: self baseline60MethodSourceFoo).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline61Foo:'
        category: 'cat'
        timeStamp: ''
        source: self baseline61MethodSourceFoo).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline62Foo:'
        category: 'cat'
        timeStamp: ''
        source: self baseline62MethodSourceFoo)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloAtomicConfigurationResource methodsFor: 'Issue 86' stamp: 'dkh 9/4/2012 23:23'!
setUpConfigurationOfProjectIssue86
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfProjectIssue86-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self linearProjectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline60ProjectIssue86:'
        category: 'cat'
        timeStamp: ''
        source: self baseline60MethodSourceProjectIssue86).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline61ProjectIssue86:'
        category: 'cat'
        timeStamp: ''
        source: self baseline61MethodSourceProjectIssue86).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline62ProjectIssue86:'
        category: 'cat'
        timeStamp: ''
        source: self baseline62MethodSourceProjectIssue86)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfUmbrella' stamp: 'dkh 9/4/2012 23:23'!
setUpConfigurationOfUmbrellaA
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfUmbrellaA-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'version50Umbrella:'
        category: 'cat'
        timeStamp: ''
        source: self version50MethodSourceUmbrella)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfUmbrella' stamp: 'dkh 9/4/2012 23:24'!
setUpConfigurationOfUmbrellaB
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfUmbrellaB-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'version51Umbrella:'
        category: 'cat'
        timeStamp: ''
        source: self version51MethodSourceUmbrella)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloAtomicConfigurationResource methodsFor: 'running' stamp: 'DaleHenrichs 3/16/2010 10:12'!
setUpMonticelloRepository
	"This method builds a fake repository with the version references from #buildReferences."
	"self reset"

	monticelloRepository := MCDictionaryRepository new.
! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/18/2010 09:29'!
version20Foo: spec 
	"self reset"
	<version: '2.0' imports: #('2.0-baseline')>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #release.
		spec 
			package: 'GoferBar' with: 'GoferBar-dkh.1';
			package: 'GoferFoo' with: 'GoferFoo-dkh.4';
			package: 'GoferBeau' with: 'GoferBeau-dkh.15';
			package: 'GoferFaux' with: 'GoferFaux-tg.30';
			yourself ].
! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 3/18/2010 09:29'!
version20MethodSourceFoo

	^(self class sourceCodeAt: #version20Foo:) asString

! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 6/10/2010 16:37'!
version50Foo: spec 
	"self reset"
	<version: '5.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #release.
		spec 
			package: 'GoferUmbrella' with: 'GoferUmbrella-dkh.4';
			yourself ].
! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 6/10/2010 17:40'!
version50MethodSourceFoo

	^(self class sourceCodeAt: #version50Foo:) asString

! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfUmbrella' stamp: 'DaleHenrichs 6/10/2010 17:39'!
version50MethodSourceUmbrella

	^(self class sourceCodeAt: #version50Umbrella:) asString

! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfUmbrella' stamp: 'DaleHenrichs 6/10/2010 17:30'!
version50Umbrella: spec 
	"self reset"
	<version: '5.0'>
	
	spec for: #common do: [
		spec 
			project: 'Umbrella' with: [
				spec
					className: 'MetacelloTestConfigurationOfLinearFoo';
					versionString: '5.0';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 6/10/2010 16:37'!
version51Foo: spec 
	"self reset"
	<version: '5.1'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #release.
		spec 
			package: 'GoferUmbrella' with: 'GoferUmbrella-lr.5';
			yourself ].
! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfAtomicFoo' stamp: 'DaleHenrichs 6/10/2010 17:40'!
version51MethodSourceFoo

	^(self class sourceCodeAt: #version51Foo:) asString

! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfUmbrella' stamp: 'DaleHenrichs 6/10/2010 17:39'!
version51MethodSourceUmbrella

	^(self class sourceCodeAt: #version51Umbrella:) asString

! !

!MetacelloAtomicConfigurationResource methodsFor: 'ConfigurationOfUmbrella' stamp: 'DaleHenrichs 6/10/2010 17:30'!
version51Umbrella: spec 
	"self reset"
	<version: '5.1'>
	
	spec for: #common do: [
		spec 
			project: 'Umbrella' with: [
				spec
					className: 'MetacelloTestConfigurationOfLinearFoo';
					versionString: '5.1';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

TestResource subclass: #MetacelloAtomicMonticelloResource
	instanceVariableNames: 'versionReferences monticelloRepository'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Resources'!

!MetacelloAtomicMonticelloResource methodsFor: 'accessing' stamp: 'DaleHenrichs 3/16/2010 10:17'!
monticelloRepository
	^ monticelloRepository! !

!MetacelloAtomicMonticelloResource methodsFor: 'running' stamp: 'DaleHenrichs 6/9/2010 12:10'!
setUp
	super setUp.
	self
		setUpVersionReferences;
		setUpMonticelloRepository;
		setUpDependency;
		setUpNewerDependency! !

!MetacelloAtomicMonticelloResource methodsFor: 'running' stamp: 'dkh 9/4/2012 23:24'!
setUpDependency
    "self reset"

    | reference |
    reference := GoferVersionReference name: 'GoferUmbrella-dkh.4'.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot:
                    (MCSnapshot
                        fromDefinitions:
                            (Array
                                with:
                                    (MCOrganizationDefinition categories: (Array with: reference packageName asSymbol))
                                with:
                                    (MCClassDefinition
                                        name: (reference packageName copyWithout: $-) asSymbol
                                        superclassName: #'Object'
                                        category: reference packageName asSymbol
                                        instVarNames: #()
                                        comment: '')))
                dependencies:
                    (Array
                        with:
                            (MCVersionDependency
                                package: (MetacelloTestsMCPackage new name: 'GoferBarDependency')
                                info: (monticelloRepository versionInfoFromVersionNamed: 'GoferBarDependency-lr.30'))
                        with:
                            (MCVersionDependency
                                package: (MetacelloTestsMCPackage new name: 'GoferFooDependency')
                                info: (monticelloRepository versionInfoFromVersionNamed: 'GoferFooDependency-lr.30'))))! !

!MetacelloAtomicMonticelloResource methodsFor: 'running' stamp: 'dkh 9/4/2012 23:24'!
setUpMonticelloRepository
    "This method builds a fake repository with the version references from #buildReferences."

    monticelloRepository := MCDictionaryRepository new.
    versionReferences
        do: [ :assoc | 
            | reference superclassName |
            reference := assoc key.
            superclassName := assoc value.
            monticelloRepository
                basicStoreVersion:
                    (MCVersion new
                        setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                        info:
                            (MCVersionInfo
                                name: reference name
                                id: UUID new
                                message: 'This is a mock version'
                                date: Date today
                                time: Time now
                                author: reference author
                                ancestors: #())
                        snapshot:
                            (MCSnapshot
                                fromDefinitions:
                                    (Array
                                        with:
                                            (MCOrganizationDefinition categories: (Array with: reference packageName asSymbol))
                                        with:
                                            (MCClassDefinition
                                                name: (reference packageName copyWithout: $-) asSymbol
                                                superclassName: superclassName
                                                category: reference packageName asSymbol
                                                instVarNames: #()
                                                comment: '')))
                        dependencies: #()) ]! !

!MetacelloAtomicMonticelloResource methodsFor: 'running' stamp: 'dkh 9/4/2012 23:24'!
setUpNewerDependency
    "self reset"

    | reference |
    reference := GoferVersionReference name: 'GoferUmbrella-lr.5'.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot:
                    (MCSnapshot
                        fromDefinitions:
                            (Array
                                with:
                                    (MCOrganizationDefinition categories: (Array with: reference packageName asSymbol))
                                with:
                                    (MCClassDefinition
                                        name: (reference packageName copyWithout: $-) asSymbol
                                        superclassName: #'Object'
                                        category: reference packageName asSymbol
                                        instVarNames: #()
                                        comment: '')))
                dependencies:
                    (Array
                        with:
                            (MCVersionDependency
                                package: (MetacelloTestsMCPackage new name: 'GoferBarDependency')
                                info: (monticelloRepository versionInfoFromVersionNamed: 'GoferBarDependency-lr.35'))
                        with:
                            (MCVersionDependency
                                package: (MetacelloTestsMCPackage new name: 'GoferFooDependency')
                                info: (monticelloRepository versionInfoFromVersionNamed: 'GoferFooDependency-lr.35'))))! !

!MetacelloAtomicMonticelloResource methodsFor: 'running' stamp: 'DaleHenrichs 6/11/2010 10:18'!
setUpVersionReferences
	"self reset"

	versionReferences := OrderedCollection new.
	versionReferences
		add: ((GoferVersionReference name: 'GoferFan-dkh.1') -> #GoferFar);
		add: ((GoferVersionReference name: 'GoferBar-dkh.1') -> #Object);
		add: ((GoferVersionReference name: 'GoferFoo-dkh.4') -> #GoferBeau);
		add: ((GoferVersionReference name: 'GoferFoo-dkh.5') -> #GoferBeau);
		add: ((GoferVersionReference name: 'GoferBeau-dkh.15') -> #GoferBar);
		add: ((GoferVersionReference name: 'GoferFaux-tg.30') -> #Object);
		add: ((GoferVersionReference name: 'GoferFar-dkh.4') -> #GoferFoo);
		add: ((GoferVersionReference name: 'GoferBarDependency-dkh.4') -> #Object);
		add: ((GoferVersionReference name: 'GoferFooDependency-lr.4') -> #Object);
		add: ((GoferVersionReference name: 'GoferBarDependency-lr.30') -> #Object);
		add: ((GoferVersionReference name: 'GoferFooDependency-lr.30') -> #Object);
		add: ((GoferVersionReference name: 'GoferBarDependency-lr.35') -> #Object);
		add: ((GoferVersionReference name: 'GoferFooDependency-lr.35') -> #Object);
		yourself
	! !

!MetacelloAtomicMonticelloResource methodsFor: 'accessing' stamp: 'DaleHenrichs 3/16/2010 10:17'!
versionReferences
	^ versionReferences! !

TestResource subclass: #MetacelloConfigurationResource
	instanceVariableNames: 'monticelloRepository'
	classVariableNames: 'ProjectAttributes'
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Resources'!

!MetacelloConfigurationResource classSide methodsFor: 'accessing' stamp: 'dkh 6/12/2012 15:41:23.319'!
project

	^self new project! !

!MetacelloConfigurationResource classSide methodsFor: 'accessing' stamp: 'dkh 6/12/2012 15:41:23.319'!
projectAttributes

	ProjectAttributes == nil ifTrue: [ ^#() ].
	^ProjectAttributes! !

!MetacelloConfigurationResource classSide methodsFor: 'accessing' stamp: 'dkh 6/12/2012 15:41:23.319'!
projectAttributes: aCollection

	ProjectAttributes := aCollection! !

!MetacelloConfigurationResource methodsFor: 'Issue 77' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline10B: spec 
	"self reset"
	<version: '1.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'C' with: [
				spec
					className: 'MetacelloTestConfigurationOfIssue77C';
					loads: #('GoferFoo');
					versionString: '1.2';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			package: 'GoferBeau' with: 'GoferBeau-dkh.53';
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'Issue 77' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline10D: spec 
	"self reset"
	<version: '1.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'C' with: [
				spec
					className: 'MetacelloTestConfigurationOfIssue77C';
					loads: #('GoferFoo');
					versionString: '1.3';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			package: 'GoferBar' with: [
				spec 
					file:'GoferBar-lr.1' ];
			group: 'default' with: #('GoferBar');
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'Issue 77' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline10MethodSourceB

	^(self class sourceCodeAt: #baseline10B:) asString

! !

!MetacelloConfigurationResource methodsFor: 'Issue 77' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline10MethodSourceD

	^(self class sourceCodeAt: #baseline10D:) asString

! !

!MetacelloConfigurationResource methodsFor: 'Issue 77' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline12C: spec 
	"self reset"
	<version: '1.2'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.1';
			package: 'GeauxBeau' with: 'GeauxBeau-dkh.55';
			yourself. ].
! !

!MetacelloConfigurationResource methodsFor: 'Issue 77' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline12MethodSourceC

	^(self class sourceCodeAt: #baseline12C:) asString

! !

!MetacelloConfigurationResource methodsFor: 'Issue 77' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline13C: spec 
	"self reset"
	<version: '1.3'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.4';
			package: 'GeauxBeau' with: 'GeauxBeau-dkh.56';
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'Issue 77' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline13MethodSourceC

	^(self class sourceCodeAt: #baseline13C:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline20Fan: spec 
	"self reset"
	<version: '2.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '2.0';
					loads: #('GoferFaux' 'GoferBeau');
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'Far' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '2.0';
					loads: #('GoferBeau');
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline20Foo: spec 
	"self reset"
	<version: '2.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.1';
			package: 'GoferBar' with: 'GoferBar.branch-lr.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.30';
			package: 'GoferBeau' with: 'GoferBeau-dkh.25';
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline20MethodSourceFan

	^(self class sourceCodeAt: #baseline20Fan:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline20MethodSourceFoo

	^(self class sourceCodeAt: #baseline20Foo:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline30Fan: spec 
	"self reset"
	<version: '3.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '3.0';
					loads: #('GoferFaux' 'GoferBeau');
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline30Foo: spec 
	"self reset"
	<version: '3.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with: [
				spec 
					preLoadDoIt: #preloadDoIt;
					file: 'GoferFoo-lr.1' ];
			package: 'GoferBar' with: 'GoferBar.branch-lr.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.30';
			package: 'GoferBeau' with: 'GoferBeau-dkh.53';
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline30MethodSourceFan

	^(self class sourceCodeAt: #baseline30Fan:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline30MethodSourceFoo

	^(self class sourceCodeAt: #baseline30Foo:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline35Fan: spec 
	"self reset"
	<version: '3.5'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '3.5';
					loads: #('GoferFaux' 'GoferBeau');
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline35Foo: spec 
	"self reset"
	<version: '3.5'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with:'GoferFoo-lr.1';
			package: 'GoferBar' with: 'GoferBar-lr.0';
			package: 'GoferFaux' with: 'GoferFaux-tg.31';
			package: 'GoferBeau' with: 'GoferBeau-dkh.54';
			yourself.
		spec
			group: '1' with: #('GoferFoo' 'GoferBar');
			group: '2' with: #('GoferFoo' 'GoferFaux');
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline35MethodSourceFan

	^(self class sourceCodeAt: #baseline35Fan:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline35MethodSourceFoo

	^(self class sourceCodeAt: #baseline35Foo:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFie' stamp: 'dkh 9/11/2012 16:03:49'!
baseline35MethodSourceProjectFie

	^(self class sourceCodeAt: #baseline35ProjectFie:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFie' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline35ProjectFie: spec 
	"just projects"
	"self reset"

	<version: '3.5'>
	spec for: #common do: [
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '3.5';
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'Feaux' with: [
				spec
					className: 'MetacelloTestConfigurationOfFeaux';
					versionString: '4.0';
					file: 'MetacelloTestConfigurationOfFeaux';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40Fan: spec 
	"self reset"
	<version: '4.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '4.0';
					loads: #('GoferFaux' 'GoferBeau');
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFeaux' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40Feaux: spec 
	"self reset"
	<version: '4.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GeauxFoo' with:'GeauxFoo-lr.1';
			package: 'GeauxBar' with: 'GeauxBar.branch-lr.2';
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40Foo: spec 
	"self reset"
	<version: '4.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with:'GoferFoo-lr.1';
			package: 'GoferBar' with: 'GoferBar-lr.0';
			package: 'GoferFaux' with: 'GoferFaux-tg.32';
			package: 'GoferBeau' with: 'GoferBeau-dkh.55';
			yourself.
		spec
			group: '1' with: #('GoferFoo' 'GoferBar');
			group: '2' with: #('GoferFoo' 'GoferFaux');
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40MethodSourceFan

	^(self class sourceCodeAt: #baseline40Fan:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFeaux' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40MethodSourceFeaux

	^(self class sourceCodeAt: #baseline40Feaux:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40MethodSourceFoo

	^(self class sourceCodeAt: #baseline40Foo:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFee' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40MethodSourceProjectFee

	^(self class sourceCodeAt: #baseline40ProjectFee:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFie' stamp: 'dkh 9/11/2012 16:03:49'!
baseline40MethodSourceProjectFie

	^(self class sourceCodeAt: #baseline40ProjectFie:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFoe' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40MethodSourceProjectFoe

	^(self class sourceCodeAt: #baseline40ProjectFoe:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFum' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40MethodSourceProjectFum

	^(self class sourceCodeAt: #baseline40ProjectFum:) asString

! !

!MetacelloConfigurationResource methodsFor: 'Issue 95' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40MethodSourceProjectInfinite

	^(self class sourceCodeAt: #baseline40ProjectInfinite:) asString

! !

!MetacelloConfigurationResource methodsFor: 'Issue 95' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40MethodSourceProjectIssue95

	^(self class sourceCodeAt: #baseline40ProjectIssue95:) asString

! !

!MetacelloConfigurationResource methodsFor: 'Issue 95' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40MethodSourceProjectLoop

	^(self class sourceCodeAt: #baseline40ProjectLoop:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFee' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40ProjectFee: spec 
	"projects and packages"
	"self reset"
	<version: '4.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '4.0';
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself.
		spec 
			package: 'GeauxFaux' with: 'GeauxFaux-tg.32';
			package: 'GeauxBeau' with: 'GeauxBeau-dkh.55';
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFie' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40ProjectFie: spec 
	"just projects"
	"self reset"

	<version: '4.0'>
	spec for: #common do: [
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '4.0';
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'Feaux' with: [
				spec
					className: 'MetacelloTestConfigurationOfFeaux';
					versionString: '4.0';
					file: 'MetacelloTestConfigurationOfFeaux';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFoe' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40ProjectFoe: spec 
	"projects and packages"
	"self reset"
	<version: '4.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '4.0';
					loads: '1';
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFum' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40ProjectFum: spec 
	"master"
	"self reset"
	<version: '4.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Feaux' with: [
				spec
					className: 'MetacelloTestConfigurationOfFeaux';
					versionString: '4.0';
					file: 'MetacelloTestConfigurationOfFeaux';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '4.0';
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'ProjectFie' with: [
				spec
					className: 'MetacelloTestConfigurationOfProjectFie';
					versionString: '4.0';
					file: 'MetacelloTestConfigurationOfProjectFie';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'ProjectFee' with: [
				spec
					className: 'MetacelloTestConfigurationOfProjectFee';
					versionString: '4.0';
					file: 'MetacelloTestConfigurationOfProjectFee';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'Issue 95' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40ProjectInfinite: spec 
	"self reset"
	<version: '4.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec
			project: 'Loop' with: [
				spec
					className: 'MetacelloTestConfigurationOfProjectLoop';
					versionString: '4.0';
					loads: 'GeauxBeau';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself.
		spec 
			package: 'GeauxBar' with: [
				spec
					file: 'GeauxBar.branch-lr.2';
					requires: 'Loop';
					yourself ];
			package: 'GoferBar' with: 'GoferBar-lr.1';
			yourself ].! !

!MetacelloConfigurationResource methodsFor: 'Issue 95' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40ProjectIssue95: spec 
	"self reset"
	<version: '4.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Loop' with: [
				spec
					className: 'MetacelloTestConfigurationOfProjectLoop';
					versionString: '4.0';
					loads: 'GoferFaux';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'Infinite' with: [
				spec
					className: 'MetacelloTestConfigurationOfProjectInfinite';
					versionString: '4.0';
					loads: 'GeauxBar';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].! !

!MetacelloConfigurationResource methodsFor: 'Issue 95' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline40ProjectLoop: spec 
	"self reset"
	<version: '4.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Infinite' with: [
				spec
					className: 'MetacelloTestConfigurationOfProjectInfinite';
					versionString: '4.0';
					loads: 'GoferBar';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			package: 'GoferFaux' with: [
				spec
					file:'GoferFaux-tg.30';
					requires: 'Infinite';
					yourself ];
			package: 'GeauxBeau' with: [
				spec
					file: 'GeauxBeau-dkh.55';
					yourself ];
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline50Fan: spec 
	"self reset"
	<version: '5.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '5.0';
					loads: #('GoferFaux' 'GoferBeau');
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline50Foo: spec 
	"self reset"
	<version: '5.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with:'GoferFoo-lr.2';
			package: 'GoferBar' with: 'GoferBar-lr.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.34';
			package: 'GoferBeau' with: 'GoferBeau-dkh.55';
			yourself.
		spec
			group: '1' with: #('GoferFoo' 'GoferBar');
			group: '2' with: #('GoferFoo' 'GoferFaux');
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline50MethodSourceFan

	^(self class sourceCodeAt: #baseline50Fan:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline50MethodSourceFoo

	^(self class sourceCodeAt: #baseline50Foo:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFix' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline60Fix: spec 
	"self reset"
	<version: '6.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.4';
			package: 'GoferBar' with: 'GoferBar-lr.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.35';
			yourself. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFix' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline60MethodSourceFix

	^(self class sourceCodeAt: #baseline60Fix:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFix' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline61Fix: spec 
	"self reset"
	<version: '6.1'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.4';
			package: 'GoferBar' with: 'GoferBar-lr.1';
			package: 'GoferBeau' with: 'GoferBeau-dkh.53';
			package: 'GoferFaux' with: 'GoferFaux-tg.31';
			yourself. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFix' stamp: 'dkh 6/12/2012 15:41:23.319'!
baseline61MethodSourceFix

	^(self class sourceCodeAt: #baseline61Fix:) asString

! !

!MetacelloConfigurationResource methodsFor: 'Issue 115' stamp: 'dkh 6/12/2012 15:41:23.319'!
baselineVersion10Issue115: spec
	<version: '1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #baseline.
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself.
		spec 
			package: 'GeauxFoo'. ].
! !

!MetacelloConfigurationResource methodsFor: 'Issue 136' stamp: 'dkh 6/12/2012 15:41:23.319'!
baselineVersion10Issue136: spec
	<version: '1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #baseline.
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferBeau'. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
baselineVersion113ProjectToolBox: spec
	<version: '1.1.3-baseline'>

	spec for: #'outer' do: [
		spec 
			package: 'Example-Core';
			package: 'Example-Test'. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
baselineVersion124ProjectToolBox: spec
	<version: '1.2.4-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.example.com/aa'. ].

	spec for: #'common' do: [
		spec repository: 'http://www.example.com/ab'. ].
! !

!MetacelloConfigurationResource methodsFor: 'Issue 125' stamp: 'dkh 9/11/2012 15:13'!
baselineVersion20Issue125: spec
    <version: '2.0-baseline'>
    spec
        for: #'common'
        do: [ 
            spec blessing: #'baseline'.
            spec description: 'MetacelloConfigurationResource>>baselineVersion20Issue125:'.
            spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
            spec
                package: 'GoferFoo';
                package: 'GoferBar' with: [ spec requires: 'GoferFoo' ];
                yourself ]! !

!MetacelloConfigurationResource methodsFor: 'Issue 125' stamp: 'dkh 9/11/2012 15:14'!
baselineVersion30Issue125: spec
    <version: '3.0-baseline' imports: #('2.0-baseline')>
    spec
        for: #(#'attribute1' #'attribute2')
        do: [ 
            spec description: 'MetacelloConfigurationResource>>baselineVersion30Issue125:'.
            spec
                package: 'GoferFaux' with: [ spec requires: 'GoferFoo' ];
                package: 'GoferBeau' with: [ spec requires: 'GoferFaux' ];
                yourself ]! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'dkh 9/13/2012 15:54'!
bleedingEdgeVersion: spec
    "self reset"

    <symbolicVersion: #'bleedingEdge'>
    spec for: #'common' version: '4.0'! !

!MetacelloConfigurationResource methodsFor: 'accessing' stamp: 'dkh 6/12/2012 15:41:23.319'!
monticelloRepository
	^ monticelloRepository! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'dkh 6/12/2012 15:41:23.319'!
postloadDoIt
	"self reset"

	Smalltalk at: #'Metacello_Configuration_Test_POST_DoIt_Result' put: true! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'dkh 6/12/2012 15:41:23.319'!
preloadDoIt
	"self reset"

	Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result' put: true! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'dkh 6/12/2012 15:41:23.319'!
preloadDoItMethodSource

	^(self class sourceCodeAt: #preloadDoIt) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'dkh 6/12/2012 15:41:23.319'!
project
	"self reset"

	| constructor project |
	"Construct Metacello project"
	project := MetacelloMCProject new.
	"Allow for customization of #projectAttributes"
	project projectAttributes: MetacelloConfigurationResource projectAttributes.
	MetacelloVersionConstructor on: self project: project.
	project loader: 
		((project loaderClass new)
			shouldDisablePackageCache: true;
			yourself).
	project loadType: #linear.
	^project
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'dkh 6/12/2012 15:41:23.319'!
projectClassMethodSource

	^(self class class sourceCodeAt: #project) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'dkh 6/12/2012 15:41:23.319'!
projectMethodSource

	^(self class sourceCodeAt: #project) asString

! !

!MetacelloConfigurationResource methodsFor: 'running' stamp: 'dkh 9/11/2012 15:10'!
setUp
    "self reset"

    super setUp.
    self
        setUpMonticelloRepository;
        setUpConfigurationOfFoo;
        setUpConfigurationOfFeaux;
        setUpConfigurationOfProjectFie;
        setUpConfigurationOfProjectFee;
        setUpConfigurationOfFum;
        setUpConfigurationOfProjectFoe;
        setUpConfigurationOfFan;
        setUpConfigurationOfFix;
        setUpIssue77;
        setUpIssue95;
        setUpConfigurationOfSymbolic;
        setUpConfigurationOfProjectToolBox;
        setUpConfigurationOfProjectIssue115;
        setUpConfigurationOfProjectIssue136;
        setUpConfigurationOfProjectIssue125;
        yourself
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFan' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpConfigurationOfFan
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfFan-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline20Fan:'
        category: 'cat'
        timeStamp: ''
        source: self baseline20MethodSourceFan).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline30Fan:'
        category: 'cat'
        timeStamp: ''
        source: self baseline30MethodSourceFan).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline35Fan:'
        category: 'cat'
        timeStamp: ''
        source: self baseline35MethodSourceFan).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline40Fan:'
        category: 'cat'
        timeStamp: ''
        source: self baseline40MethodSourceFan).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline50Fan:'
        category: 'cat'
        timeStamp: ''
        source: self baseline50MethodSourceFan)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFeaux' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpConfigurationOfFeaux
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfFeaux-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline40Feaux:'
        category: 'cat'
        timeStamp: ''
        source: self baseline40MethodSourceFeaux)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFix' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpConfigurationOfFix
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfFix-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline60Fix:'
        category: 'cat'
        timeStamp: ''
        source: self baseline60MethodSourceFix).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline61Fix:'
        category: 'cat'
        timeStamp: ''
        source: self baseline61MethodSourceFix)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFoo' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpConfigurationOfFoo
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfFoo-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: false
        selector: 'bleedingEdgeVersion:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'bleedingEdgeVersion:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline20Foo:'
        category: 'cat'
        timeStamp: ''
        source: self baseline20MethodSourceFoo).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline30Foo:'
        category: 'cat'
        timeStamp: ''
        source: self baseline30MethodSourceFoo).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline35Foo:'
        category: 'cat'
        timeStamp: ''
        source: self baseline35MethodSourceFoo).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline40Foo:'
        category: 'cat'
        timeStamp: ''
        source: self baseline40MethodSourceFoo).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline50Foo:'
        category: 'cat'
        timeStamp: ''
        source: self baseline50MethodSourceFoo).
    (MCMethodDefinition
        className: className asString
        selector: 'preloadDoIt'
        category: 'cat'
        timeStamp: ''
        source: self preloadDoItMethodSource)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfFum' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpConfigurationOfFum
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfFum-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline40ProjectFum:'
        category: 'cat'
        timeStamp: ''
        source: self baseline40MethodSourceProjectFum)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFee' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpConfigurationOfProjectFee
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfProjectFee-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline40ProjectFee:'
        category: 'cat'
        timeStamp: ''
        source: self baseline40MethodSourceProjectFee)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFie' stamp: 'dkh 6/26/2012 14:56'!
setUpConfigurationOfProjectFie
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfProjectFie-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline35ProjectFie:'
        category: 'cat'
        timeStamp: ''
        source: self baseline35MethodSourceProjectFie).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline40ProjectFie:'
        category: 'cat'
        timeStamp: ''
        source: self baseline40MethodSourceProjectFie)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectFoe' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpConfigurationOfProjectFoe
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfProjectFoe-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline40ProjectFoe:'
        category: 'cat'
        timeStamp: ''
        source: self baseline40MethodSourceProjectFoe)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'Issue 95' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpConfigurationOfProjectInfinite
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfProjectInfinite-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline40ProjectInfinite:'
        category: 'cat'
        timeStamp: ''
        source: self baseline40MethodSourceProjectInfinite)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'Issue 115' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpConfigurationOfProjectIssue115
	"self reset"
	
	| versionInfo |
	versionInfo := self setUpConfigurationOfProjectIssue115dkh1.
	versionInfo := self setUpConfigurationOfProjectIssue115dkh2: {versionInfo}.
	! !

!MetacelloConfigurationResource methodsFor: 'Issue 115' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpConfigurationOfProjectIssue115dkh1
    "self reset"

    | reference className definitionArray versionInfo |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfProjectIssue115-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baselineVersion10Issue115:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'baselineVersion10Issue115:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version10Issue115:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version10Issue115:') asString)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (versionInfo := MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #()).
    ^ versionInfo! !

!MetacelloConfigurationResource methodsFor: 'Issue 115' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpConfigurationOfProjectIssue115dkh2: ancestors
    "self reset"

    | reference className definitionArray versionInfo |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfProjectIssue115-dkh.2'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baselineVersion10Issue115:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'baselineVersion10Issue115:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version10Issue115:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version10Issue115:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version11Issue115:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version11Issue115:') asString)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (versionInfo := MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: ancestors)
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #()).
    ^ versionInfo! !

!MetacelloConfigurationResource methodsFor: 'Issue 125' stamp: 'dkh 9/11/2012 15:33'!
setUpConfigurationOfProjectIssue125
    "self reset"

    | reference className definitionArray versionInfo |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfProjectIssue125-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'version30Issue125:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version30Issue125:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'baselineVersion20Issue125:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'baselineVersion20Issue125:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'baselineVersion30Issue125:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'baselineVersion30Issue125:') asString)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (versionInfo := MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #()).
    ^ versionInfo! !

!MetacelloConfigurationResource methodsFor: 'Issue 136' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpConfigurationOfProjectIssue136
	"self reset"
	
	| versionInfo |
	versionInfo := self setUpConfigurationOfProjectIssue136dkh1.
	versionInfo := self setUpConfigurationOfProjectIssue136dkh2: {versionInfo}.
	! !

!MetacelloConfigurationResource methodsFor: 'Issue 136' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpConfigurationOfProjectIssue136dkh1
    "self reset"

    | reference className definitionArray versionInfo |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfProjectIssue136-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baselineVersion10Issue136:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'baselineVersion10Issue136:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version10Issue136:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version10Issue136:') asString)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (versionInfo := MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #()).
    ^ versionInfo! !

!MetacelloConfigurationResource methodsFor: 'Issue 136' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpConfigurationOfProjectIssue136dkh2: ancestors
    "self reset"

    | reference className definitionArray versionInfo |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfProjectIssue136-dkh.2'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baselineVersion10Issue136:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'baselineVersion10Issue136:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version10Issue136:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version10Issue136:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version11Issue136:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version11Issue136:') asString)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (versionInfo := MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: ancestors)
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #()).
    ^ versionInfo! !

!MetacelloConfigurationResource methodsFor: 'Issue 95' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpConfigurationOfProjectIssue95
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfProjectIssue95-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline40ProjectIssue95:'
        category: 'cat'
        timeStamp: ''
        source: self baseline40MethodSourceProjectIssue95)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'Issue 95' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpConfigurationOfProjectLoop
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfProjectLoop-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline40ProjectLoop:'
        category: 'cat'
        timeStamp: ''
        source: self baseline40MethodSourceProjectLoop)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpConfigurationOfProjectToolBox
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfProjectToolBox-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'postloadDoIt'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'postloadDoIt') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'preloadDoIt'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'preloadDoIt') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version100ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version100ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version101ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version101ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version102ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version102ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version103ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version103ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version104ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version104ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version105ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version105ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version106ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version106ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version107ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version107ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version108ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version108ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version109ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version109ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version110ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version110ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version111ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version111ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version112ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version112ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'baselineVersion113ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'baselineVersion113ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version113ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version113ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version114ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version114ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version115ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version115ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version116ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version116ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version117ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version117ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version118ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version118ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version119ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version119ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version120ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version120ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version121ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version121ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version122ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version122ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version123ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version123ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'baselineVersion124ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'baselineVersion124ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version124ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version124ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version125ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version125ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version126ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version126ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version127ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version127ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version128ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version128ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version129ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version129ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version130ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version130ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version131ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version131ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version132ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version132ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version133ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version133ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version134ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version134ProjectToolBox:') asString).
    (MCMethodDefinition
        className: className asString
        selector: 'version135ProjectToolBox:'
        category: 'cat'
        timeStamp: ''
        source: (self class sourceCodeAt: #'version135ProjectToolBox:') asString)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfSymbolic' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpConfigurationOfSymbolic
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfSymbolic-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'stableVersionD:'
        category: 'cat'
        timeStamp: ''
        source: self stableVersionDMethodSourceSymbolic).
    (MCMethodDefinition
        className: className asString
        selector: 'version40Symbolic:'
        category: 'cat'
        timeStamp: ''
        source: self version40SymbolicMethodSourceSymbolic).
    (MCMethodDefinition
        className: className asString
        selector: 'version41Symbolic:'
        category: 'cat'
        timeStamp: ''
        source: self version41SymbolicMethodSourceSymbolic).
    (MCMethodDefinition
        className: className asString
        selector: 'version42Symbolic:'
        category: 'cat'
        timeStamp: ''
        source: self version42SymbolicMethodSourceSymbolic).
    (MCMethodDefinition
        className: className asString
        selector: 'version43Symbolic:'
        category: 'cat'
        timeStamp: ''
        source: self version43SymbolicMethodSourceSymbolic)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'Issue 77' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpIssue77
	"self reset"
	
	self
		setUpIssue77B;
		setUpIssue77C;
		setUpIssue77D
		! !

!MetacelloConfigurationResource methodsFor: 'Issue 77' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpIssue77B
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfIssue77B-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline10B:'
        category: 'cat'
        timeStamp: ''
        source: self baseline10MethodSourceB)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'Issue 77' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpIssue77C
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfIssue77C-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline12C:'
        category: 'cat'
        timeStamp: ''
        source: self baseline12MethodSourceC).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline13C:'
        category: 'cat'
        timeStamp: ''
        source: self baseline13MethodSourceC)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'Issue 77' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpIssue77D
    "self reset"

    | reference className definitionArray |
    reference := GoferVersionReference name: 'MetacelloTestConfigurationOfIssue77D-dkh.1'.
    className := reference packageName asSymbol.
    definitionArray := {(MCOrganizationDefinition categories: (Array with: className)).
    (MCClassDefinition
        name: className
        superclassName: #'Object'
        category: className
        instVarNames: #()
        comment: '').
    (MCMethodDefinition
        className: className asString
        classIsMeta: true
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectClassMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'project'
        category: 'cat'
        timeStamp: ''
        source: self projectMethodSource).
    (MCMethodDefinition
        className: className asString
        selector: 'baseline10D:'
        category: 'cat'
        timeStamp: ''
        source: self baseline10MethodSourceD)}.
    monticelloRepository
        basicStoreVersion:
            (MCVersion new
                setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                info:
                    (MCVersionInfo
                        name: reference name
                        id: UUID new
                        message: 'This is a mock version'
                        date: Date today
                        time: Time now
                        author: reference author
                        ancestors: #())
                snapshot: (MCSnapshot fromDefinitions: definitionArray)
                dependencies: #())! !

!MetacelloConfigurationResource methodsFor: 'Issue 95' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpIssue95
	"self reset"
	
	self
		setUpConfigurationOfProjectInfinite;
		setUpConfigurationOfProjectLoop;
		setUpConfigurationOfProjectIssue95;
		yourself		! !

!MetacelloConfigurationResource methodsFor: 'running' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUpMonticelloRepository
	"This method builds a fake repository with the version references from #buildReferences."
	"self reset"

	monticelloRepository := MCDictionaryRepository new.
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfSymbolic' stamp: 'dkh 6/12/2012 15:41:23.319'!
stableVersionC: spec 
	"self reset"
	<symbolicVersion: #stable>
	
	spec for: #'common' do: [ spec version: '4.2'].
	spec for: #'platformVersion1.x' do: [ spec version: '4.0'].
	spec for: #'platformVersion1.0.x' do: [ spec version: '4.1'].
	spec for: #'platformVersion1.1.x' do: [ spec version: '4.2'].
	spec for: #'platformVersion1.2.x' do: [ spec version: '4.3'].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfSymbolic' stamp: 'dkh 6/12/2012 15:41:23.319'!
stableVersionD: spec 
	"self reset"
	<symbolicVersion: #stable>
	
	spec for: #'common' version: '4.2'.
	spec for: #'platformVersion1.x' version: '4.0'.
	spec for: #'platformVersion1.0.x' version: '4.1'.
	spec for: #'platformVersion1.1.x' version: '4.2'.
	spec for: #'platformVersion1.2.x' version: '4.3'.
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfSymbolic' stamp: 'dkh 6/12/2012 15:41:23.319'!
stableVersionDMethodSourceSymbolic

	^(self class sourceCodeAt: #stableVersionD:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version100ProjectToolBox: spec
	<version: '1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'testBlessing'.
		spec 
			package: 'Example-Core' with: [
				spec 
					includes: #('Example-AddOn' );
					file: 'Example-Core-anon.1';
					repository: 'http://www.example.com/or';
					preLoadDoIt: #'preloadForCore';
					postLoadDoIt: #'postloadForCore:package:'. ];
			package: 'Example-AddOn' with: [
				spec requires: #('Example-Core' ). ];
			package: 'Example-Tests' with: [
				spec requires: #('Example-AddOn' ). ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version101ProjectToolBox: spec
	<version: '1.0.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'testBlessing'. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version102ProjectToolBox: spec
	<version: '1.0.2-baseline'>

	spec for: #'common' do: [
		spec preLoadDoIt: #'preloadForCore'.
		spec postLoadDoIt: #'postloadForCore:package:'.
		spec 
			package: 'Example-Core' with: [
				spec includes: #('Example-AddOn' ). ];
			package: 'Example-AddOn' with: [
				spec requires: #('Example-Core' ). ];
			package: 'Example-Tests' with: [
				spec requires: #('Example-AddOn' ). ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version103ProjectToolBox: spec
	<version: '1.0.3-baseline' imports: #('1.0.2-baseline' )>

	spec for: #'common' do: [
		spec preLoadDoIt: #'alternatePreloadForCore'. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version104ProjectToolBox: spec
	<version: '1.0.4-baseline' imports: #('1.0.2-baseline' )>

	spec for: #'common' do: [
		spec preLoadDoIt: nil. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version105ProjectToolBox: spec
	<version: '1.0.5-baseline'>

	spec for: #'common' do: [
		spec package: 'Example-Core' with: [
				spec repository: 'http://www.example.com/ob'. ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version106ProjectToolBox: spec
	<version: '1.0.6-baseline'>

	spec for: #'common' do: [
		spec package: 'Example-Core' with: [
				spec repositories: [
						spec
							repository: 'http://www.example.com/ob';
							repository: 'http://www.example.com/or' ]. ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version107ProjectToolBox: spec
	<version: '1.0.7-baseline'>

	spec for: #'common' do: [
		spec 
			package: 'Example-Core' with: [
				spec 
					supplyingAnswers: #( #( 'preload' 'preload answer' ) #( 'postload' 'postload answer' ) );
					preLoadDoIt: #'preloadForSupplyingAnswers';
					postLoadDoIt: #'postloadForSupplyingAnswers'. ];
			package: 'Example-Tests' with: [
				spec supplyingAnswers: #( #( 'string' 'preload answer' ) #( 'symbol' #'abc def' ) #( 'integer' 1 ) #( 'boolean' true ) #( 'another boolean' false ) #( 'character' $a ) ). ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version108ProjectToolBox: spec
	<version: '1.0.8-baseline'>

	spec for: #'common' do: [
		spec 
			package: 'Example-Core';
			package: 'Example-Tests' with: [
				spec requires: #('Example-Core' ). ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version109ProjectToolBox: spec
	<version: '1.0.9-baseline'>

	spec for: #'common' do: [
		spec 
			package: 'Example-Core';
			package: 'Example-Tests' with: [
				spec includes: #('Example-Core' ). ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'Issue 115' stamp: 'dkh 6/12/2012 15:41:23.319'!
version10Issue115: spec
	<version: '1.0' imports: #('1.0-baseline')>

	spec for: #'common' do: [
		spec blessing: #development.
		spec  project: 'Foo' .
		spec package: 'GeauxFoo' with: 'GeauxFoo-lr.1'. ].
! !

!MetacelloConfigurationResource methodsFor: 'Issue 136' stamp: 'dkh 6/12/2012 15:41:23.319'!
version10Issue136: spec
	<version: '1.0' imports: #('1.0-baseline')>

	spec for: #'common' do: [
		spec blessing: #development.
		spec package: 'GoferBeau' with: 'GoferBeau-dkh.15'. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version110ProjectToolBox: spec
	<version: '1.1.0-baseline'>

	spec for: #'common' do: [
		spec 
			package: 'Example-Core';
			package: 'Example-Base';
			package: 'Example-Test1' with: [
				spec 
					requires: #('Example-Base' );
					includes: #('Example-Core' ). ];
			package: 'Example-Test2' with: [
				spec 
					includes: #('Example-Core' );
					supplyingAnswers: #( #( 'captionMatch' 'answer' ) ). ];
			package: 'Example-Test3' with: [
				spec 
					requires: #('Example-Base' );
					supplyingAnswers: #( #( 'captionMatch' 'answer' ) ). ];
			package: 'Example-Test4' with: [
				spec 
					requires: #('Example-Base' );
					includes: #('Example-Core' );
					supplyingAnswers: #( #( 'captionMatch' 'answer' ) ). ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version111ProjectToolBox: spec
	<version: '1.1.1-baseline'>

	spec for: #'common' do: [
		spec package: 'Example-Core'.

		spec for: #'nested' do: [
			spec package: 'Example-Base'. ]. ].

	spec for: #'extra' do: [
		spec package: 'Example-Test'. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version112ProjectToolBox: spec
	<version: '1.1.2-baseline'>

	spec for: #'common' do: [
		spec package: 'Example-Core'.

		spec for: #'nested' do: [
			spec 
				package: 'Example-Base';
				package: 'Example-Test-Nested'. ]. ].

	spec for: #'extra' do: [
		spec package: 'Example-Test'. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version113ProjectToolBox: spec
	<version: '1.1.3' imports: #('1.1.3-baseline' )>

	spec for: #'outer' do: [
		spec 
			package: 'Example-Core' with: 'Example-Core-dkh.1';
			package: 'Example-Test' with: 'Example-Test-dkh.1'.

		spec for: #'nested' do: [
			spec package: 'Example-Core' with: 'Example-Core-dkh.2'. ]. ].

	spec for: #'extra' do: [
		spec package: 'Example-Core' with: 'Example-Core-dkh.3'. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version114ProjectToolBox: spec
	<version: '1.1.4-baseline'>

	spec for: #'common' do: [
		spec project: 'Example Project' with: [
				spec
					className: 'MetacelloExampleProjectConfig';
					versionString: '1.0-baseline';
					preLoadDoIt: #'preloadForProject';
					postLoadDoIt: #'postloadForProject';
					repository: 'http://www.example.com/ob' ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version115ProjectToolBox: spec
	<version: '1.1.5-baseline' imports: #('1.1.4-baseline' )>

	spec for: #'common' do: [
		spec project: 'Example Project' with: [
				spec
					preLoadDoIt: #'alternatePreloadForCore' ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version116ProjectToolBox: spec
	<version: '1.1.6-baseline' imports: #('1.1.4-baseline' )>

	spec for: #'common' do: [
		spec project: 'Example Project' with: [
				spec
					preLoadDoIt: #'alternatePreloadForCore' ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version117ProjectToolBox: spec
	<version: '1.1.7-baseline' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec package: 'Example-Core' overrides: [
				spec preLoadDoIt: #'alternatePreloadForCore'. ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version118ProjectToolBox: spec
	<version: '1.1.8-baseline' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec package: 'Example-Core' with: [
				spec preLoadDoIt: #'alternatePreloadForCore'. ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version119ProjectToolBox: spec
	<version: '1.1.9-baseline' imports: #('1.1.4-baseline' )>

	spec for: #'common' do: [
		spec project: 'Example Project' overrides: [
				spec
					className: 'MetacelloExampleProjectConfig';
					versionString: '1.0-baseline';
					preLoadDoIt: #'alternatePreloadForCore';
					repository: 'http://www.example.com/ob' ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'Issue 115' stamp: 'dkh 6/12/2012 15:41:23.319'!
version11Issue115: spec
	<version: '1.1' imports: #('1.0-baseline')>

	spec for: #'common' do: [
		spec blessing: #development.
		spec  project: 'Foo' with: ''.
		spec package: 'GeauxFoo' with: 'GeauxFoo-lr.1'. ].
! !

!MetacelloConfigurationResource methodsFor: 'Issue 136' stamp: 'dkh 6/12/2012 15:41:23.319'!
version11Issue136: spec
	<version: '1.1' imports: #('1.0-baseline')>

	spec for: #'common' do: [
		spec blessing: #development.
		spec package: 'GoferBeau' with: 'GoferBeau-dkh.25'. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version120ProjectToolBox: spec
	<version: '1.2.0-baseline' imports: #('1.1.4-baseline' )>

	spec for: #'common' do: [
		spec project: 'Copied Example' copyFrom: 'Example Project' with: [
				spec
					preLoadDoIt: #'alternatePreloadForCore' ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version121ProjectToolBox: spec
	<version: '1.2.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'testBlessing'.
		spec repository: 'http://www.example.com/vor'.
		spec 
			package: 'Example-Core' with: [
				spec 
					includes: #('Example-AddOn' );
					file: 'Example-Core-anon.1';
					repository: 'http://www.example.com/or';
					preLoadDoIt: #'preloadForCore';
					postLoadDoIt: #'postloadForCore:package:'. ];
			package: 'Example-AddOn' with: [
				spec requires: #('Example-Core' ). ];
			package: 'Example-Tests' with: [
				spec requires: #('Example-AddOn' ). ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version122ProjectToolBox: spec
	<version: '1.2.2-baseline'>

	spec for: #'common' do: [
		spec project: 'Example Project' with: [
				spec
					className: 'MetacelloExampleProjectConfig';
					repository: 'http://www.example.com/ob' ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version123ProjectToolBox: spec
	<version: '1.2.3-baseline'>

	spec for: #'common' do: [
		spec project: 'Example Project' with: [
				spec
					className: 'MetacelloExampleProjectConfig';
					repository: 'http://www.example.com/ob';
					repository: 'http://www.example.com/or' ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version124ProjectToolBox: spec
	<version: '1.2.4' imports: #('1.2.4-baseline' )>

	spec for: #'common' do: [
		spec repository: 'http://www.example.com/ac'. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version125ProjectToolBox: spec
	<version: '1.2.5-baseline' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec package: 'Example-Core' with: [
				spec 
					preLoadDoIt: #'preloadDoIt';
					postLoadDoIt: #'postloadDoIt'. ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version126ProjectToolBox: spec
	<version: '1.2.6-baseline' imports: #('1.2.5-baseline' )>

	spec for: #'common' do: [
		spec package: 'Example-Core' with: [
				spec 
					preLoadDoIt: nil;
					postLoadDoIt: nil. ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version127ProjectToolBox: spec
	<version: '1.2.7-baseline'>

	spec for: #'common' do: [
		spec project: 'Example Project' with: [
				spec
					className: 'MetacelloExampleProjectConfig';
					versionString: '1.0-baseline';
					preLoadDoIt: #'preloadDoIt';
					postLoadDoIt: #'postloadDoIt';
					repository: 'http://www.example.com/ob' ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version128ProjectToolBox: spec
	<version: '1.2.8-baseline' imports: #('1.2.7-baseline' )>

	spec for: #'common' do: [
		spec project: 'Example Project' with: [
				spec
					preLoadDoIt: nil;
					postLoadDoIt: nil ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version129ProjectToolBox: spec
	<version: '1.2.9-baseline'>

	spec for: #'common' do: [
		spec 
			project: 'Example Project' with: [
				spec
					className: 'MetacelloExampleProjectConfig';
					versionString: '1.0-baseline';
					preLoadDoIt: #'preloadDoIt';
					postLoadDoIt: #'postloadDoIt';
					repository: 'http://www.example.com/ob' ];
			project: 'Copy Project' copyFrom: 'Example Project' with: [
				spec
					preLoadDoIt: nil;
					postLoadDoIt: nil ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version130ProjectToolBox: spec
	<version: '1.3.0-baseline'>

	spec for: #'common' do: [
		spec 
			project: 'Example Project' with: [
				spec
					className: 'MetacelloExampleProjectConfig';
					versionString: '1.0-baseline';
					preLoadDoIt: #'preloadDoIt';
					postLoadDoIt: #'postloadDoIt';
					repository: 'http://www.example.com/ob' ];
			project: 'Copy Project' copyFrom: 'Example Project' with: [
				spec repository: 'http://www.example.com/or' ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version131ProjectToolBox: spec
	<version: '1.3.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'. ].

	spec for: #'level1_1' do: [
		spec 
			package: 'Example-Core' with: [
				spec repository: 'http://www.example.com/1'. ];
			package: 'Example-Core' with: [
				spec repository: 'http://www.example.com/2'. ];
			package: 'Example-Core' with: [
				spec repository: 'http://www.example.com/3'. ].

		spec for: #'level2_1' do: [
			spec package: 'Example-Core' with: [
					spec repository: 'http://www.example.com/4'. ].

			spec for: #'level3_1' do: [
				spec package: 'Example-Core' with: [
						spec repository: 'http://www.example.com/5'. ]. ]. ].

		spec for: #'level2_2' do: [
			spec package: 'Example-Core' with: [
					spec repository: 'http://www.example.com/6'. ].

			spec for: #'level3_2' do: [
				spec package: 'Example-Core' with: [
						spec repository: 'http://www.example.com/7'. ]. ]. ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version132ProjectToolBox: spec
	<version: '1.3.2-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'. ].

	spec for: #'level1_1' do: [
		spec package: 'GoferBeau' with: 'GoferBeau-dkh.15'.

		spec for: #'level2_1' do: [
			spec package: 'GoferBeau' with: 'GoferBeau-dkh.25'.

			spec for: #'level3_1' do: [
				spec package: 'GoferBeau' with: 'GoferBeau-dkh.53'. ]. ].

		spec for: #'level2_2' do: [
			spec package: 'GoferBeau' with: 'GoferBeau-dkh.54'.

			spec for: #'level3_2' do: [
				spec package: 'GoferBeau' with: 'GoferBeau-dkh.55'. ]. ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version133ProjectToolBox: spec
	<version: '1.3.3-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'. ].

	spec for: #'level1_1' do: [
		spec package: 'GoferBar' with: 'GoferBar-jf.1'.

		spec for: #'level2_1' do: [
			spec package: 'GoferFoo' with: 'GoferFoo-lr.1'.

			spec for: #'level3_1' do: [
				spec package: 'GoferFaux' with: 'GoferFaux-tg.30'. ]. ].

		spec for: #'level2_2' do: [
			spec package: 'GeauxBar' with: 'GeauxBar.branch-lr.2'.

			spec for: #'level3_2' do: [
				spec package: 'GeauxBeau' with: 'GeauxBeau-dkh.55'. ]. ]. ].

	spec for: #'pharo' do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'. ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version134ProjectToolBox: spec
	<version: '1.3.4-baseline'>

	spec for: #'common' do: [
 ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfProjectToolBox' stamp: 'dkh 6/12/2012 15:41:23.319'!
version135ProjectToolBox: spec
	<version: '1.3.5' imports: #('1.2.4-baseline' )>

	spec for: #'common' do: [
		spec repositories: [
			spec
				repository: 'http://www.example.com/ab';
				repository: 'http://www.example.com/ac' ]. ].
! !

!MetacelloConfigurationResource methodsFor: 'Issue 125' stamp: 'dkh 9/11/2012 15:46'!
version30Issue125: spec
    <version: '3.0' imports: #('3.0-baseline')>
    spec
        for: #'common'
        do: [ 
            spec blessing: #'release'.
            spec description: 'MetacelloConfigurationResource>>version30Issue125:'.
            spec
                package: 'GoferFoo' with: 'GoferFoo-lr.4';
                package: 'GoferBar' with: 'GoferBar-jf.1';
                yourself ].
    spec
        for: #'attribute1'
        do: [ 
            spec
                package: 'GoferFaux' with: 'GoferFaux-tg.32';
                package: 'GoferBeau' with: 'GoferBeau-dkh.55';
                yourself ].
    spec
        for: #'attribute2'
        do: [ 
            spec
                package: 'GoferFaux' with: 'GoferFaux-tg.33';
                package: 'GoferBeau' with: 'GoferBeau-dkh.56';
                yourself ]! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfSymbolic' stamp: 'dkh 6/12/2012 15:41:23.319'!
version40Symbolic: spec 
	"self reset"
	<version: '4.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #release.
		spec 
			package: 'GoferBeau' with: 'GoferBeau-dkh.15';
			package: 'GoferFaux' with:'GoferFaux-tg.30';
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfSymbolic' stamp: 'dkh 6/12/2012 15:41:23.319'!
version40SymbolicMethodSourceSymbolic

	^(self class sourceCodeAt: #version40Symbolic:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfSymbolic' stamp: 'dkh 6/12/2012 15:41:23.319'!
version41Symbolic: spec 
	"self reset"
	<version: '4.1'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #release.
		spec 
			package: 'GoferBeau' with: 'GoferBeau-dkh.25';
			package: 'GoferFaux' with:'GoferFaux-tg.31';
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfSymbolic' stamp: 'dkh 6/12/2012 15:41:23.319'!
version41SymbolicMethodSourceSymbolic

	^(self class sourceCodeAt: #version41Symbolic:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfSymbolic' stamp: 'dkh 6/12/2012 15:41:23.319'!
version42Symbolic: spec 
	"self reset"
	<version: '4.2'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #release.
		spec 
			package: 'GoferBeau' with: 'GoferBeau-dkh.53';
			package: 'GoferFaux' with:'GoferFaux-tg.32';
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfSymbolic' stamp: 'dkh 6/12/2012 15:41:23.319'!
version42SymbolicMethodSourceSymbolic

	^(self class sourceCodeAt: #version42Symbolic:) asString

! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfSymbolic' stamp: 'dkh 6/12/2012 15:41:23.319'!
version43Symbolic: spec 
	"self reset"
	<version: '4.3'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #development.
		spec 
			package: 'GoferBeau' with: 'GoferBeau-dkh.54';
			package: 'GoferFaux' with:'GoferFaux-tg.33';
			yourself ].
! !

!MetacelloConfigurationResource methodsFor: 'ConfigurationOfSymbolic' stamp: 'dkh 6/12/2012 15:41:23.319'!
version43SymbolicMethodSourceSymbolic

	^(self class sourceCodeAt: #version43Symbolic:) asString

! !

TestResource subclass: #MetacelloIssue108Resource
	instanceVariableNames: 'versionReferences monticelloRepository'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Resources'!

!MetacelloIssue108Resource methodsFor: 'accessing' stamp: 'dkh 2/22/2011 20:39'!
monticelloRepository
	^ monticelloRepository! !

!MetacelloIssue108Resource methodsFor: 'running' stamp: 'dkh 2/22/2011 20:39'!
setUp
	super setUp.
	self
		setUpVersionReferences;
		setUpMonticelloRepository! !

!MetacelloIssue108Resource methodsFor: 'running' stamp: 'dkh 9/4/2012 23:28'!
setUpMonticelloRepository
    "This method builds a fake repository with the version references from #buildReferences."

    monticelloRepository := MCDictionaryRepository new.
    versionReferences
        do: [ :reference | 
            monticelloRepository
                basicStoreVersion:
                    (MCVersion new
                        setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                        info:
                            (MCVersionInfo
                                name: reference name
                                id: UUID new
                                message: 'This is a mock version'
                                date: Date today
                                time: Time now
                                author: reference author
                                ancestors: #())
                        snapshot:
                            (MCSnapshot
                                fromDefinitions:
                                    (Array
                                        with:
                                            (MCOrganizationDefinition categories: (Array with: reference packageName asSymbol))
                                        with:
                                            (MCClassDefinition
                                                name: (reference packageName copyWithout: $-) asSymbol
                                                superclassName: #'Object'
                                                category: reference packageName asSymbol
                                                instVarNames: #()
                                                comment: '')))
                        dependencies: #()) ]! !

!MetacelloIssue108Resource methodsFor: 'running' stamp: 'dkh 2/22/2011 21:01'!
setUpVersionReferences
	"self reset"

	versionReferences := OrderedCollection new.
	versionReferences
		add: (GoferVersionReference name: 'GoferBar.gemstone-dkh.68');
		add: (GoferVersionReference name: 'GoferBar.gemstone-dkh.69');
		add: (GoferVersionReference name: 'GoferBar.gemstone-dkh.70');
		add: (GoferVersionReference name: 'GoferBar-dkh.68');
		add: (GoferVersionReference name: 'GoferBar-dkh.69');
		add: (GoferVersionReference name: 'GoferBar-dkh.70');
		yourself
	! !

!MetacelloIssue108Resource methodsFor: 'accessing' stamp: 'dkh 2/22/2011 20:39'!
versionReferences
	^ versionReferences! !

TestResource subclass: #MetacelloMonticelloResource
	instanceVariableNames: 'versionReferences monticelloRepository'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Resources'!

!MetacelloMonticelloResource methodsFor: 'accessing' stamp: 'dkh 1/12/2010 13:50'!
monticelloRepository
	^ monticelloRepository! !

!MetacelloMonticelloResource methodsFor: 'running' stamp: 'DaleHenrichs 3/16/2010 16:39'!
setUp
	super setUp.
	self
		setUpVersionReferences;
		setUpMonticelloRepository! !

!MetacelloMonticelloResource methodsFor: 'running' stamp: 'dkh 9/4/2012 23:28'!
setUpMonticelloRepository
    "This method builds a fake repository with the version references from #buildReferences."

    monticelloRepository := MCDictionaryRepository new.
    versionReferences
        do: [ :reference | 
            monticelloRepository
                basicStoreVersion:
                    (MCVersion new
                        setPackage: (MetacelloTestsMCPackage new name: reference packageName)
                        info:
                            (MCVersionInfo
                                name: reference name
                                id: UUID new
                                message: 'This is a mock version'
                                date: Date today
                                time: Time now
                                author: reference author
                                ancestors: #())
                        snapshot:
                            (MCSnapshot
                                fromDefinitions:
                                    (Array
                                        with:
                                            (MCOrganizationDefinition categories: (Array with: reference packageName asSymbol))
                                        with:
                                            (MCClassDefinition
                                                name: (reference packageName copyWithout: $-) asSymbol
                                                superclassName: #'Object'
                                                category: reference packageName asSymbol
                                                instVarNames: #()
                                                comment: '')))
                        dependencies: #()) ]! !

!MetacelloMonticelloResource methodsFor: 'running' stamp: 'dkh 10/11/2011 20:22'!
setUpVersionReferences
	"self reset"

	versionReferences := OrderedCollection new.
	versionReferences
		add: (GoferVersionReference name: 'GoferBar.branch-lr.1');
		add: (GoferVersionReference name: 'GoferBar.branch-lr.2');
		add: (GoferVersionReference name: 'GoferBar-lr.0');
		add: (GoferVersionReference name: 'GoferBar-jf.1');
		add: (GoferVersionReference name: 'GoferBar-lr.1');
		add: (GoferVersionReference name: 'GoferFoo-lr.1');
		add: (GoferVersionReference name: 'GoferFoo-lr.2');
		add: (GoferVersionReference name: 'GoferFoo-lr.4');
		add: (GoferVersionReference name: 'GoferBeau-dkh.15');
		add: (GoferVersionReference name: 'GoferBeau-dkh.25');
		add: (GoferVersionReference name: 'GoferBeau-dkh.53');
		add: (GoferVersionReference name: 'GoferBeau-dkh.54');
		add: (GoferVersionReference name: 'GoferBeau-dkh.55');
		add: (GoferVersionReference name: 'GoferBeau-dkh.56');
		add: (GoferVersionReference name: 'GoferFaux-tg.30');
		add: (GoferVersionReference name: 'GoferFaux-tg.31');
		add: (GoferVersionReference name: 'GoferFaux-tg.32');
		add: (GoferVersionReference name: 'GoferFaux-tg.33');
		add: (GoferVersionReference name: 'GoferFaux-tg.34');
		add: (GoferVersionReference name: 'GoferFaux-tg.35');
		add: (GoferVersionReference name: 'GeauxBar.branch-lr.2');
		add: (GoferVersionReference name: 'GeauxFoo-lr.1');
		add: (GoferVersionReference name: 'GeauxFaux-tg.32');
		add: (GoferVersionReference name: 'GeauxBeau-dkh.55');
		add: (GoferVersionReference name: 'GeauxBeau-dkh.56');
		yourself
	! !

!MetacelloMonticelloResource methodsFor: 'accessing' stamp: 'dkh 1/12/2010 13:50'!
versionReferences
	^ versionReferences! !

!Gofer methodsFor: '*metacello-testsmc' stamp: 'DaleHenrichs 12/18/2010 20:06'!
metacelloCleanup
	"Cleans the specified packages."
	
	^ self execute: MetacelloTestsGoferCleanup! !

!Gofer methodsFor: '*metacello-testsmc' stamp: 'DaleHenrichs 12/18/2010 13:58'!
metacelloLoad
	"Load the specified packages into the image."
	
	^ self execute: MetacelloGoferLoad! !

!Gofer methodsFor: '*metacello-testsmc' stamp: 'DaleHenrichs 12/18/2010 20:07'!
metacelloUnload
	"Unload the specified packages."
	
	^ self execute: MetacelloTestsGoferUnload! !

GoferTest subclass: #MetacelloDictionaryRepositoryTest
	instanceVariableNames: 'tempRepositories'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

MetacelloDictionaryRepositoryTest subclass: #MetacelloAtomicLoadOrderTest
	instanceVariableNames: 'loadType'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloAtomicLoadOrderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 3/16/2010 10:53'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		"using #atomic loadType means that package order isn't important ... 
			linear load order is GoferBar, GoferBeau, GoferFoo
			to test atomic load order, force an incorrect load order - which shouldn't matter for atomic loads"
		spec 
			package: 'GoferBar';
			package: 'GoferFoo' with: [ spec requires: 'GoferBar' ];
			package: 'GoferBeau' with: [ spec requires: 'GoferFoo' ];
			yourself ].
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 3/18/2010 09:42'!
baseline20: spec 
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #baseline.
		"using #atomic loadType means that package order isn't important"
		spec 
			project: 'GoferFoo' with: [ 	"requires: 'GoferBeau'"
				spec
					className: 'MetacelloTestConfigurationOfAtomicFoo';
					versionString: '2.0-baseline';
					loads: 'GoferFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself.
		spec 
			package: 'GoferBar';
			package: 'GoferFaux' with: [ spec requires: 'GoferFoo' ];
			package: 'GoferBeau'; 	"requires: 'GoferBar'"
			yourself ].
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 3/16/2010 12:02'!
baseline30: spec 
	<version: '3.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferBar';
			package: 'GoferBeau' with: [ 
				spec 
					requires: 'GoferBar';
					includes: #('GoferFoo' ) ]; 
			package: 'GoferFar' with: [ spec requires: #('GoferFoo' ) ]; 
			yourself.
		spec 
			project: 'GoferFoo' with: [ "requires GoferBeau"
				spec
					className: 'MetacelloTestConfigurationOfLinearFoo';
					versionString: '2.0';
					loads: 'GoferFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 5/19/2010 14:14'!
baseline31: spec 
	<version: '3.1-baseline'>
	
	spec for: #common do: [
		spec 
			project: 'AtomicFan' with: [
				spec
					className: 'MetacelloTestConfigurationOfAtomicFan';
					versionString: '3.1-baseline';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 3/18/2010 12:27'!
baseline35: spec 
	<version: '3.5-baseline'>
	"loads correctly with atomic load, gives warning if loaded linearly...the explicit load of 
	 MetacelloTestConfigurationOfAtomicFan shouldn't break the chain of the atomic load"
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferBar';
			package: 'GoferBeau' with: [ 
				spec 
					requires: 'GoferBar';
					includes: #('GoferFoo' ) ]; 
			package: 'GoferFar' with: [ spec requires: #('GoferFoo' ) ]; "Far loaded after Foo, but Fan depends upon Far"
			yourself.
		spec 
			project: 'GoferFoo' with: [
				spec
					className: 'MetacelloTestConfigurationOfAtomicFoo';
					versionString: '2.5-baseline';
					loads: 'GoferFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 3/16/2010 16:37'!
baseline40: spec 
	<version: '4.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferUmbrella';
			yourself ].
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 6/11/2010 10:16'!
baseline50: spec 
	<version: '5.0-baseline'>
	
	spec for: #common do: [
		spec 
			project: 'UmbrellaA' with: [
				spec
					className: 'MetacelloTestConfigurationOfUmbrellaA';
					versionString: '5.0';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'UmbrellaB' with: [
				spec
					className: 'MetacelloTestConfigurationOfUmbrellaB';
					versionString: '5.1';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 6/24/2010 16:43'!
baseline60: spec 
	<version: '6.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfLinearFoo';
					versionString: '6.0';
					loads: '1';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'Issue86' with: [
				spec
					className: 'MetacelloTestConfigurationOfProjectIssue86';
					versionString: '6.0';
					loads: 'A';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself.
		spec
			package: 'GeauxFoo' with: [
				spec 
					file: 'GeauxFoo-lr.1';
					requires: #('Foo') ];
			package: 'GeauxBeau' with: [
				spec 
					file: 'GeauxBeau-dkh.55';
					requires: #('GeauxFoo' 'Issue86') ];
			yourself ].
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 6/24/2010 16:55'!
baseline61: spec 
	<version: '6.1-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfLinearFoo';
					versionString: '6.1';
					loads: '1';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'Issue86' with: [
				spec
					className: 'MetacelloTestConfigurationOfProjectIssue86';
					versionString: '6.1';
					loads: 'A';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself.
		spec
			package: 'GeauxFoo' with: [
				spec 
					file: 'GeauxFoo-lr.1';
					requires: #('Foo') ];
			package: 'GeauxBeau' with: [
				spec 
					file: 'GeauxBeau-dkh.55';
					requires: #('GeauxFoo' 'Issue86') ];
			yourself ].
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 6/24/2010 17:21'!
baseline62: spec 
	<version: '6.2-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfLinearFoo';
					versionString: '6.2';
					loads: '1';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'Issue86' with: [
				spec
					className: 'MetacelloTestConfigurationOfProjectIssue86';
					versionString: '6.2';
					loads: 'A';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself.
		spec
			package: 'GeauxFoo' with: [
				spec 
					file: 'GeauxFoo-lr.1';
					requires: #('Foo') ];
			package: 'GeauxBeau' with: [
				spec 
					file: 'GeauxBeau-dkh.55';
					requires: #('GeauxFoo' 'Issue86') ];
			yourself ].
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'running' stamp: 'DaleHenrichs 3/16/2010 10:25'!
configurationRepository
	"MetacelloConfigurationResource reset"

	^ MetacelloAtomicConfigurationResource current monticelloRepository! !

!MetacelloAtomicLoadOrderTest methodsFor: 'accessing' stamp: 'DaleHenrichs 3/16/2010 10:50'!
loadType

	loadType ~~ nil ifTrue: [ ^loadType ].
	^#atomic! !

!MetacelloAtomicLoadOrderTest methodsFor: 'accessing' stamp: 'DaleHenrichs 3/16/2010 10:25'!
monticelloRepository
	"MetacelloMonticelloResource reset"
	^ MetacelloAtomicMonticelloResource current monticelloRepository! !

!MetacelloAtomicLoadOrderTest methodsFor: 'running' stamp: 'DaleHenrichs 3/16/2010 10:51'!
setUp

	super setUp.
	loadType := nil.! !

!MetacelloAtomicLoadOrderTest methodsFor: 'running' stamp: 'DaleHenrichs 3/16/2010 10:51'!
tearDown

	super tearDown.
	loadType := nil.! !

!MetacelloAtomicLoadOrderTest methodsFor: 'running' stamp: 'DaleHenrichs 6/24/2010 17:01'!
tearDownPackages: aGoferInstance

	super tearDownPackages: aGoferInstance.
	(self hasPackage: 'GeauxFoo')
		ifTrue: [ aGoferInstance package: 'GeauxFoo' ].
	(self hasPackage: 'GeauxBeau')
		ifTrue: [ aGoferInstance package: 'GeauxBeau' ].
	(self hasPackage: 'GoferFar')
		ifTrue: [ aGoferInstance package: 'GoferFar' ].
	(self hasPackage: 'GoferFan')
		ifTrue: [ aGoferInstance package: 'GoferFan' ].
	(self hasPackage: 'GoferUmbrella')
		ifTrue: [ aGoferInstance package: 'GoferUmbrella' ].
	(self hasPackage: 'GoferBarDependency')
		ifTrue: [ aGoferInstance package: 'GoferBarDependency' ].
	(self hasPackage: 'GoferFooDependency')
		ifTrue: [ aGoferInstance package: 'GoferFooDependency' ].
	(self hasPackage: 'MetacelloTestConfigurationOfAtomicFoo')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfAtomicFoo' ].
	(self hasPackage: 'MetacelloTestConfigurationOfAtomicFan')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfAtomicFan' ].
	(self hasPackage: 'MetacelloTestConfigurationOfLinearFoo')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfLinearFoo' ].
	(self hasPackage: 'MetacelloTestConfigurationOfUmbrellaA')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfUmbrellaA' ].
	(self hasPackage: 'MetacelloTestConfigurationOfUmbrellaB')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfUmbrellaB' ].
	(self hasPackage: 'MetacelloTestConfigurationOfProjectIssue86')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfProjectIssue86' ].
		
		
	! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/18/2010 09:36'!
testBaseline10LoadAtomic

	| project version wc |
	project := self project.
	version := project version: '1.0-baseline'.
	version load.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-dkh.5').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.15').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferBar-dkh.1'! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/16/2010 10:56'!
testBaseline10LoadLinear

	| project version |
	loadType := #linear.
	project := self project.
	version := project version: '1.0-baseline'.
	self should: [ version load ] raise: Warning
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/18/2010 09:42'!
testBaseline20LoadAtomic

	| project version wc |
	project := self project.
	version := project version: '2.0-baseline'.
	self shouldnt: [ version load ] raise: Warning.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-dkh.5').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.15').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferBar-dkh.1'! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/16/2010 10:57'!
testBaseline20LoadLinear

	| project version |
	loadType := #linear.
	project := self project.
	version := project version: '2.0-baseline'.
	self should: [ version load ] raise: Warning
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/16/2010 12:05'!
testBaseline30LoadAtomic

	| project version wc |
	project := self project.
	version := project version: '3.0-baseline'.
	version load.
	wc := (GoferPackageReference name: 'GoferFar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFar-dkh.4').
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-dkh.4').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.15').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferBar-dkh.1'! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/16/2010 12:04'!
testBaseline30LoadLinear

	| project version wc |
	loadType := #linear.
	project := self project.
	version := project version: '3.0-baseline'.
	version load.
	wc := (GoferPackageReference name: 'GoferFar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFar-dkh.4').
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-dkh.4').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.15').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferBar-dkh.1'! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 4/14/2010 11:02'!
testBaseline31LoadAtomic
	"coverage for postload doits with linear load nested inside an atomic load"
	
	| project version |
	project := self project.
	version := project version: '3.1-baseline'.
	self shouldnt: [ version load ] raise: Error.
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/18/2010 12:22'!
testBaseline35LoadAtomic

	| project version wc |
	project := self project.
	version := project version: '3.5-baseline'.
	version load.
	wc := (GoferPackageReference name: 'GoferFan') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFan-dkh.1').
	wc := (GoferPackageReference name: 'GoferFar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFar-dkh.4').
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-dkh.5').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.15').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferBar-dkh.1'! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/18/2010 12:26'!
testBaseline35LoadLinear

	| project version wc |
	loadType := #linear.
	project := self project.
	version := project version: '3.5-baseline'.
	self should: [ version load ] raise: Warning
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 6/11/2010 10:45'!
testBaseline40LoadAtomic

	| project version wc |
	project := self project.
	version := project version: '4.0-baseline'.
	version load.
	wc := (GoferPackageReference name: 'GoferUmbrella') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferUmbrella-lr.5').
	wc := (GoferPackageReference name: 'GoferBarDependency') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBarDependency-lr.35').
	wc := (GoferPackageReference name: 'GoferFooDependency') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFooDependency-lr.35').
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 6/11/2010 10:45'!
testBaseline40LoadLinear

	| project version wc |
	loadType := #linear.
	project := self project.
	version := project version: '4.0-baseline'.
	version load.
	wc := (GoferPackageReference name: 'GoferUmbrella') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferUmbrella-lr.5').
	wc := (GoferPackageReference name: 'GoferBarDependency') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBarDependency-lr.35').
	wc := (GoferPackageReference name: 'GoferFooDependency') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFooDependency-lr.35').
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'test issues' stamp: 'DaleHenrichs 3/18/2010 09:47'!
testIssue66
	"http://code.google.com/p/metacello/issues/detail?id=66"
	
	| project version wc |
	project := self project.
	version := project version: '2.0'.
	self shouldnt: [ version load ] raise: Warning.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-dkh.4').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.15').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferBar-dkh.1'.
	version := project version: '2.0-baseline'.
	self shouldnt: [ version load ] raise: Warning.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-dkh.5').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.15').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferBar-dkh.1'! !

!MetacelloAtomicLoadOrderTest methodsFor: 'test issues' stamp: 'DaleHenrichs 6/11/2010 10:46'!
testIssue81A
	"http://code.google.com/p/metacello/issues/detail?id=81
	 Verify that the old version of umbrella file loads in as expected"
	
	| project version wc |
	loadType := #linear.
	project := self project.
	version := project version: '5.0-baseline'.
	version load: 'UmbrellaA'.
	wc := (GoferPackageReference name: 'GoferUmbrella') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferUmbrella-dkh.4').
	wc := (GoferPackageReference name: 'GoferBarDependency') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBarDependency-lr.30').
	wc := (GoferPackageReference name: 'GoferFooDependency') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFooDependency-lr.30').
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'test issues' stamp: 'DaleHenrichs 6/11/2010 10:46'!
testIssue81B
	"http://code.google.com/p/metacello/issues/detail?id=81
	 Note: for this bug to express itself, the dependent mcz version numbers (in this case 35) must be 
	 greater than the umbrella mcz file version number (in this case 5)"
	
	| project version wc |
	loadType := #linear.
	project := self project.
	version := project version: '5.0-baseline'.
	version load.
	wc := (GoferPackageReference name: 'GoferUmbrella') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferUmbrella-lr.5').
	wc := (GoferPackageReference name: 'GoferBarDependency') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBarDependency-lr.35').
	wc := (GoferPackageReference name: 'GoferFooDependency') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFooDependency-lr.35').
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'test issues' stamp: 'DaleHenrichs 6/24/2010 16:55'!
testIssue86A
	"Issue 86: http://code.google.com/p/metacello/issues/detail?id=86
	 	This configuration reproduces the Grease-Core vs Grease-Slime problem. "
	| project version loadDirective repo wc |
	loadType := #linear.
	project := self project.
	version := project version: '6.0-baseline'.
	repo := MetacelloAtomicConfigurationResource current monticelloRepository.
	Smalltalk at: #'Metacello_Configuration_Test_Repository' put: repo.

	repo := MetacelloMonticelloResource current monticelloRepository.
	Smalltalk at: #'Metacello_Gofer_Test_Repository' put: repo.

	loadDirective := (version load: #('GeauxBeau')) loaderPolicy loadDirective.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.4').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').

	self 
		should: [ (GoferPackageReference name: 'GoferFaux') workingCopy ]
		raise: Error.
	self 
		should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ]
		raise: Error.
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'test issues' stamp: 'DaleHenrichs 6/24/2010 16:55'!
testIssue86B
	""
	| project version loadDirective repo wc |
	loadType := #linear.
	project := self project.
	version := project version: '6.1-baseline'.
	repo := MetacelloAtomicConfigurationResource current monticelloRepository.
	Smalltalk at: #'Metacello_Configuration_Test_Repository' put: repo.

	repo := MetacelloMonticelloResource current monticelloRepository.
	Smalltalk at: #'Metacello_Gofer_Test_Repository' put: repo.

	loadDirective := (version load: #('GeauxBeau')) loaderPolicy loadDirective.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.4').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').

	self 
		should: [ (GoferPackageReference name: 'GoferFaux') workingCopy ]
		raise: Error.
	self 
		should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ]
		raise: Error.
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'test issues' stamp: 'DaleHenrichs 6/24/2010 17:21'!
testIssue86C
	""
	| project version loadDirective repo wc |
	loadType := #linear.
	project := self project.
	version := project version: '6.2-baseline'.
	repo := MetacelloAtomicConfigurationResource current monticelloRepository.
	Smalltalk at: #'Metacello_Configuration_Test_Repository' put: repo.

	repo := MetacelloMonticelloResource current monticelloRepository.
	Smalltalk at: #'Metacello_Gofer_Test_Repository' put: repo.

	loadDirective := (version load: #('GeauxBeau')) loaderPolicy loadDirective.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.4').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').

	self 
		should: [ (GoferPackageReference name: 'GoferFaux') workingCopy ]
		raise: Error.
	self 
		should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ]
		raise: Error.
! !

!MetacelloAtomicLoadOrderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/18/2010 11:56'!
testVersion20LoadAtomic

	| project version wc |
	project := self project.
	version := project version: '2.0'.
	self shouldnt: [ version load ] raise: Warning.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-dkh.4').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.15').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferBar-dkh.1'! !

!MetacelloAtomicLoadOrderTest methodsFor: 'versions' stamp: 'DaleHenrichs 3/18/2010 09:40'!
version20: spec 
	<version: '2.0' imports: #('2.0-baseline') >
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		"using #atomic loadType means that package order isn't important"
		spec 
			project: 'GoferFoo' with: '2.0';
			yourself.
		spec 
			package: 'GoferBar' with: 'GoferBar-dkh.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.30';
			package: 'GoferBeau' with: 'GoferBeau-dkh.15';
			yourself ].
! !

MetacelloDictionaryRepositoryTest subclass: #MetacelloCurrentVersionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloCurrentVersionTest methodsFor: 'private' stamp: 'DaleHenrichs 2/5/2010 12:14'!
assertProject: project expectedVersionString: expectedVersionString expectedFidelity: expectedVersionStatus

	| cv versionStatus |
	cv := project currentVersion.
	expectedVersionString == nil 
		ifTrue: [
			^cv == nil
				ifFalse: [ self assert: cv versionStatus == #somethingLoaded ]].
	"validate current version"
	self assert: cv = (project version: expectedVersionString).
	self assert: (versionStatus := cv versionStatus) == expectedVersionStatus.
! !

!MetacelloCurrentVersionTest methodsFor: 'running' stamp: 'dkh 6/7/2011 15:59'!
defaultTimeout

	^MetacelloPlatform current defaultTimeout! !

!MetacelloCurrentVersionTest methodsFor: 'running' stamp: 'dkh 4/18/2011 15:23'!
setUp

	| repo |
	super setUp.
	repo := self configurationRepository.
	self tempRepositories add: repo.
	gofer repository: repo! !

!MetacelloCurrentVersionTest methodsFor: 'running' stamp: 'DaleHenrichs 6/24/2010 15:43'!
tearDownPackages: aGoferInstance

	super tearDownPackages: aGoferInstance.
	(self hasPackage: 'GeauxFoo')
		ifTrue: [ aGoferInstance package: 'GeauxFoo' ].
	(self hasPackage: 'GeauxBar')
		ifTrue: [ aGoferInstance package: 'GeauxBar' ].
	(self hasPackage: 'GeauxFaux')
		ifTrue: [ aGoferInstance package: 'GeauxFaux' ].
	(self hasPackage: 'GeauxBeau')
		ifTrue: [ aGoferInstance package: 'GeauxBeau' ].
	(self hasPackage: 'MetacelloTestConfigurationOfFum')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfFum' ].
	(self hasPackage: 'MetacelloTestConfigurationOfFoo')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfFoo' ].
	(self hasPackage: 'MetacelloTestConfigurationOfFeaux')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfFeaux' ].
	(self hasPackage: 'MetacelloTestConfigurationOfProjectFie')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfProjectFie' ].
	(self hasPackage: 'MetacelloTestConfigurationOfProjectFoe')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfProjectFoe' ].
	(self hasPackage: 'MetacelloTestConfigurationOfProjectFee')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfProjectFee' ].
! !

!MetacelloCurrentVersionTest methodsFor: 'test projects only' stamp: 'DaleHenrichs 2/5/2010 14:37'!
testCompareCurrentVersion

	| version cv fum projectFie projectFee projectFoe foo feaux map |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		package: 'MetacelloTestConfigurationOfProjectFoe'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.
	projectFoe := (Smalltalk at: #MetacelloTestConfigurationOfProjectFoe) new project.

	gofer 
		version: 'GeauxBeau-dkh.56';
		load.
	version := feaux version: '4.0'.
	version load: 'GeauxFoo'.
	version := projectFoe version: '4.0'.
	version load: #('ALL').
	
	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: feaux expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFoe expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.

	foo currentVersion packages do: [:pkg |
		pkg isPackageLoaded
			ifTrue: [ 
				self assert: 
					(pkg 
						compareRelativeCurrentVersion: #= 
						targetVersionStatus: nil 
						using: pkg loader).
				self assert: (pkg 
						compareCurrentVersion: #= 
						targetVersionStatus: nil
						using: pkg loader) ]].

	feaux currentVersion packages do: [:pkg |
		pkg isPackageLoaded
			ifTrue: [ 
				self assert: 
					(pkg 
						compareRelativeCurrentVersion: #= 
						targetVersionStatus: nil 
						using: pkg loader).
				self assert: (pkg 
						compareCurrentVersion: #= 
						targetVersionStatus: nil
						using: pkg loader) ]].

	projectFie currentVersion projects do: [:prj |
		self assert: 
			(prj 
				compareRelativeCurrentVersion: #= 
				targetVersionStatus: #(loadedToSpec) 
				using: prj loader).
		self assert: (prj 
				compareCurrentVersion: #= 
				targetVersionStatus: #(loadedToSpec) 
				using: prj loader) ].

	projectFee currentVersion packages do: [:pkg |
		pkg isPackageLoaded
			ifTrue: [ 
				self assert: 
					(pkg 
						compareRelativeCurrentVersion: #> 
						targetVersionStatus: nil 
						using: pkg loader).
				self assert: (pkg 
						compareCurrentVersion: #> 
						targetVersionStatus: nil
						using: pkg loader) ]].
	projectFee currentVersion projects do: [:prj |
		self assert: 
			(prj 
				compareRelativeCurrentVersion: #= 
				targetVersionStatus: #(loadedToSpec) 
				using: prj loader).
		self assert: (prj 
				compareCurrentVersion: #= 
				targetVersionStatus: #(loadedToSpec) 
				using: prj loader) ].

	projectFoe currentVersion projects do: [:prj |
		self assert: 
			(prj 
				compareRelativeCurrentVersion: #= 
				targetVersionStatus: #(allLoadedToSpec) 
				using: prj loader).
		self deny: (prj 
				compareCurrentVersion: #= 
				targetVersionStatus: #(allLoadedToSpec) 
				using: prj loader) ].

	map := Dictionary new.
	map at: 'Feaux' put: #(loadedToSpec).
	map at: 'Foo' put: #(loadedToSpec).
	map at: 'ProjectFie' put: #(loadedToSpec).
	map at: 'ProjectFee' put: #(loadedMatchConstraints).
	fum currentVersion projects do: [:prj |
		self assert: 
			(prj 
				compareRelativeCurrentVersion: #>= 
				targetVersionStatus: (map at: prj name) 
				using: prj loader).
		self assert: (prj 
				compareCurrentVersion: #>= 
				targetVersionStatus: (map at: prj name) 
				using: prj loader) ].

! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/3/2010 00:06'!
testFeaux40Loaded

	| version fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := fum version: '4.0'.
	version load: #('Feaux').

	self assertProject: foo expectedVersionString: nil expectedFidelity: nil.
	self assertProject: feaux expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
! !

!MetacelloCurrentVersionTest methodsFor: 'test projects only' stamp: 'DaleHenrichs 2/5/2010 13:55'!
testFoe40AllLoaded

	| version cv fum projectFie projectFee projectFoe foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		package: 'MetacelloTestConfigurationOfProjectFoe'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.
	projectFoe := (Smalltalk at: #MetacelloTestConfigurationOfProjectFoe) new project.

	version := feaux version: '4.0'.
	version load: 'GeauxFoo'.
	version := projectFoe version: '4.0'.
	version load: #('ALL').
	gofer 
		version: 'GeauxBeau-dkh.56';
		load.
	
	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: feaux expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFoe expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.

! !

!MetacelloCurrentVersionTest methodsFor: 'test projects only' stamp: 'DaleHenrichs 12/21/2010 10:15'!
testFoe40AllLoadedDefaultPackageNamesToLoad

	| version fum projectFie projectFee projectFoe foo feaux packageNames |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		package: 'MetacelloTestConfigurationOfProjectFoe'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.
	projectFoe := (Smalltalk at: #MetacelloTestConfigurationOfProjectFoe) new project.

	version := feaux version: '4.0'.

	packageNames := version defaultPackageNamesToLoad.
	self assert: packageNames size == 2.
	self assert: (packageNames includes: 'GeauxFoo').
	self assert: (packageNames includes: 'GeauxBar').
	packageNames := version defaultPackageNamesToLoad: #( 'GeauxFoo' ).
	self assert: packageNames size == 1.
	self assert: (packageNames includes: 'GeauxFoo').

	version load: 'GeauxFoo'.

	packageNames := version defaultPackageNamesToLoad: #( 'GeauxFoo' ).
	self assert: packageNames size == 1.
	self assert: (packageNames includes: 'GeauxFoo').

	version := projectFoe version: '4.0'.
	version load: #('ALL').

	packageNames := (foo version: '4.0') defaultPackageNamesToLoad.
	self assert: packageNames size == 6.
	self assert: (packageNames includes: 'GoferFoo').
	self assert: (packageNames includes: 'GoferBar').

	packageNames := (foo version: '4.0') defaultPackageNamesToLoad: #().
	self assert: packageNames size == 2.
	self assert: (packageNames includes: 'GoferFoo').
	self assert: (packageNames includes: 'GoferBar').

! !

!MetacelloCurrentVersionTest methodsFor: 'test projects only' stamp: 'DaleHenrichs 2/6/2010 08:19'!
testFoe40Loaded

	| version cv fum projectFie projectFee projectFoe foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		package: 'MetacelloTestConfigurationOfProjectFoe'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.
	projectFoe := (Smalltalk at: #MetacelloTestConfigurationOfProjectFoe) new project.

	version := projectFoe version: '4.0'.
	version load: #('Foo').

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFoe expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.

! !

!MetacelloCurrentVersionTest methodsFor: 'test projects only' stamp: 'DaleHenrichs 2/6/2010 08:22'!
testFoe40LoadedFoo40Loaded

	| version cv fum projectFie projectFee projectFoe foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		package: 'MetacelloTestConfigurationOfProjectFoe'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.
	projectFoe := (Smalltalk at: #MetacelloTestConfigurationOfProjectFoe) new project.

	version := projectFoe version: '4.0'.
	version load: #('Foo').
	version := foo version: '4.0'.
	version load.

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFoe expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.

! !

!MetacelloCurrentVersionTest methodsFor: 'test projects only' stamp: 'DaleHenrichs 2/6/2010 08:25'!
testFoe40LoadedFoo40Loaded1LaterPackage

	| version cv fum projectFie projectFee projectFoe foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		package: 'MetacelloTestConfigurationOfProjectFoe'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.
	projectFoe := (Smalltalk at: #MetacelloTestConfigurationOfProjectFoe) new project.

	version := projectFoe version: '4.0'.
	version load: #('Foo').
	version := foo version: '4.0'.
	version load.
	gofer
		version: 'GoferFaux-tg.34'; 
		load.

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFoe expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.

! !

!MetacelloCurrentVersionTest methodsFor: 'test projects only' stamp: 'DaleHenrichs 2/6/2010 08:27'!
testFoe40LoadedFoo50Loaded
	"isCurrent and findCurrentVersion gave wrong answers for this scenario in 1.0-beta.22"

	| version cv fum projectFie projectFee projectFoe foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		package: 'MetacelloTestConfigurationOfProjectFoe'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.
	projectFoe := (Smalltalk at: #MetacelloTestConfigurationOfProjectFoe) new project.

	version := foo version: '5.0'.
	version load.

	self assertProject: foo expectedVersionString: '5.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFoe expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.

! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/6/2010 13:35'!
testFoo20Feaux40Loaded

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := fum version: '4.0'.
	version load: #('Feaux').
	version := foo version: '2.0'.
	version load: #('ALL').

	self assertProject: foo expectedVersionString: '2.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: projectFie expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: nil expectedFidelity: nil.! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/3/2010 00:02'!
testFoo20Loaded

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := foo version: '2.0'.
	version load: #('ALL').

	self assertProject: foo expectedVersionString: '2.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: nil expectedFidelity: nil.

! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 12/18/2010 14:00'!
testFoo4020Loaded

	| version cv fum projectFie projectFee foo feaux repo |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	repo := self monticelloRepository.

	version := foo version: '3.0'.
	version load.
	self assertProject: foo expectedVersionString: '3.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: nil expectedFidelity: nil.

	"Load exact match to 2.0"
	Gofer it
		repository: repo;
		version: 'GoferBeau-dkh.25'; 
		metacelloLoad.

	self assertProject: foo expectedVersionString: '2.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: nil expectedFidelity: nil.

! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'dkh 10/11/2011 21:19'!
testFoo403540Loaded1PackageLater

	| version cv fum projectFie projectFee foo feaux repo |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	repo := self monticelloRepository.

	version := foo version: '4.0'.
	version load: #('1' ).
	
	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.

	"Load partial exact match to 3.5"
	Gofer it
		repository: repo;
		version: 'GoferBeau-dkh.54'; 
		version: 'GoferFoo-lr.1'; 
		metacelloLoad.

	self assertProject: foo expectedVersionString: '3.5' expectedFidelity: #loadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '3.5' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: nil expectedFidelity: nil.

	"reload version 4.0"
	version load: '1'.

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.

	"Later package version matches constraints"
	Gofer it
		repository: repo;
		version: 'GoferFaux-tg.34'; 
		metacelloLoad.

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/6/2010 09:07'!
testFoo40Feaux40Loaded

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := fum version: '4.0'.
	version load: #('Feaux' 'Foo').

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/6/2010 09:09'!
testFoo40Loaded

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := fum version: '4.0'.
	version load: #('Foo').

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.

! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'dkh 10/11/2011 21:01'!
testFoo40Loaded1Package1EarlierPackage

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := foo version: '4.0'.
	version load: #('GoferFaux' 'GoferBeau' ).
	gofer
		version: 'GoferFaux-tg.31';
		load.

	self assertProject: foo expectedVersionString: '3.5' expectedFidelity: #loadedMatchConstraints.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '3.5' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: nil expectedFidelity: nil.

! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/6/2010 09:19'!
testFoo40Loaded1Package1LaterPackage

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := foo version: '4.0'.
	version load: #('GoferFaux' 'GoferBar' ).
	gofer
		version: 'GoferFaux-tg.34'; 
		load.

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.

! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/6/2010 09:20'!
testFoo40Loaded2Packages

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := foo version: '4.0'.
	version load: #('GoferFoo' 'GoferBeau' ).

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.

! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/3/2010 00:10'!
testFoo40LoadedEarlierPackage

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := fum version: '4.0'.
	version load: #('Foo').
	gofer
		version: 'GoferFaux-tg.31'; 
		load.

	self assertProject: foo expectedVersionString: '3.5' expectedFidelity: #loadedMatchConstraints.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '3.5' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: nil expectedFidelity: nil.

! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/6/2010 09:22'!
testFoo40LoadedLaterPackage

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := fum version: '4.0'.
	version load: #('Foo').
	gofer
		version: 'GoferFaux-tg.34'; 
		load.

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.

! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'DaleHenrichs 2/6/2010 09:24'!
testFoo50Loaded

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := foo version: '5.0'.
	version load: #('ALL').

	self assertProject: foo expectedVersionString: '5.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedMatchConstraints.

! !

!MetacelloCurrentVersionTest methodsFor: 'test packages only' stamp: 'dkh 4/23/2011 08:57'!
testIssue118

	| version cv foo packageSpec versionInfo53 wc |
	gofer
		package: 'MetacelloTestConfigurationOfFoo'; 
		load.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.

	version := foo version: '3.0'.
	version load.
	packageSpec := version packageNamed: 'GoferBeau'.
	versionInfo53 := packageSpec workingCopy ancestry ancestors first.
	self assertProject: foo expectedVersionString: '3.0' expectedFidelity: #allLoadedToSpec.

	gofer
		version: 'GoferBeau-dkh.25'; 
		load.
	self assertProject: foo expectedVersionString: '2.0' expectedFidelity: #allLoadedToSpec.

	"set up Issue 118 conditions ... simulate a merge of GoferBeau-dkh.53 by adding versionInfo as ancestor"
	packageSpec := version packageNamed: 'GoferBeau'.
	wc := packageSpec workingCopy.
	wc ancestry addAncestor: versionInfo53.
	self assertProject: foo expectedVersionString: '3.0' expectedFidelity: #allLoadedToSpec.
! !

!MetacelloCurrentVersionTest methodsFor: 'test projects and packages' stamp: 'DaleHenrichs 2/3/2010 00:07'!
testProjectFee40Loaded

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := fum version: '4.0'.
	version load: #('ProjectFee').

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: projectFee expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
! !

!MetacelloCurrentVersionTest methodsFor: 'test projects and packages' stamp: 'DaleHenrichs 2/3/2010 00:07'!
testProjectFee40Loaded2Packages

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := projectFee version: '4.0'.
	version load: #('GeauxFaux' 'GeauxBeau').

	self assertProject: foo expectedVersionString: nil expectedFidelity: nil.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFee expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
! !

!MetacelloCurrentVersionTest methodsFor: 'test projects and packages' stamp: 'DaleHenrichs 2/6/2010 13:37'!
testProjectFee40Loaded2PackagesEarlierFoo

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := projectFee version: '4.0'.
	version load: #('GeauxFaux' 'GeauxBeau').
	version := foo version: '2.0'.
	version load: #('ALL').

	self assertProject: foo expectedVersionString: '2.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFie expectedVersionString: nil expectedFidelity: nil.
	self assertProject: projectFee expectedVersionString: '4.0' expectedFidelity: #somethingLoaded.
	self assertProject: fum expectedVersionString: nil expectedFidelity: nil.
! !

!MetacelloCurrentVersionTest methodsFor: 'test projects only' stamp: 'DaleHenrichs 2/6/2010 09:26'!
testProjectFie40Loaded

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := fum version: '4.0'.
	version load: #('ProjectFie').

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: projectFee expectedVersionString: nil expectedFidelity: nil.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #loadedToSpec.
! !

!MetacelloCurrentVersionTest methodsFor: 'test projects only' stamp: 'DaleHenrichs 2/3/2010 00:04'!
testProjectFie40ProjectFee40Loaded

	| version cv fum projectFie projectFee foo feaux |
	gofer
		package: 'MetacelloTestConfigurationOfFum'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		package: 'MetacelloTestConfigurationOfFeaux'; 
		package: 'MetacelloTestConfigurationOfProjectFie'; 
		package: 'MetacelloTestConfigurationOfProjectFee'; 
		load.
	fum := (Smalltalk at: #MetacelloTestConfigurationOfFum) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.
	feaux := (Smalltalk at: #MetacelloTestConfigurationOfFeaux) new project.
	projectFie := (Smalltalk at: #MetacelloTestConfigurationOfProjectFie) new project.
	projectFee := (Smalltalk at: #MetacelloTestConfigurationOfProjectFee) new project.

	version := fum version: '4.0'.
	version load: #('ProjectFee' 'ProjectFie').

	self assertProject: foo expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: feaux expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: projectFie expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: projectFee expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
	self assertProject: fum expectedVersionString: '4.0' expectedFidelity: #allLoadedToSpec.
! !

MetacelloDictionaryRepositoryTest subclass: #MetacelloDetermineCurrentVersionForLoadTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloDetermineCurrentVersionForLoadTest methodsFor: 'running' stamp: 'dkh 4/18/2011 15:23'!
setUp

	| repo |
	super setUp.
	repo := self configurationRepository.
	self tempRepositories add: repo.
	gofer repository: repo! !

!MetacelloDetermineCurrentVersionForLoadTest methodsFor: 'running' stamp: 'DaleHenrichs 2/8/2010 15:48'!
tearDownPackages: aGoferInstance

	super tearDownPackages: aGoferInstance.
	(self hasPackage: 'MetacelloTestConfigurationOfFan')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfFan' ].
	(self hasPackage: 'MetacelloTestConfigurationOfFoo')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfFoo' ].
! !

!MetacelloDetermineCurrentVersionForLoadTest methodsFor: 'tests' stamp: 'DaleHenrichs 2/4/2010 13:26'!
test001

	| version foo fan wc |
	gofer
		package: 'MetacelloTestConfigurationOfFan'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		load.
	fan := (Smalltalk at: #MetacelloTestConfigurationOfFan) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.

	version := foo version: '3.0'.
	version load: #( 'GoferBar' 'GoferFaux').

	"When we load version 2.0 of fan, we recognize that '3.0' of foo is the currentVersion (#allLoadedToSpec 
	 or #loadedToSpec and latestVersion), so we load the packages from version 3.0 of foo instead" 
	version := fan version: '2.0'.
	version load: 'Foo'.

	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.53').
! !

!MetacelloDetermineCurrentVersionForLoadTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/21/2010 10:20'!
test002

	| version foo fan wc |
	gofer
		package: 'MetacelloTestConfigurationOfFan'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		load.
	fan := (Smalltalk at: #MetacelloTestConfigurationOfFan) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.

	version := foo version: '5.0'.
	version load: #( 'GoferBar' 'GoferFaux').

	"load older version of 1 package (that doesn't match spec of earlier version)"
	gofer
		version: 'GoferFaux-tg.33'; 
		load.

	version := fan version: '2.0'.
	self flag: 'revisit this'.
	"self 
		should: [ version load: 'Foo' ]
		raise: MetacelloProjectSpecLoadConflict"
	version load: 'Foo'

! !

!MetacelloDetermineCurrentVersionForLoadTest methodsFor: 'tests' stamp: 'DaleHenrichs 2/4/2010 13:27'!
test003

	| version foo fan wc |
	gofer
		package: 'MetacelloTestConfigurationOfFan'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		load.
	fan := (Smalltalk at: #MetacelloTestConfigurationOfFan) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.

	version := foo version: '5.0'.
	version load: #( 'GoferBar' 'GoferFaux').

	"load later version of 1 package beyond the last version of foo 5.0"
	gofer
		version: 'GoferFaux-tg.35'; 
		load.

	version := fan version: '2.0'.
	version load: 'Foo'.

	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.55').
! !

!MetacelloDetermineCurrentVersionForLoadTest methodsFor: 'tests' stamp: 'DaleHenrichs 2/4/2010 13:27'!
test004

	| version foo fan wc |
	gofer
		package: 'MetacelloTestConfigurationOfFan'; 
		package: 'MetacelloTestConfigurationOfFoo'; 
		load.
	fan := (Smalltalk at: #MetacelloTestConfigurationOfFan) new project.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.

	version := foo version: '5.0'.
	version load: #( 'GoferBar' 'GoferFaux').

	version := fan version: '2.0'.
	version load: 'Far'.

	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.55').
! !

!MetacelloDetermineCurrentVersionForLoadTest methodsFor: 'tests' stamp: 'dkh 10/11/2011 21:15'!
testIssue112

	| version foo wc |
	gofer
		package: 'MetacelloTestConfigurationOfFoo'; 
		load.
	foo := (Smalltalk at: #MetacelloTestConfigurationOfFoo) new project.

	version := foo version: '3.0'.
	version load: #( 'GoferBar' 'GoferFaux').

	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar.branch-lr.1').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.30').
	self should: [(GoferPackageReference name: 'GoferBeau') workingCopy] raise: Error.

	"A load of GoferBeau for version 3.5, should also load the correct package for GoferFaux (GoferFaux-tg.31)" 
	version := foo version: '3.5'.
	version load: 'GoferBeau'.

	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.0').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.54').
	"this is the crux of Issue 112"
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.31').
! !

!MetacelloDictionaryRepositoryTest methodsFor: 'running' stamp: 'dkh 1/12/2010 14:46'!
alternateRepository
	"MetacelloAlternateResource reset"

	^ MetacelloAlternateResource current monticelloRepository! !

!MetacelloDictionaryRepositoryTest methodsFor: 'running' stamp: 'dkh 1/12/2010 14:46'!
configurationRepository
	"MetacelloConfigurationResource reset"

	^ MetacelloConfigurationResource current monticelloRepository! !

!MetacelloDictionaryRepositoryTest methodsFor: 'running' stamp: 'dkh 9/4/2012 21:24'!
defaultTimeout
    "I don't want no stkinkin' timeouts"

    ^ 60000! !

!MetacelloDictionaryRepositoryTest methodsFor: 'running' stamp: 'DaleHenrichs 12/21/2010 10:20'!
doSilently

	^true! !

!MetacelloDictionaryRepositoryTest methodsFor: 'utilities' stamp: 'dkh 12/30/2009 10:33'!
hasPackage: aString
	| package |
	package := MCWorkingCopy allManagers
		detect: [ :each | each packageName = aString ]
		ifNone: [ nil ].
	^ package notNil! !

!MetacelloDictionaryRepositoryTest methodsFor: 'accessing' stamp: 'dkh 1/6/2010 20:43'!
loadType

	^#linear! !

!MetacelloDictionaryRepositoryTest methodsFor: 'accessing' stamp: 'dkh 1/12/2010 13:51'!
monticelloRepository
	"MetacelloMonticelloResource reset"
	^ MetacelloMonticelloResource current monticelloRepository! !

!MetacelloDictionaryRepositoryTest methodsFor: 'accessing' stamp: 'DaleHenrichs 9/22/2010 15:37'!
project

	| constructor project |
	"Construct Metacello project"
	constructor := MetacelloVersionConstructor on: self.
	project := constructor project.
	project loader: 
		((project loaderClass new)
			shouldDisablePackageCache: true;
			yourself).
	project loadType: self loadType.
	^project! !

!MetacelloDictionaryRepositoryTest methodsFor: 'accessing' stamp: 'DaleHenrichs 12/22/2010 13:43'!
projectWith: projectAttributes

	| project |
	"Construct Metacello project"
	project := MetacelloMCProject new.
	project projectAttributes: projectAttributes.
	MetacelloVersionConstructor on: self project: project.
	project loader: 
		((project loaderClass new)
			shouldDisablePackageCache: true;
			yourself).
	project loadType: self loadType.
	^project
! !

!MetacelloDictionaryRepositoryTest methodsFor: 'running' stamp: 'DaleHenrichs 12/21/2010 10:20'!
runCase
	| original |
	(self doSilently) ifFalse: [ ^super runCase ].
	original := MetacelloPlatform current bypassGoferLoadUpdateCategories.
	[ 
	MetacelloPlatform current bypassGoferLoadUpdateCategories: true.
	^ SystemChangeNotifier uniqueInstance doSilently: [ super runCase ] ]
		ensure: [ MetacelloPlatform current bypassGoferLoadUpdateCategories: original ]! !

!MetacelloDictionaryRepositoryTest methodsFor: 'running' stamp: 'dkh 4/18/2011 15:21'!
setUp
	| repo |
	super setUp.
	MetacelloConfigurationResource projectAttributes: nil.
	repo := self monticelloRepository.
	self tempRepositories add: repo.
	gofer repository: repo.
	Smalltalk at: #'Metacello_Gofer_Test_Repository' put: repo.
	repo := self alternateRepository.
	self tempRepositories add: repo.
	Smalltalk at: #'Metacello_Configuration_Test_Alternate_Repository' put: repo.
	repo := self configurationRepository.
	self tempRepositories add: repo.
	Smalltalk at: #'Metacello_Configuration_Test_Repository' put: repo.
! !

!MetacelloDictionaryRepositoryTest methodsFor: 'running' stamp: 'dkh 4/18/2011 15:22'!
tearDown
	| aGofer |
	super tearDown.
	aGofer := Gofer new.
	self tearDownPackages: aGofer.
	aGofer references notEmpty ifTrue: [ aGofer metacelloUnload ].
	Smalltalk removeKey: #'Metacello_Gofer_Test_Repository' ifAbsent: [].
	Smalltalk removeKey: #'Metacello_Configuration_Test_Repository' ifAbsent: [].
	Smalltalk removeKey: #'Metacello_Configuration_Test_Alternate_Repository' ifAbsent: [].
	self tempRepositories do: [:repo | MCRepositoryGroup default removeRepository: repo ].
! !

!MetacelloDictionaryRepositoryTest methodsFor: 'running' stamp: 'DaleHenrichs 2/8/2010 15:46'!
tearDownPackages: aGoferInstance

	(self hasPackage: 'GoferFoo')
		ifTrue: [ aGoferInstance package: 'GoferFoo' ].
	(self hasPackage: 'GoferBar')
		ifTrue: [ aGoferInstance package: 'GoferBar' ].
	(self hasPackage: 'GoferFaux')
		ifTrue: [ aGoferInstance package: 'GoferFaux' ].
	(self hasPackage: 'GoferBeau')
		ifTrue: [ aGoferInstance package: 'GoferBeau' ].
	(self hasPackage: 'MetacelloTestConfigurationOfFoo')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfFoo' ].
! !

!MetacelloDictionaryRepositoryTest methodsFor: 'accessing' stamp: 'dkh 4/18/2011 15:20'!
tempRepositories

	tempRepositories ifNil: [ tempRepositories := OrderedCollection new ].
	^tempRepositories! !

MetacelloDictionaryRepositoryTest subclass: #MetacelloGoferBasedLoaderTest
	instanceVariableNames: 'postloadAnswer postLoadExecuted preLoadExecuted'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

MetacelloGoferBasedLoaderTest subclass: #MetacelloGoferBasedAtomicLoaderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 01/15/2010 15:58'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	super baseline10: spec 
! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 4/9/2010 11:39'!
baseline11: spec 
	<version: '1.1-baseline'>
	
	super baseline11: spec 
! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 01/15/2010 15:58'!
baselineIssue40: spec 
	<version: 'Issue40-baseline'>
	
	super baselineIssue40: spec 
! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 5/19/2010 13:57'!
baselineIssue77: spec 
	<version: 'Issue77-baseline'>
	
	super baselineIssue77: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 08/30/2010 13:12'!
baselineIssue95: spec 
	<version: 'Issue95-baseline'>
	
	super baselineIssue95: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 01/15/2010 15:59'!
baselineMoose: spec 
	<version: '1.0-Moose'>
	
	super baselineMoose: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'accessing' stamp: 'dkh 1/6/2010 20:44'!
loadType

	^#atomic! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 01/15/2010 15:59'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>
	
	super version10: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 01/15/2010 15:59'!
version11: spec
	<version: '1.1' imports: #('1.0-baseline' )>
	
	super version11: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 1/19/2010 15:13'!
version30: spec 
	<version: '3.0'>
	
	super version30: spec 
! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 4/9/2010 11:23'!
version31: spec 
	<version: '3.1'>
	
	super version31: spec 
! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 1/19/2010 15:13'!
version40: spec 
	<version: '4.0'>
	
	super version40: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 1/19/2010 15:13'!
version50: spec 
	<version: '5.0'>
	
	super version50: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 4/16/2010 10:24'!
version60: spec 
	<version: '6.0'>
	
	super version60: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 4/16/2010 10:24'!
version61: spec 
	<version: '6.1'>
	
	super version61: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 4/16/2010 10:33'!
version62: spec 
	<version: '6.2'>
	
	super version62: spec! !

!MetacelloGoferBasedAtomicLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 4/16/2010 10:33'!
version63: spec 
	<version: '6.3'>
	
	super version63: spec! !

!MetacelloGoferBasedLoaderTest methodsFor: 'baselines' stamp: 'dkh 12/30/2009 15:01'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo';
			package: 'GoferBar';
			yourself ].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 4/9/2010 11:40'!
baseline11: spec 
	<version: '1.1-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with: [
				spec 
					preLoadDoIt: #preloadExecute;
					postLoadDoIt: #postloadExecute ];
			yourself ].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'baselines' stamp: 'dkh 1/12/2010 13:11'!
baselineIssue40: spec 
	<version: 'Issue40-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo';
			package: 'GoferBar' with: [
				spec repository: 'dictionary://Metacello_Configuration_Test_Alternate_Repository' ];
			yourself ].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 12/20/2010 12:34'!
baselineIssue77: spec 
	<version: 'Issue77-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'B' with: [
				spec
					className: 'MetacelloTestConfigurationOfIssue77B';
					versionString: '1.0';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: 'D' with: [
				spec
					className: 'MetacelloTestConfigurationOfIssue77D';
					versionString: '1.0';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 08/30/2010 11:54'!
baselineIssue95: spec 
	<version: 'Issue95-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Issue95' with: [
				spec
					className: 'MetacelloTestConfigurationOfProjectIssue95';
					versionString: '4.0';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 1/20/2010 09:59'!
baselineMoose: spec 
	<version: '1.0-Moose'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFaux' with: [
				spec file: 'GoferFaux-' ];
			yourself ].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'doits' stamp: 'DaleHenrichs 4/9/2010 12:31'!
postloadExecute

	postLoadExecuted := true! !

!MetacelloGoferBasedLoaderTest methodsFor: 'doits' stamp: 'dkh 1/6/2010 21:19'!
postloadSupplyingAnswers

	postloadAnswer := ProvideAnswerNotification signal: 'postload'.
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'doits' stamp: 'DaleHenrichs 4/9/2010 11:40'!
preloadExecute

	preLoadExecuted := true! !

!MetacelloGoferBasedLoaderTest methodsFor: 'running' stamp: 'DaleHenrichs 5/19/2010 14:13'!
setUp

	super setUp.
	Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result' put: false.
	preLoadExecuted := postLoadExecuted := false.
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'running' stamp: 'DaleHenrichs 12/22/2010 14:11'!
tearDown
	super tearDown.
	Smalltalk removeKey: #'Metacello_Configuration_Test_DoIt_Result' ifAbsent: [].
	MetacelloConfigurationResource projectAttributes: nil.! !

!MetacelloGoferBasedLoaderTest methodsFor: 'running' stamp: 'DaleHenrichs 12/22/2010 14:07'!
tearDownPackages: aGoferInstance

	super tearDownPackages: aGoferInstance.
	(self hasPackage: 'GeauxBar')
		ifTrue: [ aGoferInstance package: 'GeauxBar' ].
	(self hasPackage: 'GeauxBeau')
		ifTrue: [ aGoferInstance package: 'GeauxBeau' ].
	(self hasPackage: 'MetacelloTestConfigurationOfFix')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfFix' ].
	(self hasPackage: 'MetacelloTestConfigurationOfIssue77B')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfIssue77B' ].
	(self hasPackage: 'MetacelloTestConfigurationOfIssue77C')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfIssue77C' ].
	(self hasPackage: 'MetacelloTestConfigurationOfIssue77D')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfIssue77D' ].
	(self hasPackage: 'MetacelloTestConfigurationOfProjectLoop')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfProjectLoop' ].
	(self hasPackage: 'MetacelloTestConfigurationOfProjectInfinite')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfProjectInfinite' ].
	(self hasPackage: 'MetacelloTestConfigurationOfProjectIssue95')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfProjectIssue95' ].
	(self hasPackage: 'MetacelloTestConfigurationOfProjectToolBox')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfProjectToolBox' ].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 4/9/2010 11:42'!
testBaseline11PrePostLoadFetch

	| project version |
	project := self project.
	version := project version: '1.1-baseline'.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version fetch.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 4/9/2010 13:18'!
testBaseline11PrePostLoadLoad

	| project version loader |
	project := self project.
	version := project version: '1.1-baseline'.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: preLoadExecuted.
	self assert: postLoadExecuted.
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/12/2010 10:34'!
testBaselineFetch

	| project version loader files |
	project := self project.
	version := project version: '1.0-baseline'.
	loader := version fetch.
	files := #('GoferFoo-lr.4' 'GoferBar-lr.1') asOrderedCollection.
	loader loadDirective packageDirectivesDo: [:pkgDirective | 
		files remove: pkgDirective file ifAbsent: [ self assert: false ]].
	loader loadDirective versionDirectivesDo: [:vrsnDirective |
		vrsnDirective loader ~~ nil
			ifTrue: [ | spec |
				spec := vrsnDirective spec.
				self assert: (spec isKindOf: MetacelloVersionSpec) ]].
	self assert: files isEmpty
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'dkh 01/14/2010 11:56'!
testBaselineLoad

	| project version wc |
	project := self project.
	version := project version: '1.0-baseline'.
	version load.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.4').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferBar-lr.1'! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/12/2010 09:32'!
testBaselineRecord

	| project version loader files |
	project := self project.
	version := project version: '1.0-baseline'.
	loader := version record.
	files := #('GoferFoo' 'GoferBar') asOrderedCollection.
	loader loadDirective packageDirectivesDo: [:pkgDirective | 
		files remove: pkgDirective packageName ifAbsent: [ self assert: false ]].
	self assert: files isEmpty
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/4/2010 20:07'!
testIssue40Baseline

	| project version wc1 wc2 |
	project := self project.
	version := project version: 'Issue40-baseline'.
	version load.
	wc1 := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: wc1 repositoryGroup repositories size = 2.
	self assert: (wc1 repositoryGroup includes: (Smalltalk at: #'Metacello_Gofer_Test_Repository')).
	self assert: (wc1 ancestry ancestors first name = 'GoferFoo-lr.4').
	wc2 := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc2 ancestry ancestors first name = 'GoferBar-dkh.25').
	self assert: wc2 repositoryGroup repositories size = 2.
	self assert: (wc2 repositoryGroup includes: (Smalltalk at: #'Metacello_Configuration_Test_Alternate_Repository')).
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'dkh 10/11/2011 21:14'!
testIssue49PartialLoadA

	| project version wc |
	project := self project.
	version := project version: '4.0'.
	version load: '1'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.1').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.0').
	self should: [ (GoferPackageReference name: 'GoferFaux') workingCopy ] raise: Error.
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 01/20/2010 13:23'!
testIssue49PartialLoadB

	| project version wc |
	project := self project.
	version := project version: '5.0'.
	version load: '2'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.2').
	self should: [ (GoferPackageReference name: 'GoferBar') workingCopy ] raise: Error.
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.34').
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'dkh 10/11/2011 21:14'!
testIssue49PartialLoadC

	| project version wc |
	project := self project.
	version := project version: '4.0'.
	version load: '1'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.1').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.0').
	self should: [ (GoferPackageReference name: 'GoferFaux') workingCopy ] raise: Error.
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.
	version := project version: '5.0'.
	version load: '2'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.2').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.34').
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 01/20/2010 13:57'!
testIssue49PartialLoadD

	| project version wc |
	project := self project.
	version := project version: '5.0'.
	version load: '2'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.2').
	self should: [ (GoferPackageReference name: 'GoferBar') workingCopy ] raise: Error.
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.34').
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.
	version := project version: '4.0'.
	version load: '1'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.2').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.34').
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 01/20/2010 13:26'!
testIssue49PartialLoadE

	| project version wc |
	project := self project.
	version := project version: '5.0'.
	version load: '2'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.2').
	self should: [ (GoferPackageReference name: 'GoferBar') workingCopy ] raise: Error.
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.34').
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.
	version := project version: '4.0'.
	version load: '3'. "should get error, since there is no GoferBeau package in 5.0"
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 01/20/2010 13:55'!
testIssue49PartialLoadF

	| project version wc |
	project := self project.
	version := project version: '5.0'.
	version load: '4'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.2').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.34').
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.
	version := project version: '4.0'.
	version load: '4'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.2').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.34').
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'dkh 10/11/2011 21:20'!
testIssue49PartialLoadG

	| project version wc |
	project := self project.
	version := project version: '4.0'.
	version load: '4'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.1').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.0').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.32').
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.
	version := project version: '5.0'.
	version load: '4'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.2').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.34').
	self should: [ (GoferPackageReference name: 'GoferBeau') workingCopy ] raise: Error.
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/7/2010 08:11'!
testIssue59PackageSpecRepositoryOverrides
	"test for Issue 59: http://code.google.com/p/metacello/issues/detail?id=59"
	
	| project version wc repoSpec pkg loader |
	project := self project.
	version := project version: '1.0'.
	repoSpec := version spec repositorySpecs first.
	pkg := version packageNamed: 'GoferBar'.
	pkg repository: repoSpec.
	loader := pkg loader.
	loader loaderPolicy: (MetacelloLoaderPolicy overrideRepositories: (OrderedCollection with: MCDictionaryRepository new)).
	self should: [ pkg load ] raise: Error.
	loader loaderPolicy: (MetacelloLoaderPolicy overrideRepositories: (OrderedCollection with: (Smalltalk at: #'Metacello_Gofer_Test_Repository'))).
	pkg load.
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-jf.1').
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 5/19/2010 14:29'!
testIssue77
	"The following project structure is loaded:
		project A 1.0
	   		project B 1.0
	     		project C 1.2
	   		project D 1.0 [without a direct load reference for C, but specifying version 1.3 of C]
	     		project C 1.3
	 and with the bug, project C version 1.3 is _not_ loaded.
	"

	| project version loader wc |
	project := self project.
	version := project version: 'Issue77-baseline'.
	loader := version load.
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.53').
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.4').
	self 
		should: [ (GoferPackageReference name: 'GeauxBeau') workingCopy ]
		raise: Error! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'dkh 2/22/2011 18:36'!
testIssue95
	| project version wc |
	project := self project.
	version := project version: 'Issue95-baseline'.
	gofer
		version: 'GoferFaux-tg.30';
		version: 'GeauxBeau-dkh.55';
		version: 'GeauxBar.branch-lr.2';
		load.
	version load.
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.30').
	wc := (GoferPackageReference name: 'GeauxBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GeauxBeau-dkh.55').
	wc := (GoferPackageReference name: 'GeauxBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GeauxBar.branch-lr.2').
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 4/16/2010 10:31'!
testMczFileExplicitLoad
	"Older files will be loaded if directly referenced from the project being loaded (explicit version request)"
	
	| project version wc |
	project := self project.
	version := project version: '6.2'.
	version load.

	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.4').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.35').

	version := project version: '6.3'.
	version load.

	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.4').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.53').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	
	"explicit load older mcz file IS loaded ... see testMczFileImplicitLoad for alternate case"
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.31').
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 4/16/2010 10:31'!
testMczFileImplicitLoad
	"when loading a project reference, do not load mcz files that are older than the currently loaded mcz files (implicit version request)"
	
	| project version wc |
	project := self project.
	version := project version: '6.0'.
	version load.

	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.4').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.35').

	version := project version: '6.1'.
	version load.

	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.4').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.53').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	
	"implicit load older mcz file NOT loaded ... see testMczFileExplicitLoad for alternate case"
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.35').
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 2/4/2010 15:14'!
testMooseBaselineLoad

	| project version wc test |
	project := self project.
	version := project version: '1.0-Moose'.
	version load.
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.35').
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'dkh 2/22/2011 18:37'!
testNestedLoad1

	| project version loader wc configurationName |
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer repository: self configurationRepository.
	gofer package: configurationName.
	gofer load.
	MetacelloConfigurationResource projectAttributes: #(#'level1_1' #'level2_2' #'level3_2' #'level2_1').
	project := (Smalltalk at: configurationName asSymbol) project.
	version := project version: '1.3.3-baseline'.
	loader := version load.
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-jf.1').
	wc := (GoferPackageReference name: 'GeauxBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GeauxBar.branch-lr.2').
	wc := (GoferPackageReference name: 'GeauxBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GeauxBeau-dkh.55').
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.1').
	self 
		should: [ (GoferPackageReference name: 'GoferFaux') workingCopy ]
		raise: Error! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'dkh 1/5/2011 16:35'!
testNestedLoad2

	| project version loader wc configurationName |
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer repository: self configurationRepository.
	gofer package: configurationName.
	gofer load.
	MetacelloConfigurationResource projectAttributes: #(#'level1_1' #'level2_2' #'level3_2' #'level2_1').
	project := (Smalltalk at: configurationName asSymbol) project.
	version := project version: '1.3.2-baseline'.
	loader := version load.
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.25').
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'dkh 1/5/2011 16:35'!
testNestedLoad3

	| project version loader wc configurationName |
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer repository: self configurationRepository.
	gofer package: configurationName.
	gofer load.
	MetacelloConfigurationResource projectAttributes: #(#'level1_1' #'level2_2' #'level2_1' #'level3_2' ).
	project := (Smalltalk at: configurationName asSymbol) project.
	version := project version: '1.3.2-baseline'.
	loader := version load.
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.55').
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'dkh 2/22/2011 20:07'!
testProjectFetch

	| project version wc files loader |
	project := self project.
	version := project version: '3.0'.
	loader := version fetch.
	files := #('MetacelloTestConfigurationOfFoo-dkh.1' 'GoferFoo-lr.1' 'GoferBar.branch-lr.1' 'GoferFaux-tg.30' 'GoferBeau-dkh.53' ) asOrderedCollection.
	loader loadDirective packageDirectivesDo: [:pkgDirective | | file |
		file := pkgDirective file.
		self assert: (files indexOf: file) = 1.
		files remove: file ifAbsent: [ self assert: false ]].
	loader loadDirective versionDirectivesDo: [:vrsnDirective |
		vrsnDirective loader ~~ nil
			ifTrue: [ | spec |
				spec := vrsnDirective spec.
				self assert: (spec isKindOf: MetacelloVersionSpec) ]].
	self deny: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result')
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'dkh 2/22/2011 20:07'!
testProjectLoad

	| project version wc |
	project := self project.
	version := project version: '3.0'.
	version load.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.1').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar.branch-lr.1').
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.53').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.30').
	self assert: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result')
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 4/9/2010 11:24'!
testProjectPrePostLoad

	| project version |
	project := self project.
	version := project version: '3.1'.
	self deny: preLoadExecuted.
	self deny: postLoadExecuted.
	version load.
	self assert: preLoadExecuted.
	self assert: postLoadExecuted.
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'dkh 9/2/2012 11:03'!
testProjectRecord
    | project version names loader |
    Transcript
        cr;
        show: 'testProjectRecord [0]'.
    self deny: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result').
    Transcript
        cr;
        show: 'testProjectRecord [1]'.
    project := self project.
    version := project version: '3.0'.
    loader := version record.
    names := #('MetacelloTestConfigurationOfFoo' 'GoferFoo' 'GoferBar' 'GoferFaux' 'GoferBeau') asOrderedCollection.
    loader loadDirective
        packageDirectivesDo: [ :pkgDirective | 
            | name |
            name := pkgDirective packageName.
            Transcript
                cr;
                show: 'testProjectRecord [4]: ' , name.
            self assert: (names indexOf: name) = 1.
            Transcript
                cr;
                show: 'testProjectRecord [5]: ' , name.
            names remove: name ifAbsent: [ self assert: false ].
            Transcript
                cr;
                show: 'testProjectRecord [6]: ' , name ].
    Transcript
        cr;
        show: 'testProjectRecord [2]'.
    self deny: (Smalltalk at: #'Metacello_Configuration_Test_DoIt_Result').
    Transcript
        cr;
        show: 'testProjectRecord [3]'! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'dkh 1/6/2010 21:19'!
testRepositoryOverrides

	| project version wc |
	project := self project.
	version := project version: '1.0'.
	version repositoryOverrides: (OrderedCollection with: MCDictionaryRepository new).
	self 
		should: [ version load ]
		raise: Error.
	version repositoryOverrides: (OrderedCollection with: (Smalltalk at: #'Metacello_Gofer_Test_Repository')).
	version load.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.1').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-jf.1').
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/12/2010 10:22'!
testRepositoryOverridesFetch

	| project version loader names |
	project := self project.
	version := project version: '1.0'.
	version repositoryOverrides: (OrderedCollection with: MCDictionaryRepository new).
	self 
		should: [ version fetch ]
		raise: Error.
	version repositoryOverrides: (OrderedCollection with: (Smalltalk at: #'Metacello_Gofer_Test_Repository')).
	loader := version fetch.
	names := #('GoferFoo-lr.1' 'GoferBar-jf.1' ) asOrderedCollection.
	loader loadDirective packageDirectivesDo: [:pkgDirective | | name |
		name := pkgDirective file.
		self assert: (names indexOf: name) = 1.
		names remove: name ifAbsent: [ self assert: false ]].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/12/2010 10:23'!
testRepositoryOverridesRecord

	| project version loader names |
	project := self project.
	version := project version: '1.0'.
	version repositoryOverrides: (OrderedCollection with: MCDictionaryRepository new).
	self 
		shouldnt: [ version record ]
		raise: Error.
	version repositoryOverrides: (OrderedCollection with: (Smalltalk at: #'Metacello_Gofer_Test_Repository')).
	loader := version record.
	names := #('GoferFoo' 'GoferBar' ) asOrderedCollection.
	loader loadDirective packageDirectivesDo: [:pkgDirective | | name |
		name := pkgDirective packageName.
		self assert: (names indexOf: name) = 1.
		names remove: name ifAbsent: [ self assert: false ]].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'dkh 1/6/2010 21:20'!
testSupplyingAnswerLoad

	| project version wc |
	project := self project.
	version := project version: '1.1'.
	self deny: postloadAnswer = 'postload answer'.
	version load.
	self assert: postloadAnswer = 'postload answer'.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.1').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-jf.1').
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/12/2010 10:34'!
testVersionFetch

	| project version loader names |
	project := self project.
	version := project version: '1.0'.
	loader := version fetch.
	names := #('GoferFoo-lr.1' 'GoferBar-jf.1' ) asOrderedCollection.
	loader loadDirective packageDirectivesDo: [:pkgDirective | | name |
		name := pkgDirective file.
		self assert: (names indexOf: name) = 1.
		names remove: name ifAbsent: [ self assert: false ]].
	loader loadDirective versionDirectivesDo: [:vrsnDirective |
		vrsnDirective loader ~~ nil
			ifTrue: [ | spec |
				spec := vrsnDirective spec.
				self assert: (spec isKindOf: MetacelloVersionSpec) ]].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'dkh 1/6/2010 21:19'!
testVersionLoad

	| project version wc |
	project := self project.
	version := project version: '1.0'.
	version load.
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.1').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-jf.1').
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/12/2010 10:24'!
testVersionRecord

	| project version loader names |
	project := self project.
	version := project version: '1.0'.
	loader := version record.
	names := #('GoferFoo' 'GoferBar' ) asOrderedCollection.
	loader loadDirective packageDirectivesDo: [:pkgDirective | | name |
		name := pkgDirective packageName.
		self assert: (names indexOf: name) = 1.
		names remove: name ifAbsent: [ self assert: false ]].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'versions' stamp: 'dkh 1/6/2010 20:38'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.1';
			package: 'GoferBar' with: 'GoferBar-jf.1';
			yourself. ].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'versions' stamp: 'dkh 1/6/2010 20:39'!
version11: spec
	<version: '1.1' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec 
			package: 'GoferFoo' with: [
				spec
					file: 'GoferFoo-lr.1';
					supplyingAnswers: #(#('postload' 'postload answer'));
					postLoadDoIt: #postloadSupplyingAnswers ];
			package: 'GoferBar' with: 'GoferBar-jf.1';
			yourself. ].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 3/11/2010 23:22'!
version30: spec 
	<version: '3.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: '1' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '3.0';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself. ].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 4/9/2010 11:40'!
version31: spec 
	<version: '3.1'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: '1' with: [
				spec
					preLoadDoIt: #preloadExecute;
					postLoadDoIt: #postloadExecute;
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '3.0';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself. ].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 3/11/2010 23:22'!
version40: spec 
	<version: '4.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: '1' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '4.0';
					loads: #('1');
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: '2' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '4.0';
					loads: #('2');
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: '3' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '4.0';
					loads: #('GoferBeau');
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself.

		spec
			group: '4' with: #('1' '2') ].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 3/11/2010 23:23'!
version50: spec 
	<version: '5.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: '1' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '5.0';
					loads: #('1');
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			project: '2' with: [
				spec
					className: 'MetacelloTestConfigurationOfFoo';
					versionString: '5.0';
					loads: #('2');
					file: 'MetacelloTestConfigurationOfFoo';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself.

		spec
			group: '4' with: #('1' '2') ].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 4/16/2010 11:12'!
version60: spec
	<version: '6.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFix';
					versionString: '6.0';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 4/16/2010 11:12'!
version61: spec
	<version: '6.1'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			project: 'Foo' with: [
				spec
					className: 'MetacelloTestConfigurationOfFix';
					versionString: '6.1';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 4/16/2010 10:26'!
version62: spec
	<version: '6.2'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.4';
			package: 'GoferBar' with: 'GoferBar-lr.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.35';
			yourself. ].
! !

!MetacelloGoferBasedLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 4/16/2010 10:26'!
version63: spec
	<version: '6.3'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.4';
			package: 'GoferBar' with: 'GoferBar-lr.1';
			package: 'GoferBeau' with: 'GoferBeau-dkh.53';
			package: 'GoferFaux' with: 'GoferFaux-tg.31';
			yourself. ].
! !

MetacelloDictionaryRepositoryTest subclass: #MetacelloGoferFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloGoferFunctionalTest methodsFor: 'baselines' stamp: 'DaleHenrichs 1/20/2010 09:58'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
	spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo';
			package: 'GoferBar';
			package: 'GoferFaux';
			yourself ].
! !

!MetacelloGoferFunctionalTest methodsFor: 'baselines' stamp: 'dkh 11/16/2011 11:08'!
baseline20: spec 
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'GoferFoo' with: [spec repository: 'dictionary://Metacello_Gofer_Test_Repository' ];
			package: 'GoferBar' with: [spec repository: 'dictionary://Metacello_Gofer_Test_Repository' ];
			package: 'GoferFaux' with: [spec repository: 'dictionary://Metacello_Gofer_Test_Repository' ];
			yourself ].
! !

!MetacelloGoferFunctionalTest methodsFor: 'running' stamp: 'dkh 11/16/2011 10:43'!
doSilently

	^(#(#testCommitPackageSpec #testCommitPackageVersion #testPackagesNeedSaving #testIssue155) includes: testSelector asSymbol) not! !

!MetacelloGoferFunctionalTest methodsFor: 'accessing' stamp: 'dkh 12/30/2009 10:37'!
repositorySpec

	| project version |
	project := self project.
	version := project version: '1.0-baseline'.
	^version spec repositorySpecs first.
! !

!MetacelloGoferFunctionalTest methodsFor: 'running' stamp: 'dkh 1/12/2010 14:18'!
tearDown
	super tearDown.
	MetacelloMonticelloResource reset. "testCommitPackageSpec modifies the repository resource"! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'dkh 12/22/2009 11:48'!
testBasics
	| repoSpec repo |
	repoSpec := self repositorySpec.
	repo := repoSpec createRepository.
	self assert: repoSpec type = 'dictionary'.
	self assert: repo class == MCDictionaryRepository.
	! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'DaleHenrichs 12/18/2010 20:15'!
testCommitNewPackageSpec
	| repoSpec repo project packagesNeedSaving allVersionsSize packageName |
	project := self project.
	repoSpec := self repositorySpec.
	repo := repoSpec createRepository.
	allVersionsSize := repo allVersionInfos size.
	gofer repository: repo.
	gofer 
		package: 'GoferFoo'; 
		package: 'GoferBar'; 
		metacelloLoad.
	"Create new package"
	packageName := 'GoferFaux'.
	PackageInfo registerPackageName: packageName.
	MCWorkingCopy forPackage: (MetacelloTestsMCPackage new name: packageName).
	(MCClassDefinition 
		name: (packageName copyWithout: $-) asSymbol 
		superclassName: #Object 
		category: packageName asSymbol 
		instVarNames: #() 
		comment: '') createClass.
	self assert: (packagesNeedSaving := project packagesNeedSaving: '1.0-baseline') notEmpty.
	packagesNeedSaving do: [:assoc | | gof |
		gof := Gofer new.
		gof disablePackageCache.
		gof repository: assoc value.
		gof package: assoc key name.
		gof commit: 'testing' ].
	self assert: repo allVersionInfos size = (allVersionsSize + 1)! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'DaleHenrichs 12/18/2010 14:01'!
testCommitPackageSpec
	| repoSpec repo project packagesNeedSaving allVersionsSize |
	project := self project.
	repoSpec := self repositorySpec.
	repo := repoSpec createRepository.
	allVersionsSize := repo allVersionInfos size.
	gofer repository: repo.
	gofer 
		package: 'GoferFoo'; 
		package: 'GoferBar'; 
		metacelloLoad.
	(Smalltalk classNamed: #GoferBar) compile: 'foo'.
	self assert: (packagesNeedSaving := project packagesNeedSaving: '1.0-baseline') notEmpty.
	packagesNeedSaving do: [:assoc | | gof |
		gof := Gofer new.
		gof disablePackageCache.
		gof repository: assoc value.
		gof package: assoc key name.
		gof commit: 'testing' ].
	self assert: repo allVersionInfos size = (allVersionsSize + 1)! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'DaleHenrichs 12/18/2010 14:01'!
testCommitPackageVersion
	| repoSpec repo project packagesNeedSaving allVersionsSize |
	project := self project.
	repoSpec := self repositorySpec.
	repo := repoSpec createRepository.
	allVersionsSize := repo allVersionInfos size.
	gofer repository: repo.
	gofer 
		package: 'GoferFoo'; 
		package: 'GoferBar'; 
		metacelloLoad.
	(Smalltalk classNamed: #GoferBar) compile: 'foo'.
	self assert: (packagesNeedSaving := project packagesNeedSaving: '1.0') notEmpty.
	packagesNeedSaving do: [:assoc | | gof |
		gof := Gofer new.
		gof disablePackageCache.
		gof repository: assoc value.
		gof package: assoc key name.
		gof commit: 'testing' ].
	self assert: repo allVersionInfos size = (allVersionsSize + 1)! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'dkh 10/11/2011 22:43'!
testComparison

	| blk |
	blk := [:file1 :operator :file2 | | ref1 ref2 |
		ref1 := GoferResolvedReference name: file1.
		ref2 := GoferResolvedReference name: file2.
		ref1 compare: ref2 using: operator].
	self assert: (blk value: 'GoferFaux-tg.34' value: #>= value: 'GoferFaux-tg.32').
	self assert: (blk value: 'GoferFaux-tg.32' value: #<= value: 'GoferFaux-tg.34').
	self assert: (blk value: 'GoferBar.branch-lr.2' value: #> value: 'GoferBar.branch-lr.1').
	self deny: (blk value: 'GoferBar-lr.1' value: #> value: 'GoferBar.branch-lr.1').
	self assert: (blk value: 'GoferBar-lr.1' value: #< value: 'GoferBar.branch-lr.1').
	self deny: (blk value: 'GoferBar-lr.1' value: #= value: 'GoferBar.branch-lr.1').
	self assert: (blk value: 'GoferBar.branch-lr.1' value: #> value: 'GoferBar-lr.1').
	self deny: (blk value: 'GoferBar.branch-lr.1' value: #< value: 'GoferBar-lr.1').
	self deny: (blk value: 'GoferBar.branch-lr.1' value: #= value: 'GoferBar-lr.1').
	self assert: (blk value: 'GoferBar-lr.1' value: #> value: 'GoferBar-jf.1').
	self deny: (blk value: 'GoferBar-lr.1' value: #< value: 'GoferBar-jf.1').
	self deny: (blk value: 'GoferBar-lr.1' value: #= value: 'GoferBar-jf.1').
	self assert: (blk value: 'Bootstrap.232-dkh.163' value: #< value: 'Bootstrap-dkh.178').
	self deny: (blk value: 'Bootstrap.232-dkh.163' value: #> value: 'Bootstrap-dkh.178').
	self deny: (blk value: 'Bootstrap.232-dkh.163' value: #= value: 'Bootstrap-dkh.178').
	self assert: (blk value: 'Bootstrap.232-dkh.178' value: #> value: 'Bootstrap-dkh.163').
	self deny: (blk value: 'Bootstrap.232-dkh.178' value: #< value: 'Bootstrap-dkh.163').
	self deny: (blk value: 'Bootstrap.232-dkh.178' value: #= value: 'Bootstrap-dkh.163').
! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'dkh 10/11/2011 22:22'!
testComparison01

	| ref1 ref2 |
	ref1 := GoferResolvedReference name: 'Bootstrap.232-dkh.163'.
	ref2 := GoferResolvedReference name: 'Bootstrap-dkh.178'.
	self assert: (ref1 compare: ref2 using: #<).
	self assert: (ref2 compare: ref1 using: #>).
	self deny: (ref2 compare: ref1 using: #=).

! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'dkh 9/4/2012 20:34'!
testIssue155
    "self debug: #testIssue155"

    | repoSpec repo project dirty |
    project := self class new project.
    repoSpec := self repositorySpec.
    repo := repoSpec createRepository.
    gofer repository: repo.
    gofer
        package: 'GoferFoo';
        package: 'GoferBar';
        load.
    self assert: (project packagesNeedSaving: '2.0-baseline') isEmpty.
    (Smalltalk classNamed: #'GoferBar') compile: 'foo'.
    self assert: (dirty := project packagesNeedSaving: '2.0') notEmpty.
    dirty do: [ :assoc | assoc key load ].
    self assert: (dirty := project packagesNeedSaving: '2.0') notEmpty.
    dirty
        do: [ :assoc | 
            [ assoc key load ]
                on: MetacelloSkipDirtyPackageLoad
                do: [ :ex | ex resume: true ] ].
    self assert: (dirty := project packagesNeedSaving: '2.0') notEmpty.
    dirty
        do: [ :assoc | 
            [ 
            [ assoc key load ]
                on: MetacelloSkipDirtyPackageLoad
                do: [ :ex | ex resume: false ] ]
                on: Warning
                do: [ :ex | ex resume: true ] ].
    self assert: (dirty := project packagesNeedSaving: '2.0') isEmpty! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'dkh 1/12/2010 15:00'!
testIssue40PackageResolution

	|  ref pkgBar pkgFoo |
	pkgBar := GoferPackageReference name: 'GoferFoo'.
	ref := pkgBar resolveWith: gofer.
	self assert: ref repository == self monticelloRepository.
	self assert: ref versionNumber = 4.
	gofer repository: self alternateRepository.
	pkgBar := GoferPackageReference name: 'GoferBar'.
	ref := pkgBar resolveWith: gofer.
	self assert: ref repository == self alternateRepository.
	self assert: ref versionNumber = 25.
	self assert: ref author = 'dkh'.
	pkgFoo := GoferPackageReference name: 'GoferFoo'.
	ref := pkgFoo resolveWith: gofer.
	self assert: ref repository == self alternateRepository.
	self assert: ref versionNumber = 104.
	gofer
		package: 'GoferBar';
		package: 'GoferFoo';
		load.
	self assert: pkgBar workingCopy ancestry ancestors first name = 'GoferBar-dkh.25'.
	self assert: pkgFoo workingCopy ancestry ancestors first name = 'GoferFoo-dkh.104'.! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'dkh 1/12/2010 15:18'!
testIssue40VersionResolution

	|  ref pkgBar pkgFoo |
	pkgBar := GoferVersionReference name: 'GoferFoo-lr.2'.
	ref := pkgBar resolveWith: gofer.
	self assert: ref repository == self monticelloRepository.
	self assert: ref versionNumber = 2.
	gofer repository: self alternateRepository.
	pkgBar := GoferVersionReference name: 'GoferBar-jf.1'.
	ref := pkgBar resolveWith: gofer.
	self assert: ref repository == self monticelloRepository.
	self assert: ref versionNumber = 1.
	self assert: ref author = 'jf'.
	ref := (GoferVersionReference name: 'GoferBar-dkh.24') resolveWith: gofer.
	self assert: ref repository == self alternateRepository.
	self assert: ref versionNumber = 24.
	self assert: ref author = 'dkh'.
	pkgFoo := GoferVersionReference name: 'GoferFoo-dkh.75'.
	ref := pkgFoo resolveWith: gofer.
	self assert: ref repository == self alternateRepository.
	self assert: ref versionNumber = 75.
	gofer
		version: 'GoferBar-jf.1';
		version: 'GoferFoo-dkh.75';
		load.
	self assert: pkgBar workingCopy ancestry ancestors first name = 'GoferBar-jf.1'.
	self assert: (pkgBar workingCopy repositoryGroup includes: self monticelloRepository).
	self assert: pkgBar workingCopy repositoryGroup repositories size = 3.
	self assert: pkgFoo workingCopy ancestry ancestors first name = 'GoferFoo-dkh.75'.
	self assert: (pkgFoo workingCopy repositoryGroup includes: self alternateRepository).
	self assert: pkgFoo workingCopy repositoryGroup repositories size = 3.
! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'DaleHenrichs 2/4/2010 15:14'!
testMoosePackageResolution

	|  ref pkg |
	pkg := GoferPackageReference name: 'GoferFaux'.
	ref := pkg resolveWith: gofer.
	self assert: ref repository == self monticelloRepository.
	self assert: ref versionNumber = 35.
	pkg := MetacelloGoferPackage name: 'GoferFaux' packageFilename: 'GoferFaux-'.
	ref := pkg resolveWith: gofer.
	self assert: ref repository == self monticelloRepository.
	self assert: ref versionNumber = 35.
	pkg := GoferPackageReference name: 'GoferFaux-'.
	self should: [ pkg resolveWith: gofer ] raise: Error.
	pkg := GoferVersionReference name: 'GoferFaux-'.
	self should: [ pkg resolveWith: gofer ] raise: Error.
! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'dkh 1/12/2010 14:39'!
testPackageResolution
	|  project version repo pkg ref |
	project := self project.
	version := project version: '1.0-baseline'.
	repo := version spec repositorySpecs first createRepository.
	gofer repository: repo.
	pkg := GoferPackageReference name: 'GoferFoo'.
	ref := pkg resolveWith: gofer.
	self assert: ref versionNumber = 4.
	pkg := GoferPackageReference name: 'GoferBar'.
	ref := pkg resolveWith: gofer.
	self assert: ref versionNumber = 1.
	self assert: ref author = 'lr'.
! !

!MetacelloGoferFunctionalTest methodsFor: 'tests' stamp: 'dkh 12/22/2009 11:49'!
testPackagesNeedSaving
	| repoSpec repo project |
	project := self class new project.
	repoSpec := self repositorySpec.
	repo := repoSpec createRepository.
	gofer repository: repo.
	gofer package: 'GoferFoo'; package: 'GoferBar'; load.
	self assert: (project packagesNeedSaving: '1.0-baseline') isEmpty.
	(Smalltalk classNamed: #GoferBar) compile: 'foo'.
	self assert: (project packagesNeedSaving: '1.0-baseline') notEmpty.
! !

!MetacelloGoferFunctionalTest methodsFor: 'versions' stamp: 'dkh 01/14/2010 14:26'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.1';
			package: 'GoferBar' with: 'GoferBar-jf.1';
			package: 'Faux-Smalltalk' with: 'Faux-Smalltalk-tg.32';
			yourself. ].
! !

!MetacelloGoferFunctionalTest methodsFor: 'versions' stamp: 'dkh 11/16/2011 11:08'!
version20: spec
	<version: '2.0' imports: #('2.0-baseline' )>
	
	spec for: #common do: [
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.1';
			package: 'GoferBar' with: 'GoferBar-jf.1';
			package: 'Faux-Smalltalk' with: 'Faux-Smalltalk-tg.32';
			yourself. ].
! !

MetacelloDictionaryRepositoryTest subclass: #MetacelloMCCachingLoaderTestCase
	instanceVariableNames: 'platformCacheRepository'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloMCCachingLoaderTestCase methodsFor: 'baselines' stamp: 'DaleHenrichs 3/4/2010 14:39'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo';
			package: 'GoferBar';
			package: 'GoferFaux';
			yourself ].
! !

!MetacelloMCCachingLoaderTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 3/7/2010 08:52'!
testBaselineFetch

	| project version repo map pkgSpecs |
	project := self project.
	version := project version: '1.0-baseline'.
	repo := version loaderPolicy cacheRepository.
	self assert: repo allVersionInfos isEmpty.
	version fetch: 'default'.
	self deny: repo allVersionInfos isEmpty.
	map := Dictionary new.
	(Gofer new allResolvedIn: repo) do: [:resolvedRef | map at: resolvedRef packageName put: resolvedRef ].
	pkgSpecs := version packages.
	self assert: map size = pkgSpecs size.
	pkgSpecs do: [:pkgSpec | map at: pkgSpec name ifAbsent: [ self assert: false ]].
		! !

!MetacelloMCCachingLoaderTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 3/4/2010 20:35'!
testBaselineLoad

	| project version wc |
	project := self project.
	version := project version: '1.0-baseline'.
	version load: #('default').
	wc := (GoferPackageReference name: 'GoferFoo') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFoo-lr.4').
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-lr.1').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferFaux-tg.35').
! !

!MetacelloMCCachingLoaderTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 3/7/2010 08:53'!
testDualFetch

	| project version repo map pkgSpecs |
	project := self project.
	version := project version: '2.0'.
	repo := version loaderPolicy cacheRepository.
	self assert: repo allVersionInfos isEmpty.
	version fetch: 'default'.
	self deny: repo allVersionInfos isEmpty.
	version := project version: '1.0-baseline'.
	version fetch: #('default').
	self deny: repo allVersionInfos isEmpty.
	map := Dictionary new.
	(Gofer new allResolvedIn: repo) do: [:resolvedRef | map at: resolvedRef packageName put: resolvedRef ].
	pkgSpecs := version packages.
	self assert: map size = pkgSpecs size.
	pkgSpecs do: [:pkgSpec | map at: pkgSpec name ifAbsent: [ self assert: false ]].
		! !

!MetacelloMCCachingLoaderTestCase methodsFor: 'tests' stamp: 'DaleHenrichs 3/7/2010 08:54'!
testVersion10Fetch

	| project version repo map pkgSpecs |
	project := self project.
	version := project version: '1.0'.
	repo := version loaderPolicy cacheRepository.
	self assert: repo allVersionInfos isEmpty.
	version fetch: #('default').
	self deny: repo allVersionInfos isEmpty.
	map := Dictionary new.
	(Gofer new allResolvedIn: repo) do: [:resolvedRef | map at: resolvedRef name put: resolvedRef ].
	pkgSpecs := version packages.
	self assert: map size = pkgSpecs size.
	pkgSpecs do: [:pkgSpec | map at: pkgSpec file ifAbsent: [ self assert: false ]].
		! !

!MetacelloMCCachingLoaderTestCase methodsFor: 'versions' stamp: 'DaleHenrichs 3/4/2010 14:55'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.1';
			package: 'GoferBar' with: 'GoferBar-jf.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.32';
			yourself. ].
! !

!MetacelloMCCachingLoaderTestCase methodsFor: 'versions' stamp: 'DaleHenrichs 3/4/2010 18:35'!
version20: spec
	<version: '2.0' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.4';
			package: 'GoferBar' with: 'GoferBar-lr.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.35';
			yourself. ].
! !

MetacelloDictionaryRepositoryTest subclass: #MetacelloMCSpecLoaderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloMCSpecLoaderTest methodsFor: 'baselines' stamp: 'DaleHenrichs 1/20/2010 09:57'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec 
			package: 'GoferFoo';
			package: 'GoferBar';
			package: 'GoferFaux';
			yourself ].
! !

!MetacelloMCSpecLoaderTest methodsFor: 'baselines' stamp: 'dkh 01/14/2010 12:30'!
baseline20: spec 
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec repository: 'dictionary://Metacello_Configuration_Test_Alternate_Repository'.
		spec 
			package: 'GoferFoo';
			package: 'GoferBar';
			yourself ].
! !

!MetacelloMCSpecLoaderTest methodsFor: 'running' stamp: 'DaleHenrichs 12/21/2010 10:29'!
doSilently

	^(#(#testPackageSave ) includes: testSelector asSymbol) not! !

!MetacelloMCSpecLoaderTest methodsFor: 'running' stamp: 'dkh 01/14/2010 16:53'!
tearDown
	super tearDown.
	MetacelloMonticelloResource reset. "testCommitPackageSpec modifies the repository resource"! !

!MetacelloMCSpecLoaderTest methodsFor: 'tests' stamp: 'dkh 01/14/2010 12:46'!
testCopySpec

	| project version loader repo fakePackage |
	project := self project.
	version := project version: '1.0-baseline'.
	loader := version spec loader.
	repo := MCDictionaryRepository new.
	self assert: repo allVersionInfos size = 0.
	loader 
		copySpec: (version packageNamed: 'GoferFoo')
		from: version spec repositorySpecs
		to: repo.
	self assert: repo allVersionInfos size = 1.
	
	"error condition"
	fakePackage := version packageNamed: 'GoferFoo'.
	fakePackage name: 'MetacelloTestConfigurationOfFoo'.
	self assert: (loader 
		copySpec: fakePackage
		from: version spec repositorySpecs
		to: repo) == nil
! !

!MetacelloMCSpecLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/15/2010 11:38'!
testGoferCommit

	| project version repoSpec repo allVersionsSize pkg |
	project := self project.
	version := project version: '1.0'.
	repoSpec := version spec repositorySpecs first.
	repo := repoSpec createRepository.
	allVersionsSize := repo allVersionInfos size.
	version load.
	(Smalltalk classNamed: #GoferBar) compile: 'foo'.
	pkg := version packageNamed: 'GoferBar'.
	pkg repository: repoSpec.
	pkg goferCommitPackage: 'commit message'.
	self assert: repo allVersionInfos size = (allVersionsSize + 1)! !

!MetacelloMCSpecLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 2/4/2010 15:15'!
testLatestPackage

	| project version loader latestFile |
	project := self project.
	version := project version: '1.0-baseline'.
	loader := version spec loader.
	latestFile := loader 
		latestPackage: 'GoferFoo' 
		fromRepository: version spec repositorySpecs.
	self assert: latestFile = 'GoferFoo-lr.4'.

	latestFile := loader 
		latestPackage: 'GoferBar' 
		fromRepository: version spec repositorySpecs.
	self assert: latestFile = 'GoferBar-lr.1'.

	latestFile := loader 
		latestPackage: 'GoferFaux' 
		fromRepository: version spec repositorySpecs.
	self assert: latestFile = 'GoferFaux-tg.35'.

	"error condition"
	latestFile := loader 
		latestPackage: 'MetacelloTestConfigurationOfFoo' 
		fromRepository: version spec repositorySpecs.
	self assert: latestFile == nil.
! !

!MetacelloMCSpecLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 01/16/2011 13:28'!
testPackageSave

	| project version repoSpec repo allVersionsSize pkg |
	project := self project.
	version := project version: '1.0'.
	repoSpec := version spec repositorySpecs first.
	repo := repoSpec createRepository.
	allVersionsSize := repo allVersionInfos size.
	version load.
	(Smalltalk classNamed: #GoferBar) compile: 'foo'.
	pkg := version packageNamed: 'GoferBar'.
	pkg repository: repoSpec.
	[ pkg savePackage ]
		on: MCVersionNameAndMessageRequest
		do: [ :notifcation | notifcation resume: (Array with: notifcation suggestedName with: 'xxx') ].
	self assert: repo allVersionInfos size = (allVersionsSize + 1)! !

!MetacelloMCSpecLoaderTest methodsFor: 'tests' stamp: 'DaleHenrichs 3/5/2010 14:17'!
testPackageSpecLoad

	| project version repoSpec pkg wc |
	project := self project.
	version := project version: '1.0'.
	repoSpec := version spec repositorySpecs first.
	pkg := version packageNamed: 'GoferBar'.
	pkg repository: repoSpec.
	pkg load.
	wc := (GoferPackageReference name: 'GoferBar') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBar-jf.1').
! !

!MetacelloMCSpecLoaderTest methodsFor: 'tests' stamp: 'dkh 2/22/2011 20:08'!
testRepositoryFor

	| project version loader pkgSpec repo1 repo2 |
	project := self project.
	version := project version: '2.0-baseline'.
	loader := version spec loader.
	pkgSpec := version packageNamed: 'GoferBar'.
	repo1 := self monticelloRepository.
	repo2 := self alternateRepository.

	pkgSpec file: 'GoferBar.branch-lr.1'.
	self assert: 
		(loader 
			repositoryFor: pkgSpec 
			from: version spec repositorySpecs) == repo1.
	pkgSpec file: 'GoferBar-dkh.25'.
	self assert: 
		(loader 
			repositoryFor: pkgSpec 
			from: version spec repositorySpecs) == repo2.

	"error condition"
	pkgSpec file: 'MetacelloTestConfigurationOfFoo-dkh.1'.
	self assert: 
		(loader 
			repositoryFor: pkgSpec 
			from: version spec repositorySpecs) == nil.
! !

!MetacelloMCSpecLoaderTest methodsFor: 'versions' stamp: 'DaleHenrichs 1/20/2010 09:57'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec 
			package: 'GoferFoo' with: 'GoferFoo-lr.1';
			package: 'GoferBar' with: 'GoferBar-jf.1';
			package: 'GoferFaux' with: 'GoferFaux-tg.32';
			yourself. ].
! !

MetacelloDictionaryRepositoryTest subclass: #MetacelloSymbolicVersionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloSymbolicVersionTest methodsFor: 'baselines' stamp: 'DaleHenrichs 1/21/2011 10:00'!
baseline20: spec 
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec 
			project: 'Symbolic' with: [
				spec
					className: 'MetacelloTestConfigurationOfSymbolic';
					repository: 'dictionary://Metacello_Configuration_Test_Repository' ];
			yourself ].
! !

!MetacelloSymbolicVersionTest methodsFor: 'versions' stamp: 'DaleHenrichs 1/21/2011 10:00'!
bleedingEdge: spec 
	<symbolicVersion: #bleedingEdge>
	
	spec for: #'platformVersion1.x' version: '2.0-baseline'.
! !

!MetacelloSymbolicVersionTest methodsFor: 'running' stamp: 'dkh 4/18/2011 15:23'!
setUp

	| repo |
	super setUp.
	repo := self configurationRepository.
	self tempRepositories add: repo.
	gofer repository: repo! !

!MetacelloSymbolicVersionTest methodsFor: 'versions' stamp: 'DaleHenrichs 9/22/2010 16:28'!
stableVersion: spec 
	<symbolicVersion: #stable>
	
	spec for: #'platformVersion1.x' version: '1.1'.
! !

!MetacelloSymbolicVersionTest methodsFor: 'running' stamp: 'DaleHenrichs 9/23/2010 15:19'!
tearDown

	super tearDown.
	MetacelloConfigurationResource projectAttributes: nil! !

!MetacelloSymbolicVersionTest methodsFor: 'running' stamp: 'DaleHenrichs 9/22/2010 16:13'!
tearDownPackages: aGoferInstance

	super tearDownPackages: aGoferInstance.
	(self hasPackage: 'MetacelloTestConfigurationOfSymbolic')
		ifTrue: [ aGoferInstance package: 'MetacelloTestConfigurationOfSymbolic' ].
! !

!MetacelloSymbolicVersionTest methodsFor: 'tests stable' stamp: 'DaleHenrichs 9/22/2010 17:08'!
testBasicStableVersion

	| project version wc |
	project := self projectWith: #(#'platformVersion1.x').
	version := project version: #stable.
	version load.
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.25').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferFaux-tg.31'.! !

!MetacelloSymbolicVersionTest methodsFor: 'tests stable' stamp: 'DaleHenrichs 1/21/2011 10:01'!
testBleedingEdgeMethod

	| project version |
	project := self projectWith: #(#'platformVersion1.x').
	self assert: (project version: #bleedingEdge) = project bleedingEdge.
! !

!MetacelloSymbolicVersionTest methodsFor: 'tests stable' stamp: 'DaleHenrichs 9/23/2010 15:51'!
testStableVersion

	| project version wc |
	project := self project.
	version := project version: '2.0'.
	version load.
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.53').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferFaux-tg.32'.! !

!MetacelloSymbolicVersionTest methodsFor: 'tests stable' stamp: 'DaleHenrichs 9/23/2010 15:20'!
testStableVersion10x

	| project version wc |
	MetacelloConfigurationResource projectAttributes: #(#'platformVersion1.x' #'platformVersion1.0.x' ).
	project := self project.
	version := project version: '2.0'.
	version load.
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.25').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferFaux-tg.31'! !

!MetacelloSymbolicVersionTest methodsFor: 'tests stable' stamp: 'DaleHenrichs 9/23/2010 15:23'!
testStableVersion11x

	| project version wc |
	MetacelloConfigurationResource projectAttributes: #(#'platformVersion1.x' #'platformVersion1.1.x' ).
	project := self project.
	version := project version: '2.0'.
	version load.
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.53').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferFaux-tg.32'! !

!MetacelloSymbolicVersionTest methodsFor: 'tests stable' stamp: 'DaleHenrichs 9/23/2010 15:23'!
testStableVersion12x

	| project version wc |
	MetacelloConfigurationResource projectAttributes: #(#'platformVersion1.x' #'platformVersion1.2.x' ).
	project := self project.
	version := project version: '2.0'.
	version load.
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.54').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferFaux-tg.33'! !

!MetacelloSymbolicVersionTest methodsFor: 'tests stable' stamp: 'DaleHenrichs 9/23/2010 15:24'!
testStableVersion1x

	| project version wc |
	MetacelloConfigurationResource projectAttributes: #(#'platformVersion1.x').
	project := self project.
	version := project version: '2.0'.
	version load.
	wc := (GoferPackageReference name: 'GoferBeau') workingCopy.
	self assert: (wc ancestry ancestors first name = 'GoferBeau-dkh.15').
	wc := (GoferPackageReference name: 'GoferFaux') workingCopy.
	self assert: wc ancestry ancestors first name = 'GoferFaux-tg.30'! !

!MetacelloSymbolicVersionTest methodsFor: 'tests stable' stamp: 'DaleHenrichs 1/21/2011 09:58'!
testStableVersionMethod

	| project version |
	project := self projectWith: #(#'platformVersion1.x').
	self assert: (project version: #stable) = project stableVersion.
! !

!MetacelloSymbolicVersionTest methodsFor: 'versions' stamp: 'DaleHenrichs 9/22/2010 16:27'!
version10: spec 
	<version: '1.0'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #release.
		spec 
			package: 'GoferBeau' with: 'GoferBeau-dkh.15';
			package: 'GoferFaux' with:'GoferFaux-tg.30';
			yourself ].
! !

!MetacelloSymbolicVersionTest methodsFor: 'versions' stamp: 'DaleHenrichs 9/22/2010 16:27'!
version11: spec 
	<version: '1.1'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #release.
		spec 
			package: 'GoferBeau' with: 'GoferBeau-dkh.25';
			package: 'GoferFaux' with:'GoferFaux-tg.31';
			yourself ].
! !

!MetacelloSymbolicVersionTest methodsFor: 'versions' stamp: 'DaleHenrichs 9/22/2010 16:28'!
version12: spec 
	<version: '1.2'>
	
	spec for: #common do: [
		spec repository: 'dictionary://Metacello_Gofer_Test_Repository'.
		spec blessing: #release.
		spec 
			package: 'GoferBeau' with: 'GoferBeau-dkh.53';
			package: 'GoferFaux' with:'GoferFaux-tg.32';
			yourself ].
! !

!MetacelloSymbolicVersionTest methodsFor: 'versions' stamp: 'DaleHenrichs 9/22/2010 16:32'!
version20: spec 
	<version: '2.0' imports: #('2.0-baseline')>
	
	spec for: #common do: [ spec project: 'Symbolic' with:  #stable ].
! !

MetacelloDictionaryRepositoryTest subclass: #MetacelloToolBoxConstructorTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC'!

!MetacelloToolBoxConstructorTestCase methodsFor: 'private' stamp: 'dkh 6/12/2012 15:41:23.319'!
assertMethodSourceFor: configurationName isEqualAfterModifyingVersion: versionString
	| cl original modified constructor pragma |
	constructor := MetacelloToolBoxConstructor new.
	constructor configuration: (cl := Smalltalk at: configurationName asSymbol) new.
	pragma := (constructor extractAllVersionPragmas at: versionString) at: 1.
	original := (cl sourceCodeAt: pragma selector) asString.
	[ 
	(MetacelloToolBox configurationNamed: configurationName)
		modifyVersionMethodForVersion: versionString;
		commitMethod ] on: MetacelloCannotUpdateReleasedVersionError do: [ :ex | ex resume ].
	modified := (cl sourceCodeAt: pragma selector) asString.
	self assert: original = modified.
! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'private' stamp: 'dkh 6/12/2012 15:41:23.319'!
assertVersionSpecFor: configurationName isEqualAfterModifyingVersion: versionString
	| original modified |
	original := ((Smalltalk at: configurationName asSymbol) project version: versionString) versionSpec printString.
	[ 
	(MetacelloToolBox configurationNamed: configurationName)
		modifyVersionMethodForVersion: versionString;
		commitMethod ] on: MetacelloCannotUpdateReleasedVersionError do: [ :ex | ex resume ].
	modified := ((Smalltalk at: configurationName asSymbol) project version: versionString) versionSpec printString.
	self assert: original = modified.
! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'private' stamp: 'dkh 6/12/2012 15:41:23.319'!
atomicConfigurationRepository

	^MetacelloAtomicConfigurationResource current monticelloRepository! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'private' stamp: 'dkh 6/12/2012 15:41:23.319'!
configurationNameList
	^ #(  'MetacelloTestConfigurationOfIssue77B' 'MetacelloTestConfigurationOfIssue77C' 'MetacelloTestConfigurationOfIssue77D' 'MetacelloTestConfigurationOfAtomicFan' 'MetacelloTestConfigurationOfAtomicFoo' 'MetacelloTestConfigurationOfFan' 'MetacelloTestConfigurationOfFeaux' 'MetacelloTestConfigurationOfFix' 'MetacelloTestConfigurationOfFoo' 'MetacelloTestConfigurationOfFum' 'MetacelloTestConfigurationOfLinearFoo' 'MetacelloTestConfigurationOfProjectFee' 'MetacelloTestConfigurationOfProjectFie' 'MetacelloTestConfigurationOfProjectFoe' 'MetacelloTestConfigurationOfProjectInfinite' 'MetacelloTestConfigurationOfProjectIssue86' 'MetacelloTestConfigurationOfProjectIssue95' 'MetacelloTestConfigurationOfProjectLoop' 'MetacelloTestConfigurationOfUmbrellaA' 'MetacelloTestConfigurationOfUmbrellaB')! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'private' stamp: 'dkh 6/12/2012 15:41:23.319'!
fullConfigurationNameList

	^self configurationNameList, #('MetacelloTestConfigurationOfProjectToolBox')! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'running' stamp: 'dkh 6/12/2012 15:41:23.319'!
setUp
	| repo |
	super setUp.
	repo := MetacelloAtomicConfigurationResource current monticelloRepository.
	self tempRepositories add: repo.
	Smalltalk at: #'Metacello_Atomic_Configuration_Test_Repository' put: repo.! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'running' stamp: 'dkh 6/12/2012 15:41:23.319'!
tearDown
	| aGofer |
	super tearDown.
	Smalltalk removeKey: #'Metacello_Atomic_Configuration_Test_Repository' ifAbsent: [].
	MetacelloConfigurationResource projectAttributes: nil! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'running' stamp: 'dkh 6/12/2012 15:41:23.319'!
tearDownPackages: aGoferInstance
	super tearDownPackages: aGoferInstance.
	self fullConfigurationNameList
		do: [ :configurationName | 
			(self hasPackage: configurationName)
				ifTrue: [ aGoferInstance package: configurationName ] ]! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testConfigurationResources
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	self configurationNameList do: [ :configurationName | gofer package: configurationName ].
	gofer load.
	self configurationNameList
		do: [ :configurationName | 
			((Smalltalk at: configurationName asSymbol) new project versions collect: [ :each | each versionString ])
				do: [ :versionString | self assertVersionSpecFor: configurationName isEqualAfterModifyingVersion: versionString ] ]! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBox
	| configurationName rejects |
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer package: configurationName.
	gofer load.
	rejects := #('1.0.4-baseline' '1.0.6-baseline' '1.0.7-baseline' '1.1.0-baseline' '1.1.4-baseline' '1.1.6-baseline' '1.2.8-baseline' '1.2.9-baseline' ).
	(((Smalltalk at: configurationName asSymbol) new project versions collect: [ :each | each versionString ])
		reject: [ :each | rejects includes: each ])
		do: [ :versionString | self assertVersionSpecFor: configurationName isEqualAfterModifyingVersion: versionString ]! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBox104Baseline
	| configurationName versionString |
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer package: configurationName.
	gofer load.
	versionString := '1.0.4-baseline'.
	self assertVersionSpecFor: configurationName isEqualAfterModifyingVersion: versionString.
! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBox106Baseline
	| configurationName versionString |
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer package: configurationName.
	gofer load.
	versionString := '1.0.6-baseline'.
	self assertVersionSpecFor: configurationName isEqualAfterModifyingVersion: versionString! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBox107Baseline
	| configurationName versionString |
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer package: configurationName.
	gofer load.
	versionString := '1.0.7-baseline'.
	self assertVersionSpecFor: configurationName isEqualAfterModifyingVersion: versionString! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBox110Baseline
	| configurationName versionString |
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer package: configurationName.
	gofer load.
	versionString := '1.1.0-baseline'.
	self assertVersionSpecFor: configurationName isEqualAfterModifyingVersion: versionString! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBox114Baseline
	| configurationName versionString |
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer package: configurationName.
	gofer load.
	versionString := '1.1.4-baseline'.
	self assertVersionSpecFor: configurationName isEqualAfterModifyingVersion: versionString! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBox116Baseline
	| configurationName versionString |
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer package: configurationName.
	gofer load.
	versionString := '1.1.6-baseline'.
	self assertVersionSpecFor: configurationName isEqualAfterModifyingVersion: versionString! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBox128Baseline
	| configurationName versionString |
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer package: configurationName.
	gofer load.
	versionString := '1.2.8-baseline'.
	self assertVersionSpecFor: configurationName isEqualAfterModifyingVersion: versionString! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBox129Baseline
	| configurationName versionString |
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer package: configurationName.
	gofer load.
	versionString := '1.2.9-baseline'.
	self assertVersionSpecFor: configurationName isEqualAfterModifyingVersion: versionString! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBoxSourceComparison
	| configurationName rejects |
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer package: configurationName.
	gofer load.
	rejects := #('1.0.6-baseline' '1.1.1-baseline' '1.1.2-baseline' '1.1.3' '1.3.0-baseline' '1.3.1-baseline' '1.3.2-baseline' '1.3.3-baseline').
	(((Smalltalk at: configurationName asSymbol) new project versions collect: [ :each | each versionString ])
		reject: [ :each | rejects includes: each ])
		do: [ :versionString | self assertMethodSourceFor: configurationName isEqualAfterModifyingVersion: versionString ]! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBoxSourceComparison106Baseline
	| configurationName versionString |
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer package: configurationName.
	gofer load.
	versionString := '1.0.6-baseline'.
	self assertMethodSourceFor: configurationName isEqualAfterModifyingVersion: versionString! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBoxSourceComparison111Baseline
	| configurationName versionString |
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer package: configurationName.
	gofer load.
	versionString := '1.1.1-baseline'.
	self assertMethodSourceFor: configurationName isEqualAfterModifyingVersion: versionString! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBoxSourceComparison112Baseline
	| configurationName versionString |
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer package: configurationName.
	gofer load.
	versionString := '1.1.2-baseline'.
	self assertMethodSourceFor: configurationName isEqualAfterModifyingVersion: versionString! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBoxSourceComparison113
	| configurationName versionString |
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer package: configurationName.
	gofer load.
	versionString := '1.1.3'.
	self assertMethodSourceFor: configurationName isEqualAfterModifyingVersion: versionString.
! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBoxSourceComparison130Baseline
	| configurationName versionString |
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer package: configurationName.
	gofer load.
	versionString := '1.3.0-baseline'.
	self assertMethodSourceFor: configurationName isEqualAfterModifyingVersion: versionString! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBoxSourceComparison131Baseline
	| configurationName versionString |
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer package: configurationName.
	gofer load.
	versionString := '1.3.1-baseline'.
	self assertMethodSourceFor: configurationName isEqualAfterModifyingVersion: versionString! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBoxSourceComparison132Baseline
	| configurationName versionString |
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer package: configurationName.
	gofer load.
	versionString := '1.3.2-baseline'.
	self assertMethodSourceFor: configurationName isEqualAfterModifyingVersion: versionString! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBoxSourceComparison133Baseline
	| configurationName versionString |
	gofer
		repository: self atomicConfigurationRepository;
		repository: self alternateRepository;
		repository: self configurationRepository.
	configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
	gofer package: configurationName.
	gofer load.
	versionString := '1.3.3-baseline'.
	self assertMethodSourceFor: configurationName isEqualAfterModifyingVersion: versionString! !

!MetacelloToolBoxConstructorTestCase methodsFor: 'tests' stamp: 'dkh 6/12/2012 15:41:23.319'!
testProjectToolBoxTraversal131Baseline
    | configurationName versionString expected toolbox attributes |
    gofer
        repository: self atomicConfigurationRepository;
        repository: self alternateRepository;
        repository: self configurationRepository.
    configurationName := 'MetacelloTestConfigurationOfProjectToolBox'.
    gofer package: configurationName.
    gofer load.
    versionString := '1.3.1-baseline'.
    attributes := #(#'level1_1' #'level2_2' #'level3_2' #'level2_1').
    MetacelloConfigurationResource projectAttributes: attributes.
    toolbox := MetacelloToolBox new project: (Smalltalk at: configurationName asSymbol) project.
    expected := Dictionary new.
    expected
        at: #(#(#'level1_1') #(#'level2_1')) asMetacelloAttributePath
        put:
            'spec package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/4''. ].'.
    expected
        at: #(#(#'level1_1') #(#'level2_2') #(#'level3_2')) asMetacelloAttributePath
        put:
            'spec package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/7''. ].'.
    expected
        at: #(#(#'level1_1') #(#'level2_2')) asMetacelloAttributePath
        put:
            'spec package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/6''. ].'.
    expected
        at: #'level1_1' asMetacelloAttributePath
        put:
            'spec 
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/1''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/2''. ];
	package: ''Example-Core'' with: [
		spec repository: ''http://www.example.com/3''. ].'.
    toolbox
        updateVersionMethodForVersion: versionString
        updateProjects: false
        updatePackages: false
        versionSpecsDo: [ :attributeOrPath :versionSpec | 
            attributeOrPath ~~ #'common'
                ifTrue: [ 
                    | string |
                    string := versionSpec printString.
                    self assert: string = (expected at: attributeOrPath asMetacelloAttributePath) ].
            false ]! !

MetacelloBaseConfiguration subclass: #MetacelloMCTestsAbstractConfig
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Configurations'!

MetacelloMCTestsAbstractConfig subclass: #MetacelloExampleProjectConfig
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Configurations'!

!MetacelloExampleProjectConfig methodsFor: 'baselines' stamp: 'DaleHenrichs 1/21/2010 18:38'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core';
			package: 'Example-AddOn' with: [ spec requires: #('Example-Core' ) ];
			package: 'Example-Tests' with: [ spec requires: #('Example-AddOn' ) ];
			package: 'Example-TestsUI' with: [ spec requires: #('Example-UI' 'Example-Tests' ) ];
			package: 'Example-UI' with: [ spec requires: #('Example-AddOn' ) ]].
! !

!MetacelloMCTestsAbstractConfig methodsFor: 'accessing' stamp: 'dkh 10/21/2009 13:37'!
project

	| constructor |
	^project ifNil: [
		"Construct Metacello project"
		constructor := MetacelloVersionConstructor on: self.
		project := constructor project.
		project loader: MetacelloNullRecordingMCSpecLoader new.
		project].
! !

MetacelloMCTestsAbstractConfig subclass: #MetacelloVersionQueryExampleConfig
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Configurations'!

!MetacelloVersionQueryExampleConfig methodsFor: 'baselines' stamp: 'DaleHenrichs 3/11/2010 21:14'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec
			project: 'UTF8' with: [
				spec
					className: 'MetacelloVersionQueryMiscConfig';
					file: 'MetacelloVersionQueryMiscConfig';
					versionString: '1.0-baseline';
					loads: #('Misc-UTF8' ) ].
		spec 
			package: 'Example-Core' with: [ spec requires: #('UTF8' ) ];
			package: 'Example-AddOn' with: [ spec requires: #('Example-Core' ) ];
			package: 'Example-Tests' with: [ spec requires: #('Example-AddOn' ) ];
			package: 'Example-TestsUI' with: [ spec requires: #('Example-UI' 'Example-Tests' ) ];
			package: 'Example-UI' with: [ spec requires: #('Example-AddOn' ) ].
		spec
			group: 'Core' with: #('Example-Core' 'Example-AddOn' );
			group: 'Tests' with: #('Example-Tests' 'Example-TestsUI' );
			group: 'No UI' with: #('Core' 'Example-Tests' );
			"recursive group definition"
			group: 'UI' with: #('No UI' 'UI' 'Tests' ).].
! !

!MetacelloVersionQueryExampleConfig methodsFor: 'baselines' stamp: 'DaleHenrichs 2/8/2010 16:41'!
baseline20: spec 
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core';
			package: 'Example-AddOn' with: [ spec requires: #('Example-Core' ) ].
		spec
			group: 'Core' with: #('default' );
			group: 'default' with: #('Example-Core' ) ].
! !

!MetacelloVersionQueryExampleConfig methodsFor: 'baselines' stamp: 'DaleHenrichs 2/8/2010 17:07'!
baseline21: spec 
	<version: '2.1-baseline'>
	
	spec for: #common do: [
		spec 
			package: 'Example-Core';
			package: 'Core' with: [ spec requires: #('Example-Core' ) ].
		spec
			group: 'default' with: #('Example-Core' ) ].
! !

MetacelloMCTestsAbstractConfig subclass: #MetacelloVersionQueryLatestVersionConfig
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Configurations'!

!MetacelloVersionQueryLatestVersionConfig methodsFor: 'baselines' stamp: 'dkh 12/21/2009 14:48'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'simple baseleine:)'].
! !

!MetacelloVersionQueryLatestVersionConfig methodsFor: 'versions' stamp: 'dkh 12/21/2009 14:48'!
version112: spec
	<version: '1.1.2' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec blessing: #stable ].
! !

!MetacelloVersionQueryLatestVersionConfig methodsFor: 'versions' stamp: 'dkh 12/21/2009 14:48'!
version120: spec
	<version: '1.2' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec blessing: #stable ].
! !

!MetacelloVersionQueryLatestVersionConfig methodsFor: 'versions' stamp: 'dkh 12/21/2009 14:48'!
version130: spec
	<version: '1.3' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec blessing: #development ].
! !

!MetacelloVersionQueryLatestVersionConfig methodsFor: 'versions' stamp: 'dkh 12/21/2009 14:48'!
version131: spec
	<version: '1.3.1' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec blessing: #development ].
! !

!MetacelloVersionQueryLatestVersionConfig methodsFor: 'versions' stamp: 'dkh 12/21/2009 14:48'!
version132: spec
	<version: '1.3.2' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec blessing: #development ].
! !

MetacelloMCTestsAbstractConfig subclass: #MetacelloVersionQueryMasterConfig
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Configurations'!

!MetacelloVersionQueryMasterConfig methodsFor: 'baselines' stamp: 'dkh 10/24/2009 14:50'!
baselineProject30: spec 
	<version: '3.0-baseline'>
	
	spec for: #common do: [
		spec
			project: 'XML' with: [
				spec
					className: 'MetacelloVersionQueryMiscConfig';
					versionString: '1.0-baseline';
					loads: #('Misc-XML') ];
			project: 'Project Core' with: [
				spec
					className: 'MetacelloVersionQueryProjectConfig';
					versionString: '2.1-baseline';
					loads: #('Core') ];
			project: 'Project Tests' with: [
				spec
					className: 'MetacelloVersionQueryProjectConfig';
					versionString: '2.1-baseline';
					loads: #('Tests') ].
		spec 
			package: 'Master-Core' with: [ 
				spec 
					includes: #('Master-Platform');
					requires: #('Project Core' 'XML') ];
			package: 'Master-Platform';
			package: 'Master-Tests' with: [ 
				spec requires: #('Master-Core' 'Project Tests') ].
		spec
			group: 'Core' with: #('Master-Core');
			group: 'Tests' with: #('Master-Tests').].
! !

!MetacelloVersionQueryMasterConfig methodsFor: 'baselines' stamp: 'DaleHenrichs 1/22/2010 11:41'!
baselineProject31: spec 
	<version: '3.1-baseline'>
	
	spec for: #common do: [
		spec
			project: 'XML' with: [
				spec
					className: 'MetacelloVersionQueryMiscConfig';
					loads: #('Misc-XML') ];
			project: 'Project Core' with: [
				spec
					className: 'MetacelloVersionQueryProjectConfig';
					versionString: '2.1-baseline';
					loads: #('Core') ];
			project: 'Project Tests' with: [
				spec
					className: 'MetacelloVersionQueryProjectConfig';
					versionString: '2.1-baseline';
					loads: #('Tests') ].
		spec 
			package: 'Master-Core' with: [ 
				spec 
					includes: #('Master-Platform');
					requires: #('Project Core' 'XML') ];
			package: 'Master-Platform';
			package: 'Master-Tests' with: [ 
				spec requires: #('Master-Core' 'Project Tests') ].
		spec
			group: 'Core' with: #('Master-Core');
			group: 'Tests' with: #('Master-Tests').].
! !

MetacelloMCTestsAbstractConfig subclass: #MetacelloVersionQueryMiscConfig
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Configurations'!

!MetacelloVersionQueryMiscConfig methodsFor: 'baselines' stamp: 'DaleHenrichs 11/3/2010 10:27'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec 
			package: 'Misc-UTF8';
			package: 'Misc-MD5';
			package: 'Misc-XML'.].
! !

MetacelloMCTestsAbstractConfig subclass: #MetacelloVersionQueryProjectConfig
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Configurations'!

!MetacelloVersionQueryProjectConfig methodsFor: 'baselines' stamp: 'DaleHenrichs 3/11/2010 23:47'!
baselineProject20: spec 
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec
			project: 'Example ALL' with: [
				spec
					className: 'MetacelloVersionQueryExampleConfig';
					versionString: '1.0-baseline';
					loads: #('ALL' ) ].
		spec 
			package: 'Project-Core' with: [ spec requires: 'Example ALL' ];
			package: 'Project-Tests' with: [ spec requires: 'Project-Core' ].
		spec
			group: 'Core' with: #('Project-Core' );
			group: 'Tests' with: #('Project-Tests' ).].
! !

!MetacelloVersionQueryProjectConfig methodsFor: 'baselines' stamp: 'DaleHenrichs 3/11/2010 23:47'!
baselineProject21: spec 
	<version: '2.1-baseline'>
	
	spec for: #common do: [
		spec
			project: 'MD5' with: [
				spec
					className: 'MetacelloVersionQueryMiscConfig';
					versionString: '1.0-baseline';
					loads: #('Misc-MD5' ) ];
			project: 'Example Core' with: [
				spec
					className: 'MetacelloVersionQueryExampleConfig';
					versionString: '1.0-baseline';
					loads: #('Core' ) ];
			project: 'Example Tests' with: [
				spec
					className: 'MetacelloVersionQueryExampleConfig';
					versionString: '1.0-baseline';
					loads: #('Example-Tests' ) ].
		spec 
			package: 'Project-Core' with: [ spec requires: #('Example Core' 'MD5' ) ];
			package: 'Project-Tests' with: [ spec requires: #('Project-Core' 'Example Tests' ) ].
		spec
			group: 'Core' with: #('Project-Core' );
			group: 'Tests' with: #('Project-Tests' ).].
! !

MCPackage subclass: #MetacelloTestsMCPackage
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Gofer'!

!MetacelloTestsMCPackage methodsFor: 'accessing' stamp: 'DaleHenrichs 12/18/2010 20:09'!
packageInfo
	"Aiming for speeding up the running of the tests"

	^ MetacelloTestsPackageInfo named: name! !

PackageInfo subclass: #MetacelloTestsPackageInfo
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Gofer'!

!MetacelloTestsPackageInfo methodsFor: 'listing' stamp: 'DaleHenrichs 12/18/2010 20:18'!
extensionMethods
	"Test packages don't extend classes and skipping this operation is a significant performance gain for running tests"
	^ #()! !

!MetacelloTestsPackageInfo methodsFor: 'listing' stamp: 'DaleHenrichs 12/18/2010 20:09'!
overriddenMethods
	"Test packages don't override methods and skipping this operation is a significant performance gain for running tests"
	^ #()! !

GoferUnload subclass: #MetacelloTestsGoferUnload
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-TestsMC-Gofer'!

!MetacelloTestsGoferUnload methodsFor: 'running' stamp: 'DaleHenrichs 12/18/2010 14:33'!
execute
	self workingCopies 
		do: [ :copy | self unload: copy ].
	self model load.
	self gofer metacelloCleanup.
	self workingCopies 
		do: [ :copy | self unregister: copy ]! !

!MetacelloTestsGoferUnload methodsFor: 'unloading' stamp: 'DaleHenrichs 12/18/2010 20:10'!
unloadClasses: aWorkingCopy
	"skip this so that tests run faster"! !
